<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE xsl:stylesheet [
	<!ENTITY copy "&#169;">
	<!ENTITY nbsp "&#160;">
  <!ENTITY lk "/webcenter_page/user_lang_key">
]>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:XSLUtils="com.esko.webcenter.jsp.XSLUtils" xmlns:Lang="com.esko.webcenter.jsp.LanguageMgr" exclude-result-prefixes="XSLUtils Lang">
	<xsl:import href="template.xsl"/>
	<xsl:import href="attrunittmplts.xsl"/>
	<xsl:import href="approvaltemplate.xsl"/>
	<xsl:import href="searchresultstemplate.xsl"/>
	<xsl:import href="projmgmnttemplate.xsl"/>
	<xsl:import href="templatedate.xsl"/>	
	
	<xsl:key name="docVerSearchResultKey" match="/webcenter_page/search_results/doc_ver_search_result_list/doc_ver_search_result" use="@id"/>

	<xsl:template name="header"/>
	<xsl:template name="bodyheader">
	  	<!-- search results header -->
		<xsl:call-template name="searchResultsHeader"/>
	</xsl:template>

	<!-- 
  
            template that controls the generation of the body content
            
	-->
	<xsl:template name="bodycontent">
		<!-- Form for re run of search -->
		<xsl:call-template name="SearchResultsStoredValues"/>
		
		<!-- id of the action form to submit -->
		<xsl:variable name="actionFormName"><xsl:call-template name="actionFormName"/></xsl:variable>
		
		<!-- hpSection id... -->
		<xsl:variable name="hpSectionId" select="/webcenter_page/hp_section_id"/>		
	    <xsl:variable name="hpSectionIdPrefix"> 
		  <xsl:choose>
			 <xsl:when test="string-length($hpSectionId) = 0"><xsl:value-of select="''"/></xsl:when>
			 <xsl:otherwise><xsl:value-of select="$hpSectionId"/><xsl:value-of select="'_'"/></xsl:otherwise>
	      </xsl:choose>
	    </xsl:variable>
	    
	    <!-- general layout settings -->
		<xsl:variable name="showThumbnails" select="number(/webcenter_page/show_thumbnails)"/>
		<xsl:variable name="resultsStyle" select="/webcenter_page/results_style"/>
	    
	    <!-- Do we want to show actions? NOT if we are in a popup to select items! -->
		<xsl:variable name="showActions">
		    <!-- Don't show Actions menu when in saved search dialog used for selecting items -->
		    <xsl:if test="$hpSectionIdPrefix!='00001_9000000000_' and $hpSectionIdPrefix!='00001_8900000000_'">
				<xsl:value-of select="1"/>
		    </xsl:if>
		</xsl:variable>
		
		<!-- Don't show Actions menu when in saved search dialog used for selecting items -->
		<xsl:variable name="stickyActions">
			<xsl:call-template name="isStickyActions" />
		</xsl:variable>
		
		<xsl:variable name="withShowHideThumbnailsButton">
			<xsl:call-template name="withShowHideThumbnailsButton" />
		</xsl:variable>
		
		<!-- In case of Saved search in iFrame (for DAM connections) we do not want hyperlinks -->
	    <xsl:variable name="noHyperlinks">
		    <!-- Don't show Actions menu when in saved search dialog used for selecting items -->
		    <xsl:choose>
				<xsl:when test="$hpSectionIdPrefix ='00001_8900000000_'">
					<xsl:value-of select="1"/>							
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="0"/>							
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<!--
		
			The search results javascript component
			
		 -->
		<div 
			data-init="component/searchresults/internal/SearchResultsControl" 
			data-searchdata="{/webcenter_page/searchdata/datajson}"
			data-hpsectionid="{$hpSectionId}" 
			data-rerunurl="{/webcenter_page/searchdata/saved_search_re_run_url}"
			id="searchresultscontrol{$hpSectionId}" 
			class="wcr-search mainsearchresultscontrol"
			>
			<!-- 
				NEW Search Architecture...
			
				This textarea contains the complete search setup as JSON 
				(communicated forward and back between server &amp; client)
			-->
			<textarea style="display:none;" name="searchSetupModel"><xsl:value-of select="/webcenter_page/searchdata/searchsetupdatajson"/></textarea>
			
			
			<!-- Loading indicator -->
			<div class="loadingcontainer"><center><img src="images/loaderTransparent.gif" alt="{Lang:getStr(&lk;,'LOADINGINPROGRESS')}"/></center></div>
			
			<div class="assetViewDropdownContainer">
				<!-- Place to put the dropdown for switching the asset browser view -->
				<!-- Note: this place will not be used if we have space in the header -->
			</div>
			
			<!-- 
				# Placeholders #
				
				In these placeholders the functionality will be initialized.
				
				The dashboard will then later move these placeholders to different places inside the dashboard.
				
				FUTURE: Simply generate these placeholders in the code. There is no real reason why this should happen in xsl... 
				(makes it less flexible -> can only have the component once (only one placeholder) and cannot easily be re-used on different search pages => have to duplicate the placeholders to different xsl files)
			-->
			<xsl:if test="not(/webcenter_page/search_re_run)">
				<div class="searchplaceholders" style="display:none;">
					
					<!-- Placeholder for left-tree panel (Asset Browser) -->
					<div class="assetViewTreeContainer">
						<!-- Note: even before initialization, this will keep enough white space. -->
						<xsl:if test="/webcenter_page/search_criteria/displayPreferences/cascading_attribute_trees/treeElem">
							<xsl:if test="/webcenter_page/search_criteria/displayPreferences/SelectTreePanelWidth">
								<xsl:attribute name="style">width: <xsl:value-of select="/webcenter_page/search_criteria/displayPreferences/SelectTreePanelWidth"/>px;min-width: <xsl:value-of select="/webcenter_page/search_criteria/displayPreferences/SelectTreePanelWidth"/>px;</xsl:attribute>
							</xsl:if>
						</xsl:if>
					</div>
			     	
			     	<!-- Placeholder for the asset browser image panel -->
			     	<div class="searchassetbrowserImageArea">
						<!-- HERE WE WILL PUT THE ASSET BROWSER IMAGES -->
					</div>
					
					<!-- Placeholder for the cart -->
					<!-- show cart if requested and if we can do something with it (if we have actions) -->
					<xsl:if test="(/webcenter_page/search_criteria/displayPreferences/chkbox_ShowCart='1') and $showActions='1'">
						<div class="cartDisplay">
							<!-- pass the settings for the create project link -->
							<!-- FUTURE: get rid of this => this is already available on the JavaScript side in the object model!! -->
							<xsl:attribute name="data-createprojectsettings"><xsl:call-template name="ActionsGetCreateProjectFromSelectedConfig"/></xsl:attribute>
						</div>
					</xsl:if>
					
					<!-- Placeholder for the attribute category that we need to load -->
					<table>
					 	<tbody class="attributecategorycells">
					 	
					 		<!-- HERE we will put some hidden cells to attach the Attribute Category object, which will handle cascading dropdowns -->
					 		
			          	</tbody>
					</table>
					
					<!-- Placeholder for the top parameter panel -->
					<xsl:call-template name="searchResultsSavedSearchParms"/>
					
				</div>
			</xsl:if>
		
			<!-- 
				This table contains the actual search results (+ dashboard).
				
				.searchloadingarea => only becomes visible when loaded
			 -->
			<div class="searchloadingarea" style="display:none">
		      <div class="searchdashboardcontainer">
		   	  	
		          <div width="100%" class="searchreruncontainer" data-additionalfielddata="{/webcenter_page/searchdata/resultsjson/additionaldata}">
			          <xsl:choose>
			          	<xsl:when test="/webcenter_page/result_count=0">
					      	<xsl:call-template name="searchNoResultsMessage"/>
			            </xsl:when>
			            <xsl:when test="/webcenter_page/search_error_message">
			              <table width="100%" cellspacing="0" cellpadding="0" border="0">
						    <xsl:call-template name="searchErrorMessage">
						  	  <xsl:with-param name="error" select="/webcenter_page/search_error_message"/>
						    </xsl:call-template>
						  </table>		      
			            </xsl:when>
			            <xsl:otherwise>
							<form name="{$actionFormName}" method="post" action="dodocsearchactions.jsp" class="searchresultsactionform">
								<input type="hidden" name="actionVal" value=""/>
								<xsl:call-template name="SourcePageGenerateInputs">
								</xsl:call-template>
								<input type="hidden" name="actionDocVerID" value=""/>
								<input type="hidden" name="actionDocID" value=""/>
								<input type="hidden" name="projectID" value=""/>
								<xsl:if test="/webcenter_page/is_in_dialog">
									<input type="hidden" id="{$hpSectionId}_isInDialogFlag" name="{$hpSectionId}_isInDialogFlag" value="1"/>
								</xsl:if> 
	
								<xsl:choose>
									<xsl:when test="results_style='grid'">
										<!-- Grid style -->
										<xsl:call-template name="GridStyleResultsTable">
											<xsl:with-param name="showActions" select="$showActions"/>
											<xsl:with-param name="noHyperlinks" select="$noHyperlinks"/>
											<xsl:with-param name="stickyActions" select="$stickyActions"/>
											<xsl:with-param name="withShowHideThumbnailsButton" select="$withShowHideThumbnailsButton"/>
											
										</xsl:call-template>
									</xsl:when>
									<xsl:when test="results_style='card'">
										<!-- Card style -->
										<xsl:call-template name="CardStyleResultsTable">
											<xsl:with-param name="showActions" select="$showActions"/>
											<xsl:with-param name="noHyperlinks" select="$noHyperlinks"/>
											<xsl:with-param name="stickyActions" select="$stickyActions"/>
											<xsl:with-param name="withShowHideThumbnailsButton" select="$withShowHideThumbnailsButton"/>
										</xsl:call-template>
									</xsl:when>
									<xsl:otherwise>
										<!-- List style -->
										<xsl:call-template name="ListStyleResultsTable">
											<xsl:with-param name="showActions" select="$showActions"/>
											<xsl:with-param name="noHyperlinks" select="$noHyperlinks"/>
											<xsl:with-param name="stickyActions" select="$stickyActions"/>
											<xsl:with-param name="withShowHideThumbnailsButton" select="$withShowHideThumbnailsButton"/>
										</xsl:call-template>
									</xsl:otherwise>
								</xsl:choose>
							</form>
					    </xsl:otherwise>
		              </xsl:choose>
		          </div>
			  </div>	
            </div>
		</div>
	</xsl:template>
	
	<!-- The results table for Grid style -->
	<xsl:template name="GridStyleResultsTable">
		<xsl:param name="showActions"/>
		<xsl:param name="withShowHideThumbnailsButton"/>
		<xsl:param name="noHyperlinks"/>
		<xsl:param name="stickyActions"/>

		<!-- parameters of this layout -->
		<xsl:variable name="colsPerPage" select="number(/webcenter_page/cols_per_page)"/>
		<xsl:variable name="rowsPerPage" select="number(/webcenter_page/rows_per_page)"/>
		<xsl:variable name="showThumbnails" select="number(/webcenter_page/show_thumbnails)"/>
		<xsl:variable name="resultsStyle" select="/webcenter_page/results_style"/>
		
		<!-- table component -->
		<!-- data-checkbox-selector="input[name='selectedDocs']" -->
		<!-- ^^ above does not work with tables in tables (which is used in search) + does not work with "grid" -->
        <div class="wcr-table no-margin wcr161_apply_floatingscroll" 
        	data-init-whensearchready="component/table/Table">
	        <div class="wcr-table-filter">
	            <div>
   	            	<xsl:attribute name="class">wcr-table-actions-row <xsl:if test="not($stickyActions = 'true')">no-sticky-actions</xsl:if></xsl:attribute>
	            	<div class="quick-filter">
		            	<!-- sorting dropdown -->
		            	<xsl:call-template name="SearchResultsSortByDropdown"/>
	            	</div>
	            	<!-- actions -->
	            	<xsl:call-template name="ResultsTableActionMenu">
	            		<xsl:with-param name="showActions" select="$showActions"/>
	            		<xsl:with-param name="showSelectAction" select="true()"/>
	            	</xsl:call-template>
	            </div>
	        </div>
	        
	        <!-- actual table -->
	        <div class="wcr-table-section"><!-- begin of table section -->
				<xsl:variable name="gridLayoutSubType">
					<xsl:choose>
						<xsl:when test="number($colsPerPage) &lt;= number(5)">
							<xsl:value-of select="'narrow'"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="'wide'"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
		        	
				<table class="ordtable searchresultstable gridview" width="100%"
					data-showThumbnails="{$showThumbnails}"
					data-resultsStyle="{$resultsStyle}"
					data-resultsStyleSubType="{$gridLayoutSubType}"
					data-noHyperLinks="{$noHyperlinks}">
					
					<!-- show the result in a grid -->
					<tbody>
						<xsl:for-each select="search_result_id_list/search_result_id">
							<xsl:call-template name="GridStyleResultsTableCell">
								<xsl:with-param name="colsPerPage" select="$colsPerPage"/>
								<xsl:with-param name="showThumbnails" select="$showThumbnails"/>
								<xsl:with-param name="showActions" select="$showActions"/>
								<xsl:with-param name="noHyperlinks" select="$noHyperlinks"/>
							</xsl:call-template>
						</xsl:for-each>
					</tbody>
				</table>
  			</div><!-- end of table section -->
  			
			<!-- footer of the table -->
			<xsl:call-template name="ResultsTableFooter">
				<xsl:with-param name="withShowHideThumbnailsButton" select="$withShowHideThumbnailsButton"/>
			</xsl:call-template>
			
  		</div><!-- end of table component -->
	</xsl:template>
	
	<!-- a cell in grid style -->
	<xsl:template name="GridStyleResultsTableCell">
		<xsl:param name="colsPerPage"/>
		<xsl:param name="showThumbnails"/>
		<xsl:param name="showActions"/>
		<xsl:param name="noHyperlinks"/>

		<xsl:variable name="pageIndex" select="position()"/>
		<xsl:variable name="resultIndex" select="position() + number(/webcenter_page/start_search_id) - 1"/>
		<xsl:variable name="docVerSearchResult" select="key('docVerSearchResultKey', .)"/>
		<xsl:variable name="docSearchResult" select="$docVerSearchResult/doc_search_result"/>
		<xsl:variable name="urlKey" select="$docSearchResult/document"/>
		<xsl:variable name="colCount1" select="floor(number(99) div number($colsPerPage))"/>
		<xsl:variable name="colCount2" select="$colCount1 + (99 mod number($colsPerPage))"/>
	    <xsl:variable name="showSimpleGUI" select="/webcenter_page/showSimpleGUI"/>
	    
	    <xsl:variable name="sourcePageSpecific"><xsl:call-template name="SourcePageCalculateWithIndex">
			<xsl:with-param name="resultIndex" select="$resultIndex"/>
		</xsl:call-template></xsl:variable>
	    
		<xsl:variable name="thumbhrefValue">
			<xsl:call-template name="searchDocViewHrefValue">
				<xsl:with-param name="docVerID" select="$docVerSearchResult/@id"/>
 				<xsl:with-param name="sourcePage" select="$sourcePageSpecific"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="hrefValue">
			<xsl:choose>
				<xsl:when test="$showSimpleGUI='1'"><xsl:value-of select="$thumbhrefValue"/></xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="searchDocDetailsHrefValue">
						<xsl:with-param name="docVerID" select="$docVerSearchResult/@id"/>
						<xsl:with-param name="docSearchIndex" select="$resultIndex"/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:if test="(number($pageIndex)-1) mod number($colsPerPage)=0">
			<xsl:choose>
				<xsl:when test="((number($pageIndex)-1) div number($colsPerPage)) mod 2 = 1">
 					<xsl:text disable-output-escaping="yes">&lt;tr class="alt"&gt;</xsl:text>
 				</xsl:when>
 				<xsl:otherwise>
 					<xsl:text disable-output-escaping="yes">&lt;tr&gt;</xsl:text>
 				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
		
		<xsl:variable name="isNarrowLayout">
			<xsl:choose>
				<xsl:when test="number($colsPerPage) &lt;= number(5)">
					<xsl:value-of select="true()"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="false()"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		<xsl:variable name="labelsShow">
			<xsl:choose>
				<xsl:when test="/webcenter_page/search_criteria/displayPreferences/chkbox_ShowLabels='1'">
					<xsl:value-of select="true()"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="false()"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		<!-- how to align: centered when no labels are shown, otherwise left -->
		<xsl:variable name="valueAlignment">  
			<xsl:choose>
				<xsl:when test="$labelsShow = 'true'">
					<xsl:text>left</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>center</xsl:text>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		<!-- All cells in the table divide the total width equally... -->
		<xsl:variable name="cellwidth" select="concat(floor(100 div $colsPerPage),'%')"/>
		
		<!-- Only show the item if we were able to retrieve the details. This might happen if it was deleted after the crawl. -->
		<xsl:if test="$docVerSearchResult">
		
			<xsl:variable name="isDocumentLockedVal">
				<xsl:choose>
					<xsl:when test="string-length($docSearchResult/document/checkout_owner_id) > 0">
						<xsl:value-of select="'1'" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="'0'" />
					</xsl:otherwise>
				</xsl:choose>
			</xsl:variable>
				
			<!-- Narrow layout = 1-5 columns -->
			<xsl:if test="$isNarrowLayout = 'true'">
				<td align="left" width="{$cellwidth}">	
					<table border="0" cellspacing="0" cellpadding="5" height="100%" class="searchresultsrow">
						<!-- 
						  New Search Architecture...
						  All data for this item gets passed to the JavaScript side. 
						-->
						<xsl:attribute name="data-rowdisplaydata">
							<xsl:value-of select="/webcenter_page/searchdata/resultsjson/result[@id=($docVerSearchResult/@id)]"/>
						</xsl:attribute>
						<!-- 
						  Some values are currently still generated and needed in the xsl.
						  To not generate them twice, we will keep those values in the xsl for now and simply pass them to the JS side.
						-->
						<xsl:attribute name="data-xslgen-thumbhref"><xsl:value-of select="$thumbhrefValue"/></xsl:attribute>
						<!-- end -->
						
						<tr>
							<!-- selection toggle -->
							<td class="td-checkbox">
								<xsl:call-template name="ToggleThisCol">
									<xsl:with-param name="docVerID" select="$docVerSearchResult/@id"/>
									<xsl:with-param name="docName" select="$docSearchResult/document/name"/>  <!-- HADW 5 Mar 2012 TO DO Encoding -->
									<xsl:with-param name="projectId" select="$docVerSearchResult/project_list/project[1]/@id"/>
									<xsl:with-param name="documentId" select="$docSearchResult/document/@id"/>
									<xsl:with-param name="isLocked" select="$isDocumentLockedVal"/>
								</xsl:call-template>
							</td>
			
							<td><img border="0" src="images/clearpixel.gif" alt="" width="5" height="1"/></td>		<!-- white space -->
							
							<!-- Thumbnail -->
							<xsl:if test="$showThumbnails = 1">
								<td align="left" valign="middle" width="56" class="datacell" data-fieldid="thumbnail">
									<!-- the content will be put here... -->
								</td>
							</xsl:if>
			
							<td><img border="0" src="images/clearpixel.gif" alt="" width="5" height="1"/></td>	<!-- white space -->														
							
							<td valign="top" align="left" class="widecell">
								<!-- Document Name + basic information + actions -->
								<xsl:call-template name="GridStyleResultsTableCellContentDocDetails">
									<xsl:with-param name="hrefValue" select="$hrefValue"/>
									<xsl:with-param name="colsPerPage" select="$colsPerPage" />
									<xsl:with-param name="labelAlign" select="'left'"/>
									<xsl:with-param name="valueAlign" select="'left'"/>
	 								<xsl:with-param name="sourcePageSpecific" select="$sourcePageSpecific"/>
	 								<xsl:with-param name="showActions" select="$showActions"/>
	 								<xsl:with-param name="noHyperlinks" select="$noHyperlinks"/>
								</xsl:call-template>
							</td>
						</tr>
					</table>
				</td>
			</xsl:if>
			<!-- Wider layout = 6+ columns -->
			<xsl:if test="$isNarrowLayout = 'false'"> 	
				<td align="center" valign="top" name="gridCell" width="{$cellwidth}">
					<xsl:choose>
						<xsl:when test="position() mod number($colsPerPage)=0">
							<xsl:attribute name="width"><xsl:value-of select="number($colCount2)"/>%</xsl:attribute>
						</xsl:when>
						<xsl:otherwise>
							<xsl:attribute name="width"><xsl:value-of select="number($colCount1)"/>%</xsl:attribute>
						</xsl:otherwise>
					</xsl:choose>
					<table border="0" valign="top" cellspacing="0" cellpadding="0" class="searchresultsrow">
						<!-- 
					      New Search Architecture...
					      All data for this item gets passed to the JavaScript side. 
					    -->
					    <xsl:attribute name="data-rowdisplaydata">
					      <xsl:value-of select="/webcenter_page/searchdata/resultsjson/result[@id=($docVerSearchResult/@id)]"/>
					    </xsl:attribute>
					    <!-- 
						  Some values are currently still generated and needed in the xsl.
						  To not generate them twice, we will keep those values in the xsl for now and simply pass them to the JS side.
						-->
						<xsl:attribute name="data-xslgen-thumbhref"><xsl:value-of select="$thumbhrefValue"/></xsl:attribute>
					    <!-- end -->
						<tr valign="top">
							<xsl:if test="$showThumbnails = 1">
								<td align="center" valign="top" class="datacell" data-fieldid="thumbnail">
									<!-- the content will be put here... -->
								</td>
							</xsl:if>
						</tr>
						<tr>
							<td align="center">
								<xsl:call-template name="ToggleThisCol">
									<xsl:with-param name="docVerID" select="$docVerSearchResult/@id"/>
									<xsl:with-param name="docName" select="$docSearchResult/document/name"/>  <!-- HADW 5 Mar 2012 TO DO Encoding -->
									<xsl:with-param name="projectId" select="$docVerSearchResult/project_list/project[1]/@id"/>
									<xsl:with-param name="documentId" select="$docSearchResult/document/@id"/>
									<xsl:with-param name="isLocked" select="$isDocumentLockedVal"/>
								</xsl:call-template>
							</td>
						</tr>
						<tr>
							<td valign="top" align="center">
								<!-- All details -->
								<xsl:call-template name="GridStyleResultsTableCellContentDocDetails">
									<xsl:with-param name="hrefValue" select="$hrefValue"/>
									<xsl:with-param name="colsPerPage" select="$colsPerPage" />	
									<xsl:with-param name="labelAlign" select="'right'"/>	
									<xsl:with-param name="valueAlign" select="$valueAlignment"/>
	 								<xsl:with-param name="sourcePageSpecific" select="$sourcePageSpecific"/>
	 								<xsl:with-param name="showActions" select="$showActions"/>
	 								<xsl:with-param name="noHyperlinks" select="$noHyperlinks"/>
								</xsl:call-template>
							</td>
						</tr>
					</table>
				</td>
			</xsl:if> 
		</xsl:if>
		<xsl:if test="position()=last() and (position() mod number($colsPerPage)!=0)">
			<td>
				<xsl:attribute name="colspan">
					<xsl:value-of select="number($colsPerPage) - (position() mod number($colsPerPage))"/>
				</xsl:attribute>
			</td>
		</xsl:if>
		<xsl:if test="position() mod number($colsPerPage)=0 or position()=last()">
			<xsl:text disable-output-escaping="yes">&lt;/tr &gt;</xsl:text>
		</xsl:if>	
	</xsl:template>
	
	

	<!-- template that controls display document details in the grid - @author HADW -->
 	<xsl:template name="GridStyleResultsTableCellContentDocDetails">
		<xsl:param name="hrefValue" />
		<xsl:param name="colsPerPage" select="10"/><!-- Used for "cutting" the description, but not useful for card search -->
		<xsl:param name="labelAlign" />	
		<xsl:param name="valueAlign" select="'left'" />
		
 		<xsl:param name="sourcePageSpecific" select="''"/>
 		<xsl:param name="showActions" select="true()"/>
		<xsl:param name="showContentBelowLabels" select="false()"/>
		<xsl:param name="noHyperlinks"/>
		
	    <xsl:variable name="docVerSearchResult" select="key('docVerSearchResultKey', .)"/>
	    <xsl:variable name="docSearchResult" select="$docVerSearchResult/doc_search_result"/>
		<xsl:variable name="urlKey" select="$docSearchResult/document"/>
		<xsl:variable name="owner" select="$urlKey/checkout_owner_id"/>
		<xsl:variable name="showSimpleGUI" select="/webcenter_page/showSimpleGUI"/>
		<xsl:variable name="projectID" select="$docVerSearchResult/project_list/project[1]/@id"/>
		<xsl:variable name="docTypeID" select="$docVerSearchResult/doctype_id"/>
		<xsl:variable name="docVerID" select="$docVerSearchResult/@id"/>
		
		<xsl:variable name="showLabels">
			<xsl:choose>
				<xsl:when test="/webcenter_page/search_criteria/displayPreferences/chkbox_ShowLabels='1'"><xsl:value-of select = "true()"/></xsl:when>
				<xsl:otherwise><xsl:value-of select = "false()"/></xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		<div>
			
			<div>
				<xsl:attribute name="class"><xsl:text>searchgridinformationtable </xsl:text><xsl:choose>
					<!-- How to display? "showcontentbelowlabel" -->
					<xsl:when test="$showContentBelowLabels"><xsl:text>showcontentbelowlabel</xsl:text></xsl:when>
					
					<!-- How to display? "showastable" -->
					<xsl:otherwise><xsl:text>showastable</xsl:text></xsl:otherwise>
				</xsl:choose></xsl:attribute>
				<!-- Name row -->
				<div class="gridinforow">
					<div class="gridinfolabel" align="{$labelAlign}">
						<!-- Name header -->
						<xsl:call-template name="searchResultsGridLabel">
							<xsl:with-param name="columnName" select="'db_name'"/>
							<xsl:with-param name="langKey" select="'NAME'"/>
						</xsl:call-template>
					</div>	
					
					<!-- Name & locked -->
					<div class="gridinfocontent" align="{$valueAlign}">
						<span style="width: 100%; text-align: left; vertical-align: baseline;"> 
							<xsl:choose>
								<xsl:when test="$noHyperlinks = 1">
									<xsl:value-of select = "$urlKey/name"/>									
								</xsl:when>
								<xsl:otherwise>
									<a>
										<xsl:attribute name="href"><xsl:value-of select="$hrefValue"/></xsl:attribute>
										<xsl:value-of select = "$urlKey/name"/>
								  	</a>
								</xsl:otherwise>
							</xsl:choose>
							<xsl:if test="string($owner)">
							  	<i class="icon icon-WCR_Actions-Lock12" title="{Lang:getStr(&lk;,'DOC_CHECKED_OUT')}"></i>	
						  	</xsl:if>
						</span>												
					</div>
				</div>
				
				<!-- 
					Write all the rows with information...
				-->
				
				<xsl:for-each select="/webcenter_page/searchdata/columns/column">
					<xsl:sort data-type="number" order="ascending" select="@sequence"/>
					<xsl:variable name="fieldid" select="@id"/>
					
					<div class="gridinforow">
						<div class="gridinfolabel" align="{$labelAlign}">
							<xsl:call-template name="searchResultsGridLabel">
								<xsl:with-param name="columnName" select="$fieldid"/>
								<xsl:with-param name="fullString" select="@label"/>
							</xsl:call-template>
						</div>	
						<div class="gridinfocontent" align="{$valueAlign}">
							<!-- Display using javascript... -->
							<div class="datacell" data-fieldid="{$fieldid}">
								<!-- the content will be put here... -->
							</div>
						</div>
					</div>
                    
				</xsl:for-each>
				
				<!-- 
					Write the action menu row
				-->
				<xsl:if test="$showActions='1' and not($docSearchResult/document/is_url = '1')">
					<div class="gridinforow" align="{$valueAlign}">
						<div class="gridinfolabel" valign="top" align="{$labelAlign}">
							<!-- Actions: empty cell for label -->
						</div>	
						<!-- Document Operations -->
						<div class="gridinfocontent" align="{$valueAlign}" valign="middle">
							<xsl:call-template name="WriteDocumentActionLinks" >
								<xsl:with-param name="docSearchDisplayPrefsRoot" select="/webcenter_page/search_criteria/displayPreferences"/>
								<xsl:with-param name="docVersionSearchResultRoot" select="$docVerSearchResult"/>
								<xsl:with-param name="sourcePageSpecific" select="$sourcePageSpecific"/>
							</xsl:call-template>
						</div>
					</div> 
				</xsl:if>				
			</div>
		</div>
  	</xsl:template>
	
	<!-- the results table for list style -->
	<xsl:template name="ListStyleResultsTable">
		<xsl:param name="showActions"/>
		<xsl:param name="noHyperlinks"/>
		<xsl:param name="stickyActions"/>
		<xsl:param name="withShowHideThumbnailsButton"/>
		
		<!-- parameters of this layout -->
		<xsl:variable name="showThumbnails" select="number(/webcenter_page/show_thumbnails)"/>
		<xsl:variable name="resultsStyle" select="/webcenter_page/results_style"/>

		<!-- table component -->
         <div class="wcr-table no-margin wcr161_apply_floatingscroll" data-init-whensearchready="component/table/Table" data-checkbox-selector="input[name='selectedDocs']">
         	<!-- Check whether the action menu bar needs to be shown. Do we have actions to display? + Do we display actions? -->
         	<xsl:variable name="hasTableBarActionsInMenu"><xsl:call-template name="ResultTableActionMenuHasMenuItems"/></xsl:variable>
         	<xsl:variable name="showTableActionBar" select="$showActions='1' and $hasTableBarActionsInMenu = 'true'"/>
         
	        <xsl:if test="$showTableActionBar='1'">
		        <div class="wcr-table-filter">
		            <div>
       	            	<xsl:attribute name="class">wcr-table-actions-row no-filter <xsl:if test="not($stickyActions = 'true')">no-sticky-actions</xsl:if></xsl:attribute>
		            
		            	<!-- actions -->
		            	<xsl:call-template name="ResultsTableActionMenu">
		            		<xsl:with-param name="showActions" select="true()"/>
		            		<xsl:with-param name="showSelectAction" select="false()"/>
	            		</xsl:call-template>
		            </div>
		        </div>
	        </xsl:if>
	        
	        <!-- actual table -->
	        <div class="wcr-table-section"><!-- begin of table section -->
				<table class="ordtable searchresultstable" width="100%" id="searchResultsTable"
					data-showThumbnails="{$showThumbnails}"
					data-resultsStyle="{$resultsStyle}"
					data-noHyperLinks="{$noHyperlinks}">
					
					<!-- Table header -->
					<thead>
						<!-- Column headers -->
						<tr class="searchResultsHeader">
							<!-- Toggle all header -->
							<th class="td-checkbox">
								<input type="checkbox" name="selectAllDoc" data-toggle-all="1"/>
							</th>
							
							<!-- Thumbnail -->							
							<!-- Document Name -->
							<xsl:call-template name="ThumbnailNameHeader">
								<xsl:with-param name="showThumbnails" select="$showThumbnails"/>
							</xsl:call-template>
						
							<!-- All other headers... -->
							<xsl:for-each select="/webcenter_page/searchdata/columns/column">
								<xsl:sort data-type="number" order="ascending" select="@sequence"/>
								
								<xsl:call-template name="SearchResultsColumnHeader">
									<xsl:with-param name="columninfo" select="."/>
								</xsl:call-template>
								
							</xsl:for-each>
						</tr>
					</thead>
					
					<!-- Table contents -->
					<tbody>
						<xsl:for-each select="search_result_id_list/search_result_id">
							<xsl:call-template name="ListStyleResultsTableContentRow">
								<xsl:with-param name="showThumbnails" select="$showThumbnails"/>
								<xsl:with-param name="showActions" select="$showActions"/>
								<xsl:with-param name="noHyperlinks" select="$noHyperlinks"/>
							</xsl:call-template>
						</xsl:for-each>
					</tbody>
				</table>
			</div><!-- end of table section -->
			
			<!-- footer of the table -->
			<xsl:call-template name="ResultsTableFooter">
				<xsl:with-param name="withShowHideThumbnailsButton" select="$withShowHideThumbnailsButton"/>
			</xsl:call-template>
			
  		</div><!-- end of table component -->
	</xsl:template>
	
	<!-- template that controls the generation of a document link in a row format -->
	<xsl:template name="ListStyleResultsTableContentRow">
		<xsl:param name="showThumbnails"/>
		<xsl:param name="showActions"/>
		<xsl:param name="noHyperlinks"/>
		
		<xsl:variable name="resultIndex" select="position() + number(/webcenter_page/start_search_id) - 1"/>
		<xsl:variable name="docVerSearchResult" select="key('docVerSearchResultKey', .)"/>
		<xsl:variable name="docSearchResult" select="$docVerSearchResult/doc_search_result"/>
		<xsl:variable name="projectList" select="$docVerSearchResult/project_list"/>
	    <xsl:variable name="showSimpleGUI" select="/webcenter_page/showSimpleGUI"/>
	    
	    <xsl:variable name="sourcePageSpecific"><xsl:call-template name="SourcePageCalculateWithIndex">
			<xsl:with-param name="resultIndex" select="$resultIndex"/>
		</xsl:call-template></xsl:variable>

		<xsl:variable name="thumbhrefValue">
			<xsl:call-template name="searchDocViewHrefValue">
				<xsl:with-param name="docVerID" select="$docVerSearchResult/@id"/>
 				<xsl:with-param name="sourcePage" select="$sourcePageSpecific"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="hrefValue">
			<xsl:choose>
				<xsl:when test="$showSimpleGUI='1'"><xsl:value-of select="$thumbhrefValue"/></xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="searchDocDetailsHrefValue">
						<xsl:with-param name="docVerID" select="$docVerSearchResult/@id"/>
						<xsl:with-param name="docSearchIndex" select="$resultIndex"/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		<xsl:variable name="approval_cycle_state" select="$docVerSearchResult/approval_cycle_state"/>
		<xsl:variable name="approval_state_id"><xsl:value-of select="$docVerSearchResult/approval_state"/></xsl:variable>
		
		<xsl:variable name="approval_cycle_started">
			<xsl:choose>
				<xsl:when test="$approval_cycle_state='cycle_started'">1</xsl:when>
				<xsl:otherwise>0</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		<!-- If the current user is a PM of the Document's parent Project -->
	    <xsl:variable name="isProjectManager">
			<xsl:choose>
				<xsl:when test="$docVerSearchResult/is_project_manager_current_project">1</xsl:when>
				<xsl:otherwise>0</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		
		<!-- Only show the row if we were able to retrieve the details. This might happen if it was deleted before the crawl. -->
		<xsl:if test="$docVerSearchResult">
		
			<xsl:variable name="isDocumentLockedVal">
				<xsl:choose>
					<xsl:when test="string-length($docSearchResult/document/checkout_owner_id) > 0">
						<xsl:value-of select="'1'" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="'0'" />
					</xsl:otherwise>
				</xsl:choose>
			</xsl:variable>
			
			<tr>
				<!-- 
				  New Search Architecture...
				  All data for this row gets passed to the JavaScript side. 
				-->
				<xsl:attribute name="data-rowdisplaydata">
					<xsl:value-of select="/webcenter_page/searchdata/resultsjson/result[@id=($docVerSearchResult/@id)]"/>
				</xsl:attribute>
				<!-- 
				  Some values are currently still generated and needed in the xsl.
				  To not generate them twice, we will keep those values in the xsl for now and simply pass them to the JS side.
				-->
				<xsl:attribute name="data-xslgen-thumbhref"><xsl:value-of select="$thumbhrefValue"/></xsl:attribute>
				<!-- end -->
			
				<xsl:attribute name="class">searchresultsrow<xsl:if test="position() mod 2 = 0"> alt</xsl:if></xsl:attribute>
				
				<!-- First col, show the toggle selection -->
				<td class="td-checkbox">
					<xsl:call-template name="ToggleThisCol">
						<xsl:with-param name="docVerID" select="$docVerSearchResult/@id"/>
						<xsl:with-param name="docName" select="$docSearchResult/document/name"/>  <!-- HADW 5 Mar 2012 TO DO Encoding -->
						<xsl:with-param name="projectId" select="$docVerSearchResult/project_list/project[1]/@id"/>
						<xsl:with-param name="documentId" select="$docSearchResult/document/@id"/>
						<xsl:with-param name="isLocked" select="$isDocumentLockedVal"/>
					</xsl:call-template>
				</td>
												
				<!-- Thumbnail & Name + Document Operations -->
				<td class="row-actions-cell">
				    <xsl:if test="$showThumbnails = 1">
					  <xsl:attribute name="colspan">2</xsl:attribute>
				    </xsl:if>
					
					<!-- Thumbnail & Name -->
					<span class="actioncell-content">
						<!-- Can we get rid of this table? It has two cells: Thumbnail + Name -->
						<table><tr>
						<xsl:call-template name="DisplayThumbnailName">
							<xsl:with-param name="showThumbnails" select="$showThumbnails"/>
							<xsl:with-param name="hrefValue" select="$hrefValue"/>
							<xsl:with-param name="urlKeyName" select="$docSearchResult/document"/>
							<xsl:with-param name="docVerID" select="$docVerSearchResult/@id"/>
							<xsl:with-param name="projectID" select="$docVerSearchResult/project_list/project[1]/@id"/>
							<xsl:with-param name="checkoutOwnerUserID" select="$docSearchResult/document/checkout_owner_id"/>
							<xsl:with-param name="docTypeID" select="$docVerSearchResult/doctype_id"/>
							<xsl:with-param name="noHyperlinks" select="$noHyperlinks"/>
							
							<xsl:with-param name="useThumbnailCellHtml" select="'1'"/>
							<xsl:with-param name="thumbnailCellHtml">
								<td valign="middle" width="56" class="datacell" data-fieldid="thumbnail">
									<!-- the content will be put here... -->
								</td>
							</xsl:with-param>
						</xsl:call-template>
						</tr></table>
					</span>
				
					<!-- Document Operations -->
					<xsl:if test="$showActions='1' and not($docSearchResult/document/is_url = '1')">
						<xsl:call-template name="WriteDocumentActionLinks" >
							<xsl:with-param name="docSearchDisplayPrefsRoot" select="/webcenter_page/search_criteria/displayPreferences"/>
							<xsl:with-param name="docVersionSearchResultRoot" select="$docVerSearchResult"/>
							<xsl:with-param name="sourcePageSpecific" select="$sourcePageSpecific"/>
						</xsl:call-template>
					</xsl:if>
				</td>					

				<xsl:for-each select="/webcenter_page/searchdata/columns/column">
					<xsl:sort data-type="number" order="ascending" select="@sequence"/>
					
					<xsl:call-template name="SearchResultsCell">
						<xsl:with-param name="id" select="./@id"/>
						<xsl:with-param name="typeclass" select="./@typeclass"/>
					</xsl:call-template>

				</xsl:for-each>
			</tr>
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="CardStyleResultsTable">
		<xsl:param name="showActions"/>
		<xsl:param name="withShowHideThumbnailsButton"/>		
		<xsl:param name="noHyperlinks"/>
		<xsl:param name="stickyActions"/>
		
		<!-- parameters of this layout -->
		<xsl:variable name="showThumbnails" select="number(/webcenter_page/show_thumbnails)"/>
		<xsl:variable name="resultsStyle" select="/webcenter_page/results_style"/>
		
		<!-- table component -->
		<!-- note: disable "data-click-to-select" since card style has it's own functionality for that -->
        <div class="wcr-table no-margin wcr161_apply_floatingscroll" 
        	data-init-whensearchready="component/table/Table"
        	data-itemrow-selector=".card"
        	data-click-to-select="0"
        	>
	        <div class="wcr-table-filter">
	            <div>	
	                <xsl:attribute name="class">wcr-table-actions-row <xsl:if test="not($stickyActions = 'true')">no-sticky-actions</xsl:if></xsl:attribute>
	            	<div class="quick-filter">
		            	<!-- sorting dropdown -->
		            	<xsl:call-template name="SearchResultsSortByDropdown"/>
	            	</div>
	            	<!-- actions -->
	            	<xsl:call-template name="ResultsTableActionMenu">
	            		<xsl:with-param name="showActions" select="$showActions"/>
	            		<xsl:with-param name="showSelectAction" select="true()"/>
	            	</xsl:call-template>
	            </div>
	        </div>
	        
	        <!-- actual table -->
	        <div class="wcr-table-section"><!-- begin of table section -->
				<!-- CARD VIEW -->
				<div class="card-grid searchresultstable" data-init-whensearchready="component/cards/CardGridControl"
					data-showThumbnails="{$showThumbnails}"
					data-resultsStyle="{$resultsStyle}"
					data-noHyperLinks="{$noHyperlinks}">
					
					<!-- In a document source, clicking a card will select -->
					<xsl:attribute name="data-selectbythumbnail"><xsl:if test="not($showActions='1')">1</xsl:if></xsl:attribute>
					
					<xsl:for-each select="search_result_id_list/search_result_id">
						<xsl:call-template name="CardStyleResultsTableCard">
							<xsl:with-param name="showThumbnails" select="$showThumbnails"/>
							<xsl:with-param name="withShowHideThumbnailsButton" select="$withShowHideThumbnailsButton"/>
							<xsl:with-param name="showActions" select="$showActions"/>
							<xsl:with-param name="noHyperlinks" select="$noHyperlinks"/>
						</xsl:call-template>
					</xsl:for-each>
				</div>
			</div><!-- end of table section -->
			
			<!-- footer of the table -->
			<xsl:call-template name="ResultsTableFooter">
				<xsl:with-param name="withShowHideThumbnailsButton" select="false()"/>
			</xsl:call-template>
			
  		</div><!-- end of table component -->
	</xsl:template>
	
	
	<xsl:template name="CardStyleResultsTableCard">
		<xsl:param name="showThumbnails"/>
		<xsl:param name="showActions"/>
		<xsl:param name="withShowHideThumbnailsButton"/>
		<xsl:param name="noHyperlinks"/>
	
		<xsl:variable name="resultIndex" select="position() + number(/webcenter_page/start_search_id) - 1"/>
	    <xsl:variable name="docVerSearchResult" select="key('docVerSearchResultKey', .)"/>
	    <xsl:variable name="docSearchResult" select="$docVerSearchResult/doc_search_result"/>
		<xsl:variable name="urlKey" select="$docSearchResult/document"/>
		<xsl:variable name="owner" select="$urlKey/checkout_owner_id"/>
		<xsl:variable name="showSimpleGUI" select="/webcenter_page/showSimpleGUI"/>
		<xsl:variable name="projectID" select="$docVerSearchResult/project_list/project[1]/@id"/>
		<xsl:variable name="docTypeID" select="$docVerSearchResult/doctype_id"/>
		<xsl:variable name="docVerID" select="$docVerSearchResult/@id"/>
		<xsl:variable name="urlKeyName" select="$docSearchResult/document"/>
		
		<xsl:variable name="sourcePageSpecific"><xsl:call-template name="SourcePageCalculateWithIndex">
			<xsl:with-param name="resultIndex" select="$resultIndex"/>
		</xsl:call-template></xsl:variable>
		
		<xsl:variable name="thumbhrefValue">
			<xsl:call-template name="searchDocViewHrefValue">
				<xsl:with-param name="docVerID" select="$docVerSearchResult/@id"/>
 				<xsl:with-param name="sourcePage" select="$sourcePageSpecific"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="hrefValue">
			<xsl:choose>
				<xsl:when test="$showSimpleGUI='1'"><xsl:value-of select="$thumbhrefValue"/></xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="searchDocDetailsHrefValue">
						<xsl:with-param name="docVerID" select="$docVerSearchResult/@id"/>
						<xsl:with-param name="docSearchIndex" select="$resultIndex"/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		<xsl:variable name="showLabels">
			<xsl:choose>
				<xsl:when test="/webcenter_page/search_criteria/displayPreferences/chkbox_ShowLabels='1'"><xsl:value-of select = "true()"/></xsl:when>
				<xsl:otherwise><xsl:value-of select = "false()"/></xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		<!-- Only show the row if we were able to retrieve the details. This might happen if it was deleted before the crawl. -->
		<xsl:if test="$docVerSearchResult">
		
			<xsl:variable name="isDocumentLockedVal">
				<xsl:choose>
					<xsl:when test="string-length($docSearchResult/document/checkout_owner_id) > 0">
						<xsl:value-of select="'1'" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="'0'" />
					</xsl:otherwise>
				</xsl:choose>
			</xsl:variable>
			
			<!-- 
				Link for the thumbnail.
				Note: In a document source, clicking on the thumbnail will select, not view.
			-->
			<xsl:variable name="thumbnailLink">
				<xsl:choose>
					<xsl:when test="$showActions='1'"><xsl:value-of select="$thumbhrefValue"/></xsl:when>
					<xsl:otherwise></xsl:otherwise>
				</xsl:choose>
			</xsl:variable>
		
			<div class="card searchresultsrow">
				<!-- 
				  New Search Architecture...
				  All data for this item gets passed to the JavaScript side. 
				-->
				<xsl:attribute name="data-rowdisplaydata">
					<xsl:value-of select="/webcenter_page/searchdata/resultsjson/result[@id=($docVerSearchResult/@id)]"/>
				</xsl:attribute>
				<!-- 
				  Some values are currently still generated and needed in the xsl.
				  To not generate them twice, we will keep those values in the xsl for now and simply pass them to the JS side.
				-->
				<xsl:attribute name="data-xslgen-thumbhref"><xsl:value-of select="$thumbnailLink"/></xsl:attribute>
				<!-- end -->
			
				<div class="wrapper">
					<div class="card-heading"><a class="btn pull-right" data-toggle="flip"><i class="icon icon-WCR_Actions-FlipCard12" /></a>
					
						<!-- when does the name select the card? -->
						<xsl:variable name="nameSelectsCard"><xsl:choose>
							<xsl:when test="$showSimpleGUI='1'">1</xsl:when><!-- then the thumbnail already has the view operation OR in document sources = select is the main operation -->
							<xsl:otherwise>0</xsl:otherwise><!-- otherwise, the thumbnail links to the viewer and the header will link to the details -->
						</xsl:choose></xsl:variable>
					
					
						<label class="fileanchor" title="{$docSearchResult/document/name}">
							<xsl:call-template name="ToggleThisCol">
								<xsl:with-param name="docVerID" select="$docVerSearchResult/@id"/>
								<xsl:with-param name="docName" select="$docSearchResult/document/name"/>
								<xsl:with-param name="projectId" select="$docVerSearchResult/project_list/project[1]/@id"/>
								<xsl:with-param name="documentId" select="$docSearchResult/document/@id"/>
								<xsl:with-param name="isLocked" select="$isDocumentLockedVal"/>
							</xsl:call-template>
							
							<xsl:if test="$nameSelectsCard='1'">
								<span class="fileanchorname">
									<xsl:value-of select="$docSearchResult/document/name"></xsl:value-of>
								</span>
							</xsl:if>
						</label>
						<xsl:if test="$nameSelectsCard='0'">
							<a class="filelink" title="{$docSearchResult/document/name}">
								<xsl:attribute name="href"><xsl:value-of select="$hrefValue"/></xsl:attribute>
								<xsl:value-of select="$docSearchResult/document/name"></xsl:value-of>
							</a>
						</xsl:if>
					</div>
					
					<!-- Thumbnail without name -->
					<div class="datacell" data-fieldid="thumbnail">
						<!-- the content will be put here... -->
					</div>
					
					<xsl:if test="$showActions='1' and not($docSearchResult/document/is_url = '1')">
						<div class="card-footer">
							<!-- Document Operations -->
							<xsl:call-template name="WriteDocumentActionLinks" >
								<xsl:with-param name="docSearchDisplayPrefsRoot" select="/webcenter_page/search_criteria/displayPreferences"/>
								<xsl:with-param name="docVersionSearchResultRoot" select="$docVerSearchResult"/>
								<xsl:with-param name="alignVal" select="''"/>
								<xsl:with-param name="responsive" select="'1'"/>
								<xsl:with-param name="deleteifempty" select="'.card-footer'"/>
								<xsl:with-param name="sourcePageSpecific" select="$sourcePageSpecific"/>
							</xsl:call-template>
						</div>
					</xsl:if>				
						
					
					<div class="card-info-sheet">
						<!-- Document Name + basic information + actions -->
						<xsl:call-template name="GridStyleResultsTableCellContentDocDetails">
							<xsl:with-param name="hrefValue" select="$hrefValue"/>	
							<xsl:with-param name="labelAlign" select="'left'"/>	
							<xsl:with-param name="valueAlign" select="'left'"/>		
							<xsl:with-param name="generalAlign" select="'left'"/>
							<xsl:with-param name="noHyperlinks" select="$noHyperlinks"/>	
							
							<xsl:with-param name="showContentBelowLabels" select="true()"/>
							<xsl:with-param name="showActions" select="false()"/><!-- already written above -->
						</xsl:call-template>
					</div>
				</div>
			</div>
			
		</xsl:if>
	</xsl:template>
	
	
	<!-- The items in the action menu -->
	<xsl:template name="ResultsTableActionMenu">
		<xsl:param name="showActions" select="true()"/>
		<xsl:param name="showSelectAction" select="false()"/>
		
		<div class="action-menu-component"
	        data-init-whensearchready="component/actionmenu/ActionMenu">
	        <xsl:if test="$showSelectAction">
	        	<xsl:call-template name="selectallaction"/>
	        </xsl:if>
	        <xsl:if test="$showActions='1'">
		       	<xsl:call-template name="ResultsTableActionMenuItems"/>
		    </xsl:if>
	    </div>
	</xsl:template>
	
	<!-- Whether there are items to display in the action menu -->
	<xsl:template name="ResultTableActionMenuHasMenuItems">
		<!-- 
          Simple check to see if we need to show the action bar... 
          We could have done more checks here but we don't think it is worth it vs the effort of maintaining it.
        -->
        <xsl:value-of select="count(key('menuItemKey', 'DOC_SEARCHRESULTS_LIST_ACTIONS')/menuitem)>0"/>
	</xsl:template>
	
	<!-- The items in the action menu -->
	<xsl:template name="ResultsTableActionMenuItems">
		<xsl:for-each select="key('menuItemKey', 'DOC_SEARCHRESULTS_LIST_ACTIONS')/menuitem">
			<!-- get the unique id of this customized menu item -->
			<xsl:variable name="customizedMenuItem" select="."/>
			
			<!-- check if this is a builtin action -->
			<xsl:if test="action/actiontype/builtin/builtin_name">
		
				<!-- which type of builtin action? -->
				<xsl:variable name="id" select="action/actiontype/builtin/builtin_name"/>
			
				<!-- run through all the search actions that work on this type of menu item -->
				<xsl:for-each select="/webcenter_page/searchdata/actionmenu/menuitem[@id=$id]">
					<!-- get the label or allow customization by menu -->
					<xsl:variable name="label">
						<xsl:choose>
							<xsl:when test="@label"><xsl:value-of select="@label"/></xsl:when>
							<xsl:otherwise><xsl:value-of select="Lang:getStr(&lk;,$customizedMenuItem/labeltag)"/></xsl:otherwise>
						</xsl:choose>
					</xsl:variable>
				
					<!-- add the builtinaction -->
					<xsl:call-template name="builtinaction">
						<xsl:with-param name="menuitem" select="$customizedMenuItem"/>
						<xsl:with-param name="name" select="@id"/>
						<xsl:with-param name="action" select="@action"/>
						<xsl:with-param name="label" select="$label"/>
						<xsl:with-param name="jsonoptions" select="@actionconfig"/>
					</xsl:call-template>
				</xsl:for-each>
			</xsl:if>

			<xsl:if test="not(/webcenter_page/search_criteria/displayPreferences/chkbox_CustomActions = '0')">
				<!-- Start Workflow -->
			 	<xsl:call-template name="startworkflowaction">
			 		<xsl:with-param name="itemidsel" select="'value'"/>
			 		<xsl:with-param name="itemidname" select="'docversionid'"/>
			 		<xsl:with-param name="tags"><xsl:call-template name="GetActionMenuTagsFromSearch"/></xsl:with-param>
			 	</xsl:call-template>

				<!-- JavaScript -->
			 	<xsl:call-template name="javascriptaction">
			 		<xsl:with-param name="itemidsel" select="'value'"/>
			 		<xsl:with-param name="tags"><xsl:call-template name="GetActionMenuTagsFromSearch"/></xsl:with-param>
			 	</xsl:call-template>
			 </xsl:if>			
			
		</xsl:for-each>

	</xsl:template>
    
    <!-- 
    	Footer of the results table
     -->
    <xsl:template name="ResultsTableFooter">
    	<xsl:param name="withShowHideThumbnailsButton" select="true()"/>
    	
   		<!-- table footer -->
		<div class="wcr-table-footer">
			<div class="wcr-table-paging">
				<xsl:call-template name="SearchResultsPager"/>
			</div>
			<div class="wcr-table-results">
				<xsl:call-template name="SearchResultsCountDisplay"/>
			</div>
			<div class="wcr-table-view-options">
				<xsl:call-template name="SearchResultsToggleResultsStyleButton">
					<xsl:with-param name="supportsGridMode" select="true()"/>
					<xsl:with-param name="supportsCardMode" select="true()"/>
				</xsl:call-template>
			
				<xsl:if test="$withShowHideThumbnailsButton = 'true'">
                	<xsl:call-template name="SearchResultsShowHideThumbnailsButton"/>
                </xsl:if>
             </div>
		</div>
    </xsl:template>
	
	
	<!-- 
		Which page is this? 
			= used when submitting a search action from the menu
	-->
	<xsl:template name="SourcePageGenerateInputs">
	
		<xsl:variable name="sourcePageWithoutIndices">
		
			<xsl:choose>
				<xsl:when test="/webcenter_page/Source_URL"><xsl:value-of select="/webcenter_page/Source_URL"/></xsl:when>
				<xsl:when test="count(/webcenter_page/search_context/project_context)=1">dosavedsearch.jsp?searchName=<xsl:value-of select="XSLUtils:urlEncode(/webcenter_page/saved_search_name)"/>&amp;menuitem3=<xsl:value-of select="/webcenter_page/nav/menu3/@menuitemname"/>&amp;menusel3=<xsl:value-of select="/webcenter_page/nav/menu3/@selected"/>&amp;projectID=<xsl:value-of select="/webcenter_page/search_context/project_context"/>&amp;menu_file=<xsl:value-of select="/webcenter_page/menu_file"/></xsl:when>
				<xsl:when test="count(/webcenter_page/search_context/docversion_context)=1">dosavedsearch.jsp?searchName=<xsl:value-of select="XSLUtils:urlEncode(/webcenter_page/saved_search_name)"/>&amp;menuitem3=<xsl:value-of select="/webcenter_page/nav/menu3/@menuitemname"/>&amp;menusel3=<xsl:value-of select="/webcenter_page/nav/menu3/@selected"/>&amp;docVerID=<xsl:value-of select="/webcenter_page/search_context/docversion_context"/>&amp;menu_file=<xsl:value-of select="/webcenter_page/menu_file"/></xsl:when>
				<xsl:when test="string-length(/webcenter_page/hp_section_id) &gt; 0">mytodolist.jsp</xsl:when>
				<xsl:otherwise>docsearchresults.jsp</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<!--  
			Calculating information for the sourcePage url
			Note: code duplicated in all xsl templates starting with "SourcePage" in the name. 
		-->
		
		<xsl:variable name="resultsStyle" select="/webcenter_page/results_style"/>
		<xsl:variable name="showThumbnails" select="/webcenter_page/show_thumbnails"/>

		<!-- Which page (as in paging) are we on? -->
		<xsl:variable name="colsPerPage" select="number(/webcenter_page/cols_per_page)"/>
		<xsl:variable name="rowsPerPage" select="number(/webcenter_page/rows_per_page)"/>
		<xsl:variable name="resultsPerPage" select="number($rowsPerPage * $colsPerPage)"/>
		
		<!-- pagination logic (duplicated code, can be found in "SearchResultsPager" and "SourcePage*" templates) -->
		<xsl:variable name="firstIndex" select="number(/webcenter_page/start_search_id)"/>
		<xsl:variable name="curPageNumMin" select="ceiling($firstIndex div $resultsPerPage)"/>
		<xsl:variable name="curPageNum">
			<xsl:choose>
				<xsl:when test="($firstIndex &gt; 1) and ($curPageNumMin &lt; 2)">
					<xsl:value-of select="2"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$curPageNumMin"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
 		<xsl:variable name="startIndex" select="$firstIndex"/>
  		<xsl:variable name="endIndex" select="number($curPageNum) * $resultsPerPage"/>
		
		<!-- make the inputs -->
		<input type="hidden" name="sourcePage"><xsl:attribute name="value"><xsl:value-of select="$sourcePageWithoutIndices"/></xsl:attribute></input>
		<input type="hidden" name="showThumbnails" value="{$showThumbnails}"/>
		<input type="hidden" name="StartIndex" value="{$startIndex}"/>
		<input type="hidden" name="EndIndex" value="{$endIndex}"/>
		<xsl:call-template name="menuFileHiddenInput"/>
		<input type="hidden" name="resultsStyle" value="{$resultsStyle}"/>
	</xsl:template>
	
	<!-- 
		Which page is this?
			= used when closing the viewer (more specific => redirects to exact result page we came from)
	-->
	<xsl:template name="SourcePageCalculateWithIndex">
		<xsl:param name="resultIndex"/>
		
		<!-- 
			Calculating information for the sourcePage url
			Note: code duplicated in all xsl templates starting with "SourcePage" in the name. 
		-->
		<xsl:variable name="resultsStyle" select="/webcenter_page/results_style"/>
		<xsl:variable name="showThumbnails" select="number(/webcenter_page/show_thumbnails)"/>

		<!-- Which page (as in paging) are we on? -->
		<xsl:variable name="colsPerPage" select="number(/webcenter_page/cols_per_page)"/>
		<xsl:variable name="rowsPerPage" select="number(/webcenter_page/rows_per_page)"/>
		<xsl:variable name="resultsPerPage" select="number($rowsPerPage * $colsPerPage)"/>
		
		<!-- pagination logic (duplicated code, can be found in "SearchResultsPager" and "SourcePage*" templates) -->
		<xsl:variable name="firstIndex" select="number(/webcenter_page/start_search_id)"/>
		<xsl:variable name="curPageNumMin" select="ceiling($firstIndex div $resultsPerPage)"/>
		<xsl:variable name="curPageNum">
			<xsl:choose>
				<xsl:when test="($firstIndex &gt; 1) and ($curPageNumMin &lt; 2)">
					<xsl:value-of select="2"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$curPageNumMin"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
 		<xsl:variable name="startIndex" select="$firstIndex"/>
  		<xsl:variable name="endIndex" select="number($curPageNum) * $resultsPerPage"/>
	
		<!-- Name of saved search -->
		<xsl:variable name="savedSearchParam">
			<xsl:call-template name="savedSearchParam"/>
		</xsl:variable>
		
		<!-- make the url -->
		<xsl:choose>
			<xsl:when test="/webcenter_page/Source_URL"><xsl:value-of select="/webcenter_page/Source_URL"/></xsl:when>
			<xsl:when test="string-length(/webcenter_page/hp_section_id)>0">mytodolist.jsp</xsl:when>
			<xsl:when test="count(/webcenter_page/saved_search_name)=0">docsearchresults.jsp?docSearchIndex=<xsl:value-of select="$resultIndex"/>&amp;resultsStyle=<xsl:value-of select="$resultsStyle"/>&amp;<xsl:call-template name="menuFileUrlParameter"/></xsl:when>
			<xsl:otherwise>dosavedsearch.jsp?showThumbnails=<xsl:value-of select="$showThumbnails"/>&amp;resultsStyle=<xsl:value-of select="$resultsStyle"/>&amp;StartIndex=<xsl:value-of select="$startIndex"/>&amp;EndIndex=<xsl:value-of select="$endIndex"/><xsl:value-of select="$savedSearchParam"/></xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<!-- 
		Get the configuration for the "create projects from selected documents".
		Will return the empty string if the action is disabled in the search setup
	 -->
	<xsl:template name="ActionsGetCreateProjectFromSelectedConfig">
		<xsl:if test="/webcenter_page/search_criteria/displayPreferences/chkbox_CreateProject='1' and (/webcenter_page/is_manager or /webcenter_page/is_admin)">
			{<xsl:choose>
				<xsl:when test="/webcenter_page/search_criteria/displayPreferences/radiobtn_SelectTemplate='1' and /webcenter_page/search_criteria/displayPreferences/selectTemplateId!=''">
					"templateId":<xsl:value-of select="XSLUtils:encodeJSONString(/webcenter_page/search_criteria/displayPreferences/selectTemplateId)"/>
				</xsl:when>
				<xsl:when test="/webcenter_page/search_criteria/displayPreferences/radiobtn_CharacteristicsPath='1' and /webcenter_page/search_criteria/displayPreferences/selectCharPath!=''">
					"templatecharacteristicpath":<xsl:value-of select="XSLUtils:encodeJSONString(/webcenter_page/search_criteria/displayPreferences/selectCharPath)"/>
				</xsl:when>
			</xsl:choose>}
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="searchDocDetailsHrefValue">
		<xsl:param name="docVerID"/>
		<xsl:param name="docSearchIndex"/>
		<xsl:choose>
			<xsl:when test="count(/webcenter_page/saved_search_name)=0">docdetails.jsp?docSearchIndex=<xsl:value-of select="$docSearchIndex"/>&amp;searchDocVerID=<xsl:value-of select="$docVerID"/>&amp;<xsl:call-template name="menuFileUrlParameter"/>
			</xsl:when>
			<xsl:otherwise>docdetails.jsp?docVerID=<xsl:value-of select="$docVerID"/>&amp;<xsl:call-template name="menuFileUrlParameter"/><!-- TODO: memu_file=myfavoriteproj myfavoriteproj as menu file is maybe not ideal-->
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
 
 <!-- Writes "Select This Document" checkbox for a specific Document row in the main table : LIST VIEW -->
 <xsl:template name="ToggleThisCol">
	 <xsl:param name="docVerID"/> 
	 <xsl:param name="docName"/>
	 <xsl:param name="projectId"/>  <!-- needed because SDK call setAttributes asks for projectId even though documentId is unique -->
	 <xsl:param name="documentId"/>	<!-- needed because SDK call setAttributes asks for documentId even though attributes are by the version -->
	 <xsl:param name="isLocked" select="'0'"/>
	 
	 
	<input type="checkbox" name="selectedDocs">
		<!-- for historical reasons, the docVersionId goes in value while the documentid goes in id. the name is used for feedback when setting attributes from search results -->		
		<xsl:attribute name="value">
			<xsl:value-of select="$docVerID"/>
		</xsl:attribute>
		<xsl:attribute name="fullname">
			<xsl:value-of select="$docName"/>
		</xsl:attribute>									
		<xsl:attribute name="projectid">
		  <xsl:value-of select="$projectId"/>
		</xsl:attribute>	
		<xsl:attribute name="documentid">
		  <xsl:value-of select="$documentId"/>
		</xsl:attribute>
		<xsl:attribute name="is_locked">
		  <xsl:value-of select="$isLocked"/>
		</xsl:attribute>					
    </input>
 </xsl:template>

	<xsl:template name="searchDocViewHrefValue">
		<xsl:param name="docVerID"/>
		<xsl:param name="sourcePage"/>
		<xsl:text>viewdocument.jsp?docVerID=</xsl:text><xsl:value-of select="$docVerID"/><xsl:text>&amp;</xsl:text><xsl:call-template name="menuFileUrlParameter"/><xsl:text>&amp;sourcePage=</xsl:text><xsl:value-of select="XSLUtils:urlEncode($sourcePage)"/>
	</xsl:template>

	<!-- Overwrite the one in approvaltemplates: user always goes to approver page -->
	<xsl:template name="SubmitSingleDocumentActionHref">
		<xsl:param name="doc_version" />
		<xsl:param name="actionName" />
		
		<xsl:text>docdetailsapprovers.jsp?docVerID=</xsl:text>
		<xsl:value-of select="$doc_version/@id" />
		<xsl:text>&amp;menu_file=</xsl:text>
		<xsl:value-of select="/webcenter_page/menu_file" />
	</xsl:template>
	
	<!--
		Used to generate Action-Icon-Links for Documents on Search Results page
		Shows only those actions, that are toggled on from the 'Result Layout Options' from Search Congifuration  
		Author: JAMI 
		Since: 8. 9. 2014
		
		Requires: the parent XSL template has to include the following JS file import > docSearchOperations.js
	-->
	<xsl:template name="WriteDocumentActionLinks"> 
		<xsl:param name="docSearchDisplayPrefsRoot" select="'N/A'"/>
		<xsl:param name="docVersionSearchResultRoot"/>
		<xsl:param name="responsive" select="'0'"/>
		<xsl:param name="sourcePageSpecific" select="''"/>
		<xsl:param name="deleteifempty" select="''"/>
		
		<!-- Initialize Variables -->
		<xsl:variable name="docVerID" select="$docVersionSearchResultRoot/@id"/>
		<xsl:variable name="projectID" select="$docVersionSearchResultRoot/project_list/project[1]/@id"/>
		<xsl:variable name="projectName" select="$docVersionSearchResultRoot/project_list/project/name"/>
		<xsl:variable name="docID" select="$docVersionSearchResultRoot/document_id"/>
		<xsl:variable name="documentName" select="$docVersionSearchResultRoot/doc_search_result/document/name"/>
		<xsl:variable name="isProjectActive" select="key('projectStatusKey',$docVersionSearchResultRoot/project_list/project/status_id)/is_active"/>
		<!-- Actual "Download" permission is checked later on > use '1' as a dummy value -->
		<xsl:variable name="ArtiosCADOpenType" select="XSLUtils:getACADOpenModeVal($docVersionSearchResultRoot/doctype_id, '1', /webcenter_page/acad_doc_open_type)"/>
		<xsl:variable name="has3DView" select="$docVersionSearchResultRoot/has3dview"/>
		
		<xsl:variable name="isCurDocProjectManager">
			<xsl:choose>
				<xsl:when test="$docVersionSearchResultRoot/is_project_manager_current_project">1</xsl:when>
				<xsl:otherwise>0</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		<xsl:variable name="appCycleStarted">
			<xsl:choose>
				<xsl:when test="$docVersionSearchResultRoot/approval_cycle_state = 'cycle_started'">1</xsl:when>
				<xsl:otherwise>0</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		<xsl:variable name="isAdmin">
			<xsl:choose>
				<xsl:when test="/webcenter_page/is_admin">1</xsl:when>
				<xsl:otherwise>0</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		<xsl:variable name="projActiveOrSuperUser">
			<xsl:choose>
				<xsl:when test="($isProjectActive = '1') or ($isAdmin = '1') or ($isCurDocProjectManager = '1')">1</xsl:when>
				<xsl:otherwise>0</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		<xsl:variable name="cannotDelete" select="($isAdmin = '0') and ($isProjectActive = '0') and (/webcenter_page/no_doc_operations_inactive_proj)" />
		
		<xsl:variable name="isLocked">
			<xsl:choose>
				<xsl:when test="not(string($docVersionSearchResultRoot/doc_search_result/document/checkout_owner_id))">0</xsl:when>
				<xsl:otherwise>1</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		<xsl:variable name="isLockedByOtherUser">
			<xsl:choose>
				<xsl:when test="($isLocked = '0') or ($docVersionSearchResultRoot/doc_search_result/document/checkout_owner_id = /webcenter_page/loginuserid)">0</xsl:when>
				<xsl:otherwise>1</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		<xsl:variable name="jsEncodedSourcePage"><xsl:value-of select="XSLUtils:encodeForJScript($sourcePageSpecific)"/></xsl:variable>
		
		
		<!-- 
			Write the HTML
		-->
		
		<xsl:call-template name="OptimizedRowActionMenu">
			<xsl:with-param name="content">
		
		<div class="row-actions-component"
			data-init-whensearchready="component/actionmenu/RowActionMenu"
			data-fillspace="{$responsive}"
			data-deleteifempty="{$deleteifempty}">
			
			<xsl:for-each select="key('menuItemKey', 'DOC_SEARCHRESULTS_ITEM_ACTIONS')/menuitem">

			 	<!-- 1. View -->
			 	<!-- Default: ON -->
			 	<xsl:variable name="docAction_View_val">
			 		<xsl:choose>
				 		<xsl:when test="not($docSearchDisplayPrefsRoot = 'N/A') and $docSearchDisplayPrefsRoot/chkbox_DocOpView = '0'"><xsl:value-of select="false()"/></xsl:when>
				 		<xsl:otherwise><xsl:value-of select="true()"/></xsl:otherwise>
				 	</xsl:choose>
			 	</xsl:variable>
				<xsl:if test="$docAction_View_val = 'true'">
					<xsl:if test="$has3DView = '1'">
				 		<xsl:variable name="view3DJSString">docSearchOperations.ViewDocument3D('<xsl:value-of select="$docVerID"/>','<xsl:value-of select="$jsEncodedSourcePage"/>');</xsl:variable>
						<xsl:call-template name="builtinaction">
							<xsl:with-param name="name" select="'DOC_SEARCHRESULTS_ITEM_ACTION_VIEW3D'"/>
					 		<xsl:with-param name="onclick" select="$view3DJSString"/>
						</xsl:call-template>
					</xsl:if>
			 		<xsl:variable name="ViewJSString">docSearchOperations.ViewDocument('<xsl:value-of select="$docVerID"/>','<xsl:value-of select="$jsEncodedSourcePage"/>');</xsl:variable>
					<xsl:call-template name="builtinaction">
						<xsl:with-param name="name" select="'DOC_SEARCHRESULTS_ITEM_ACTION_VIEW'"/>
				 		<xsl:with-param name="onclick" select="$ViewJSString"/>
					</xsl:call-template>
			 	</xsl:if>

			 	<!-- 2. Open in ArtiosCAD -->
			 	<!-- Default: ON -->
			 	<xsl:variable name="docAction_OpenInACAD_val">
			 		<xsl:choose>
				 		<xsl:when test="not($docSearchDisplayPrefsRoot = 'N/A') and $docSearchDisplayPrefsRoot/chkbox_DocOpArtiosCAD = '0'"><xsl:value-of select="false()"/></xsl:when>
				 		<xsl:otherwise><xsl:value-of select="true()"/></xsl:otherwise>
				 	</xsl:choose>
			 	</xsl:variable>
			 	<!-- Additional conditions: Open in ACAD Standard or Enterprise is enabled on the system -->
		 		<xsl:if test="not($ArtiosCADOpenType = 'None') and $docAction_OpenInACAD_val = 'true'"> 
		 			<xsl:variable name="OpenInACADJSString">docSearchOperations.OpenInACAD('<xsl:value-of select="$ArtiosCADOpenType"/>', '<xsl:value-of select="$docVerID"/>', '<xsl:value-of select="/webcenter_page/doc_type_list/doc_type[@id='00001_0000000005']/view_jsp"/>', '<xsl:value-of select="XSLUtils:encodeForJScript($projectName)"/>', '<xsl:value-of select="XSLUtils:encodeForJScript($documentName)"/>');</xsl:variable>
					<xsl:call-template name="builtinaction">
						<xsl:with-param name="name" select="'DOC_SEARCHRESULTS_ITEM_ACTION_OPENACAD'"/>
				 		<xsl:with-param name="onclick" select="$OpenInACADJSString"/>
					</xsl:call-template>
				</xsl:if>

			 	<!-- 3. Download -->
			 	<!-- Default: ON -->
			 	<xsl:variable name="docAction_Download_val">
			 		<xsl:choose>
				 		<xsl:when test="not($docSearchDisplayPrefsRoot = 'N/A') and $docSearchDisplayPrefsRoot/chkbox_DocOpDownload = '0'"><xsl:value-of select="false()"/></xsl:when>
				 		<xsl:otherwise><xsl:value-of select="true()"/></xsl:otherwise>
				 	</xsl:choose>
			 	</xsl:variable>
				<xsl:if test="$docAction_Download_val = 'true'">
			 		<xsl:variable name="DownloadJSString">docSearchOperations.DownloadDoc('<xsl:value-of select="$docVerID"/>', '<xsl:value-of select="$projectID"/>', '<xsl:value-of select="$docVersionSearchResultRoot/doctype_id"/>', '<xsl:value-of select="$isLocked = '1'"/>');</xsl:variable>
					<xsl:call-template name="builtinaction">
						<xsl:with-param name="name" select="'DOC_SEARCHRESULTS_ITEM_ACTION_DOWNLOAD'"/>
				 		<xsl:with-param name="onclick" select="$DownloadJSString"/>
					</xsl:call-template>
			 	</xsl:if>

				<!-- 4. Define Attributes -->
				<!-- Default: ON -->
			 	<xsl:variable name="docAction_defineAttribute_val">
			 		<xsl:choose>
				 		<xsl:when test="not($docSearchDisplayPrefsRoot = 'N/A') and $docSearchDisplayPrefsRoot/chkbox_DocOpDefineAttrs = '0'"><xsl:value-of select="false()"/></xsl:when>
				 		<xsl:otherwise><xsl:value-of select="true()"/></xsl:otherwise>
				 	</xsl:choose>
			 	</xsl:variable>
				<xsl:if test="$docAction_defineAttribute_val = 'true'">
			 		<xsl:variable name="DefineAttrJSString">docSearchOperations.DefineDocAttrValue('<xsl:value-of select="$docVerID"/>');</xsl:variable>
					<xsl:call-template name="builtinaction">
						<xsl:with-param name="name" select="'DOC_SEARCHRESULTS_ITEM_ACTION_ATTR'"/>
				 		<xsl:with-param name="onclick" select="$DefineAttrJSString"/>
					</xsl:call-template>
			 	</xsl:if>
			
			 	<!-- 5. Approval Info -->
			 	<!-- Default: OFF -->
			 	<xsl:variable name="docAction_ApprovalInfo_val">
			 		<xsl:choose>
				 		<xsl:when test="not($docSearchDisplayPrefsRoot = 'N/A') and $docSearchDisplayPrefsRoot/chkbox_DocOpApprovalInfo = '1'"><xsl:value-of select="true()"/></xsl:when>
				 		<xsl:otherwise><xsl:value-of select="false()"/></xsl:otherwise>
				 	</xsl:choose>
			 	</xsl:variable>		
				<xsl:if test="$docAction_ApprovalInfo_val = 'true'">
			 		<xsl:variable name="ViewAppInfoJSString">docSearchOperations.ViewDocApprovalInfo('<xsl:value-of select="$docVerID"/>');</xsl:variable>
					<xsl:call-template name="builtinaction">
						<xsl:with-param name="name" select="'DOC_SEARCHRESULTS_ITEM_ACTION_VIEWAPPR'"/>
				 		<xsl:with-param name="onclick" select="$ViewAppInfoJSString"/>
					</xsl:call-template>
			 	</xsl:if>
			 	
			 	<!-- 6. Mail Download Link -->
			 	<!-- Default: OFF -->
			 	<xsl:variable name="docAction_MailDLLink_val">
			 		<xsl:choose>
				 		<xsl:when test="not($docSearchDisplayPrefsRoot = 'N/A') and $docSearchDisplayPrefsRoot/chkbox_DocOpMailDownloadLink = '1'"><xsl:value-of select="true()"/></xsl:when>
				 		<xsl:otherwise><xsl:value-of select="false()"/></xsl:otherwise>
				 	</xsl:choose>
			 	</xsl:variable>
				<!-- Additional conditions: Generation of Document Download links is enabled on the system -->
				<xsl:if test="(/webcenter_page/doc_download_link_generation_allowed) and ($docAction_MailDLLink_val = 'true')">
			 		<xsl:variable name="MailDLLinkJSString">executeSingleDocDLLinkGenerate('<xsl:value-of select="$docVerID"/>', '<xsl:value-of select="XSLUtils:encodeForJScript($documentName)"/>');</xsl:variable>
					<xsl:call-template name="builtinaction">
						<xsl:with-param name="name" select="'DOC_SEARCHRESULTS_ITEM_ACTION_DOWNLOADLINK'"/>
				 		<xsl:with-param name="onclick" select="$MailDLLinkJSString"/>
					</xsl:call-template>
			 	</xsl:if>
			 	
				<!-- 7. Mail Link To -->
				<!-- Default: OFF -->
			 	<xsl:variable name="docAction_MaiLinkTo_val">
			 		<xsl:choose>
				 		<xsl:when test="not($docSearchDisplayPrefsRoot = 'N/A') and ($docSearchDisplayPrefsRoot/chkbox_DocOpMailLinkTo = '1')"><xsl:value-of select="true()"/></xsl:when>
				 		<xsl:otherwise><xsl:value-of select="false()"/></xsl:otherwise>
				 	</xsl:choose>
			 	</xsl:variable>		
				<xsl:if test="$docAction_MaiLinkTo_val = 'true'">
			 		<xsl:variable name="MailLinkToJSString">docSearchOperations.MailLinkTo('<xsl:value-of select="$docVerID"/>', '<xsl:value-of select="XSLUtils:encodeForJScript($documentName)"/>', '<xsl:value-of select="/webcenter_page/hosturl"/>', '<xsl:value-of select="XSLUtils:encodeForJScript(Lang:getStr(&lk;,'MAILTOSUBJECTDOC'))"/>');</xsl:variable>
					<xsl:call-template name="builtinaction">
						<xsl:with-param name="name" select="'DOC_SEARCHRESULTS_ITEM_ACTION_MAILLINK'"/>
				 		<xsl:with-param name="onclick" select="$MailLinkToJSString"/>
					</xsl:call-template>
			 	</xsl:if>
			 	
				<!-- 8. Upload New Version -->
				<!-- Default: OFF -->
			 	<xsl:variable name="docAction_UploadNewVersion_val">
			 		<xsl:choose>
				 		<xsl:when test="not($docSearchDisplayPrefsRoot = 'N/A') and $docSearchDisplayPrefsRoot/chkbox_DocOpNewVersion = '1'"><xsl:value-of select="true()"/></xsl:when>
				 		<xsl:otherwise><xsl:value-of select="false()"/></xsl:otherwise>
				 	</xsl:choose>
			 	</xsl:variable>		
				<!-- Additional conditions: The parent project is active (or the current user is its PM or an Admin) + The Document is not locked by another User -->
				<xsl:if test="($docAction_UploadNewVersion_val = 'true') and ($projActiveOrSuperUser = '1') and ($isLockedByOtherUser = '0')">
			 		<xsl:variable name="UploadNewVersionJSString">docSearchOperations.UploadNewDocVersion('<xsl:value-of select="$docVerID"/>');</xsl:variable>
					<xsl:call-template name="builtinaction">
						<xsl:with-param name="name" select="'DOC_SEARCHRESULTS_ITEM_ACTION_UPLOADVER'"/>
				 		<xsl:with-param name="onclick" select="$UploadNewVersionJSString"/>
					</xsl:call-template>
			 	</xsl:if>			
				
				<!-- 9. More actions: Lock, Rename, Add to Cart, Delete -->
			 	<!-- Default: ON -->
			 	<xsl:variable name="docAction_MoreActions_val">
			 		<xsl:choose>
				 		<xsl:when test="not($docSearchDisplayPrefsRoot = 'N/A') and $docSearchDisplayPrefsRoot/chkbox_DocOpMoreOptions = '0'"><xsl:value-of select="false()"/></xsl:when>
				 		<xsl:otherwise><xsl:value-of select="true()"/></xsl:otherwise>
				 	</xsl:choose>
			 	</xsl:variable>			 	
				<xsl:if test="$docAction_MoreActions_val = 'true'"><!-- TODO: ... Does this setting still make sense? sort of - it just enables 4 actions in one go -->

		 			<!-- 9.a. Lock -->
		 			<xsl:variable name="LockDocumentJSString">docSearchOperations.LockDocument('<xsl:value-of select="$docVerID"/>', '<xsl:value-of select="$docID"/>');</xsl:variable>
					<xsl:call-template name="builtinaction">
						<xsl:with-param name="name" select="'DOC_SEARCHRESULTS_ITEM_ACTION_LOCK'"/>
				 		<xsl:with-param name="onclick" select="$LockDocumentJSString"/>
					</xsl:call-template>

					<!-- 9.b. Rename -->
					<xsl:variable name="RenameDocumentJSString">docSearchOperations.RenameDocument('<xsl:value-of select="$docVerID"/>', '<xsl:value-of select="$projectID"/>');</xsl:variable>
					<xsl:call-template name="builtinaction">
						<xsl:with-param name="name" select="'DOC_SEARCHRESULTS_ITEM_ACTION_RENAME'"/>
				 		<xsl:with-param name="onclick" select="$RenameDocumentJSString"/>
					</xsl:call-template>

					<!-- 9.c. Add to Cart -->
					<xsl:variable name="AddToCartDocumentJSString">docSearchOperations.AddDocumentToCart('<xsl:value-of select="$docVerID"/>');</xsl:variable>
					<xsl:call-template name="builtinaction">
						<xsl:with-param name="name" select="'DOC_SEARCHRESULTS_ITEM_ACTION_ADDTOCART'"/>
				 		<xsl:with-param name="onclick" select="$AddToCartDocumentJSString"/>
					</xsl:call-template>
					
					<!-- 9.d. Delete Document -->
					<!-- Additional conditions: The Document is currently unlocked + Document deletion is not prevenetd by Security settings related to Inactive project operations -->
					<xsl:if test="not($cannotDelete) and ($isLocked = '0')">
						<xsl:variable name="DeleteDocumentJSString">docSearchOperations.DeleteDocument('<xsl:value-of select="$docVerID"/>', '<xsl:value-of select="$docID"/>', '<xsl:value-of select="$projectID"/>', '<xsl:value-of select="XSLUtils:encodeForJScript(Lang:getStr(&lk;,'CONFIRMDELDOCS'))"/>', '<xsl:value-of select="XSLUtils:encodeForJScript(Lang:getStr(&lk;,'CONFIRMDELAPPONGDOCS'))"/>', <xsl:value-of select="$appCycleStarted = '1'"/>);</xsl:variable>
						<xsl:call-template name="builtinaction">
							<xsl:with-param name="name" select="'DOC_SEARCHRESULTS_ITEM_ACTION_DELETE'"/>
					 		<xsl:with-param name="onclick" select="$DeleteDocumentJSString"/>
						</xsl:call-template>
					</xsl:if>
			 	</xsl:if>

				<!-- Custom Actions -->
				<xsl:if test="not(/webcenter_page/search_criteria/displayPreferences/chkbox_CustomActions = '0')">
					<!-- Create Task -->
					<xsl:call-template name="createtaskaction">
						<xsl:with-param name="projectId" select="$projectID"/>
						<xsl:with-param name="docVersionId" select="$docVerID"/>
				 		<xsl:with-param name="tags"><xsl:call-template name="GetActionMenuTagsFromSearch"/></xsl:with-param>
				 		<xsl:with-param name="urlencodedpageurl" select="XSLUtils:urlEncode($sourcePageSpecific)"/>
					</xsl:call-template>
						
					<!-- Start Workflow -->
			 		<xsl:call-template name="startworkflowaction">
				 		<xsl:with-param name="itemidsel" select="'value'"/>
				 		<xsl:with-param name="itemidname" select="'docversionid'"/>
				 		<xsl:with-param name="tags"><xsl:call-template name="GetActionMenuTagsFromSearch"/></xsl:with-param>
				 	</xsl:call-template>
	
					<!-- JavaScript -->
				 	<xsl:call-template name="javascriptaction">
					 	<!-- pass both itemidsel ... -->
				 		<xsl:with-param name="itemidsel" select="'value'"/>
				 		<!-- ... and id's separately -->
				 		<xsl:with-param name="projectId" select="$projectID"/>
						<xsl:with-param name="docVersionId" select="$docVerID"/>
						
				 		<xsl:with-param name="tags"><xsl:call-template name="GetActionMenuTagsFromSearch"/></xsl:with-param>
				 	</xsl:call-template>
				 </xsl:if>

			</xsl:for-each>
	 	
	 	</div>
	 	
			</xsl:with-param>
		</xsl:call-template>
	 	
	</xsl:template>
	
	<!-- 
	
            template that controls the inclusion of javascript functionality used in both normal page and hp section
            called from scriptincs_hp_section
	
	-->
	<xsl:template name="scriptincs_common">
		<xsl:variable name="menuName"><xsl:call-template name="menuName"/></xsl:variable>
		<xsl:variable name="actionFormName"><xsl:call-template name="actionFormName"/></xsl:variable>
		
		<xsl:call-template name="SearchLangArr"/>
		
		var dlLinkLangStrings = new Array();
	  	<xsl:call-template name="i18n">
			<xsl:with-param name="keys">
    			MAILTOSUBJECTDOC|
    			MAILTOSUBJECTDOCDOWNLOAD|
    			MAILTOSUBJECTDOCSDOWNLOAD|
    			GENERATE_DLLINKFAILED|
    			GENERATE_DLLINKFAILED_INVALID_PARAMS|
    			GENERATE_DLLINKFAILED_NONE_DOCS_ALLOWED|
    			GENERATE_DLLINKFAILED_INVALID_NAMEMAP_PARAM|
    			DOCS_DENIED_FEEDBACK_MESSAGE_START|
    			DOCS_DENIED_FEEDBACK_MESSAGE_END|
    			OVERSIZE_DOC_DL_MESSAGE_POPUP_TITLE|
    			OVERSIZE_DOC_DL_MESSAGE_CONFRIM|
    			CLOSE|
    			OPEN_NEW_EMAIL_MESSAGE
    		</xsl:with-param>
    		<xsl:with-param name="nested" select="1" />
    		<xsl:with-param name="langVar" select="'dlLinkLangStrings'"/>
		</xsl:call-template>
		
		var cartLangStrings = new Array();
	  	<xsl:call-template name="i18n">
			<xsl:with-param name="keys">
    			PROJ_CREATION_LOADING|
    			CREATE_PROJ_FROM_CART|
    			REMFROMCART|
    			CLEARCART|
    			CARTEMPTY|
    			NOTHING_SELECTED|
    			CUR_IN_YOUR_CART
    		</xsl:with-param>
    		<xsl:with-param name="nested" select="1" />
    		<xsl:with-param name="langVar" select="'cartLangStrings'"/>
		</xsl:call-template>
		
		//initialize docSearchOperations object (used to execute Document Operation for individual Documents in the result)
		var docSearchOperations = new DocSearchOperations(langArr, '<xsl:value-of select="/webcenter_page/menu_file"/>', '<xsl:value-of select="$actionFormName"/>');
				
		//initialize 'Mail (Download) Link' service handler
		var sendDlLinkMgr = new downloadDocLinkMailGenerator(dlLinkLangStrings);
	  
	  function executeSingleDocDLLinkGenerate(documentVersionID, documentName) {
			//prepare dummy list of DocVersioID and a VerID-Name Map
      		var docVersionIDs = [];
           	var docVersionNameMap = [];
           	docVersionIDs.push(documentVersionID);
           	docVersionNameMap.push({id: documentVersionID, name: documentName});
      		
      		sendDlLinkMgr.generateDocumentBatchDLLinkMail(docVersionIDs, docVersionNameMap);		
		} 
	

	</xsl:template>

	<!-- 
  
            template that controls the inclusion of javascript functionality 
            
	-->
	<xsl:template name="DocSearchResultsJavaScript">
		<script src="javascript/webcenter_xml.js" type="text/javascript"/>&#xA;
		<script src="javascript/webcenter_html.js" type="text/javascript"/>&#xA;
		<script src="javascript/validate.js" type="text/javascript"/>&#xA;
		<script src="javascript/popup.js" type="text/javascript"/>&#xA;
		<script src="javascript/hover.js" type="text/javascript"/>&#xA;
		<script src="javascript/extpopup.js" type="text/javascript"/>&#xA;
		<script src="javascript/detailswin.js" type="text/javascript"/>&#xA;	
		<script src="javascript/approvalInfoPopup.js" type="text/javascript"/>&#xA;	
		<script src="javascript/docSearchOperations.js" type="text/javascript"/>&#xA;
		<script src="javascript/SendDocDownloadLink.js" type="text/javascript"/>&#xA;
		
		<xsl:call-template name="i18n">
			<xsl:with-param name="langVar" select="'dlLinkLangStrings'"/>
			<xsl:with-param name="keys">
    			MAILTOSUBJECTDOCDOWNLOAD|
    			MAILTOSUBJECTDOCSDOWNLOAD|
    			GENERATE_DLLINKFAILED|
    			GENERATE_DLLINKFAILED_INVALID_PARAMS|
    			GENERATE_DLLINKFAILED_NONE_DOCS_ALLOWED|
    			GENERATE_DLLINKFAILED_INVALID_NAMEMAP_PARAM|
    			DOCS_DENIED_FEEDBACK_MESSAGE_START|
    			DOCS_DENIED_FEEDBACK_MESSAGE_END|
    			OVERSIZE_DOC_DL_MESSAGE_POPUP_TITLE|
    			OVERSIZE_DOC_DL_MESSAGE_CONFRIM|
    			CLOSE|
    			OPEN_NEW_EMAIL_MESSAGE
    		</xsl:with-param>
		</xsl:call-template>
	 
		<xsl:call-template name="scriptincs_search_results"/>	

		<script type="text/javascript">&#xA;
		
			<xsl:call-template name="SearchLangArr"/>			
			
			//initialize docSearchOperations object (used to execute Document Operation for individual Documents in the result)
			var docSearchOperations = new DocSearchOperations(langArr, '<xsl:value-of select="/webcenter_page/menu_file"/>', 'actionform');
			
			var sendDlLinkMgr = new downloadDocLinkMailGenerator(dlLinkLangStrings);	
			
	        function SaveSearch() {
	          document.savesearchform.actionVal.value="SaveFromDocSearchResults";
	
	          // post the request&#xA;
	          document.savesearchform.submit();
	        }
		        
	        function downloadsearchresult(){
			  submitdownloadsearchresult("DownloadFromDocSearchResults");
	        }
			
			function executeSingleDocDLLinkGenerate(documentVersionID, documentName) {
				//prepare dummy list of DocVersioID and a VerID-Name Map
      			var docVersionIDs = [];
            	var docVersionNameMap = [];
            	docVersionIDs.push(documentVersionID);
            	docVersionNameMap.push({id: documentVersionID, name: documentName});
      		
      			sendDlLinkMgr.generateDocumentBatchDLLinkMail(docVersionIDs, docVersionNameMap);
			}
			
			// register this crossframelistener when we're loaded in an iframe (communicates with documentSourceHandler.js in parent window)
			if(window.self !== window.top){
				require(["pages/docsearchresults/CrossFrameListener"], function(CrossFrameListener) {
					var crossFrameListener = new CrossFrameListener();
					crossFrameListener.attach();
				});
			}	
		</script>
	</xsl:template>

</xsl:stylesheet>
