<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE xsl:stylesheet [
<!ENTITY copy "&#169;">
<!ENTITY nbsp "&#160;">
  <!ENTITY lk "/webcenter_page/user_lang_key">
]>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:java="http://xml.apache.org/xslt/java" xmlns:XSLUtils="com.esko.webcenter.jsp.XSLUtils" xmlns:Lang="com.esko.webcenter.jsp.LanguageMgr" exclude-result-prefixes="XSLUtils Lang">
	<xsl:import href="template.xsl"/>
	<xsl:import href="attrunittmplts.xsl"/>
	<xsl:import href="templatedate.xsl"/>
	<xsl:import href="doctemplates.xsl"/>	 	
	<xsl:import href="searchresultstemplate.xsl"/>	
	<xsl:import href="projmgmnttemplate.xsl"/>


	<xsl:key name="projectKey" match="/webcenter_page/search_results/project_list/project" use="@id"/>

	<xsl:template name="header"/>
	<xsl:template name="bodyheader">
	  	<!-- search results header -->
		<xsl:call-template name="searchResultsHeader"/>
	</xsl:template>

	<!-- 
  
            template that controls the generation of the body content
            
	-->
	<xsl:template name="bodycontent">
		<!-- Form for re run of search -->
		<xsl:call-template name="SearchResultsStoredValues"/>
		
		<!-- id of the action form to submit -->
		<xsl:variable name="actionFormName"><xsl:call-template name="actionFormName"/></xsl:variable>
		
		<!-- hpSection id... -->
		<xsl:variable name="hpSectionId" select="/webcenter_page/hp_section_id"/>		
	    <xsl:variable name="hpSectionIdPrefix"> 
		  <xsl:choose>
			 <xsl:when test="string-length($hpSectionId) = 0"><xsl:value-of select="''"/></xsl:when>
			 <xsl:otherwise><xsl:value-of select="$hpSectionId"/><xsl:value-of select="'_'"/></xsl:otherwise>
	      </xsl:choose>
	    </xsl:variable>
		
	    <!-- general layout settings -->
		<xsl:variable name="showThumbnails" select="number(/webcenter_page/show_thumbnails)"/>
		<xsl:variable name="resultsStyle" select="/webcenter_page/results_style"/>
	    
	    <!-- Do we want to show actions? NOT if we are in a popup to select items! -->
		<xsl:variable name="showActions">
		    <!-- Don't show Actions menu when in saved search dialog used for selecting items -->
			<xsl:if test="$hpSectionIdPrefix!='00001_9000000000_' and $hpSectionIdPrefix!='00001_8900000000_'">
				<xsl:value-of select="1"/>
		    </xsl:if>
		</xsl:variable>		
		
		<!-- Don't show Actions menu when in saved search dialog used for selecting items -->
		<xsl:variable name="stickyActions">
			<xsl:call-template name="isStickyActions" />
		</xsl:variable>
		
		<xsl:variable name="withShowHideThumbnailsButton">
			<xsl:call-template name="withShowHideThumbnailsButton" />
		</xsl:variable>
		

		<!--
		
			The search results javascript component
			
		 -->
		<div 
			data-init="component/searchresults/internal/SearchResultsControl" 
			data-searchdata="{/webcenter_page/searchdata/datajson}"
			data-hpsectionid="{$hpSectionId}" 
			data-rerunurl="{/webcenter_page/searchdata/saved_search_re_run_url}"
			id="searchresultscontrol{$hpSectionId}" 
			class="wcr-search mainsearchresultscontrol"
			>
			<!-- 
				NEW Search Architecture...
			
				This textarea contains the complete search setup as JSON 
				(communicated forward and back between server &amp; client)
			-->
			<textarea style="display:none;" name="searchSetupModel"><xsl:value-of select="/webcenter_page/searchdata/searchsetupdatajson"/></textarea>
		
			<!-- Loading indicator -->
			<div class="loadingcontainer"><center><img src="images/loaderTransparent.gif" alt="{Lang:getStr(&lk;,'LOADINGINPROGRESS')}"/></center></div>
			
			<!-- 
				# Placeholders #
				
				In these placeholders the functionality will be initialized.
				
				The dashboard will then later move these placeholders to different places inside the dashboard.
				
				FUTURE: Simply generate these placeholders in the code. There is no real reason why this should happen in xsl... 
				(makes it less flexible -> can only have the component once (only one placeholder) and cannot easily be re-used on different search pages => have to duplicate the placeholders to different xsl files)
			-->
			<xsl:if test="not(/webcenter_page/search_re_run)">
				<div class="searchplaceholders" style="display:none;">
					
					<!-- Placeholder for the attribute category that we need to load -->
					<table>
					 	<tbody class="attributecategorycells">
					 	
					 		<!-- HERE we will put some hidden cells to attach the Attribute Category object, which will handle cascading dropdowns -->
					 		
			          	</tbody>
					</table>
				
					<!-- Placeholder for the top parameter panel -->
					<xsl:call-template name="searchResultsSavedSearchParms"/>

				</div>
			</xsl:if>
		
			<!-- 
				This table contains the actual search results (+ dashboard).
				
				.searchloadingarea => only becomes visible when loaded
			 -->
			<div width="100%" class="searchloadingarea" style="display:none;">
			  <div class="searchdashboardcontainer">
			    
			    <div width="100%" class="searchreruncontainer" data-additionalfielddata="{/webcenter_page/searchdata/resultsjson/additionaldata}">
				  <xsl:choose>
				  	<xsl:when test="/webcenter_page/result_count=0">
						<xsl:call-template name="searchNoResultsMessage"/>
				    </xsl:when>
				    <xsl:when test="/webcenter_page/search_error_message">
				      <table width="100%" cellspacing="0" cellpadding="0" border="0">	
						<xsl:call-template name="searchErrorMessage">
							<xsl:with-param name="error"><xsl:value-of select="/webcenter_page/search_error_message"/></xsl:with-param>
						</xsl:call-template>
					  </table>
				    </xsl:when>
				    <xsl:otherwise>
		    			<form name="{$actionFormName}" class="searchresultsactionform" method="post" action="doprojectmgmntactions.jsp" style="margin: 0px; padding: 0px;">
							<input type="hidden" name="actionVal" value=""/>
							<xsl:call-template name="SourcePageGenerateInputs">
							</xsl:call-template>
							<input type="hidden" name="projectID" value=""/>
							<input type="hidden" name="folderID" value="" />
							<input type="hidden" name="actionDocVerID" value=""/>
							<input type="hidden" name="actionDocID" value=""/>
							<!-- grid or list style -->
							<xsl:choose>
								<xsl:when test="$resultsStyle='grid'">
									<xsl:call-template name="GridStyleResultsTable">
										<xsl:with-param name="showActions" select="$showActions"/>
										<xsl:with-param name="stickyActions" select="$stickyActions"/>
										<xsl:with-param name="withShowHideThumbnailsButton" select="$withShowHideThumbnailsButton"/>
									</xsl:call-template>
								</xsl:when>
								<xsl:otherwise>
									<xsl:call-template name="ListStyleResultsTable">
										<xsl:with-param name="showActions" select="$showActions"/>
										<xsl:with-param name="stickyActions" select="$stickyActions"/>
										<xsl:with-param name="hpSectionId" select="$hpSectionId"/>
										<xsl:with-param name="withShowHideThumbnailsButton" select="$withShowHideThumbnailsButton"/>
									</xsl:call-template>
								</xsl:otherwise>
							</xsl:choose>
						</form>
					</xsl:otherwise>
				</xsl:choose>
			</div>
		</div>
	  </div>
	</div>
	</xsl:template>

	<!-- The results table for Grid style -->
	<xsl:template name="GridStyleResultsTable">
		<xsl:param name="showActions"/>
		<xsl:param name="stickyActions"/>	
		<xsl:param name="withShowHideThumbnailsButton"/>
		<!-- parameters of this layout -->
		<xsl:variable name="colsPerPage" select="number(/webcenter_page/cols_per_page)"/>
		<xsl:variable name="rowsPerPage" select="number(/webcenter_page/rows_per_page)"/>
		<xsl:variable name="showThumbnails" select="number(/webcenter_page/show_thumbnails)"/>
		<xsl:variable name="resultsStyle" select="/webcenter_page/results_style"/>
		
		<!-- table component -->
		<!-- data-checkbox-selector="input[name='selectproject']" -->
		<!-- ^^ above does not work with tables in tables (which is used in search) + does not work with "grid" -->
        <div class="wcr-table no-margin wcr161_apply_floatingscroll" data-init-whensearchready="component/table/Table">
	        <div class="wcr-table-filter">
	            <div>
	            	<xsl:attribute name="class">wcr-table-actions-row <xsl:if test="not($stickyActions = 'true')">no-sticky-actions</xsl:if></xsl:attribute>
	            	<div class="quick-filter">
			            <!-- sorting dropdown -->
			            <xsl:call-template name="SearchResultsSortByDropdown"/>
		            </div>
	            	<!-- actions -->
	            	<xsl:call-template name="ResultsTableActionMenu">
	            		<xsl:with-param name="showActions" select="$showActions"/>
	            		<xsl:with-param name="showSelectAction" select="true()"/>
	            	</xsl:call-template>
	            </div>
	        </div>
	        
	        <!-- actual table -->
	        <div class="wcr-table-section"><!-- begin of table section -->
				<table class="ordtable searchresultstable gridview" width="100%"
					data-showThumbnails="{$showThumbnails}"
					data-resultsStyle="{$resultsStyle}">
					<tbody>
						<xsl:for-each select="search_result_id_list/search_result_id">
							<xsl:call-template name="GridStyleResultsTableCell">
								<xsl:with-param name="colsPerPage" select="$colsPerPage"/>
								<xsl:with-param name="showThumbnails" select="$showThumbnails"/>																							
							</xsl:call-template>
						</xsl:for-each>
					</tbody>
				</table>
  			</div><!-- end of table section -->
  			
			<!-- footer of the table -->
			<xsl:call-template name="ResultsTableFooter">
				<xsl:with-param name="withShowHideThumbnailsButton" select="$withShowHideThumbnailsButton" />
			</xsl:call-template>
				
  		</div><!-- end of table component -->
	</xsl:template>

	<!-- template that controls the generation of a project link in a grid format -->
	<xsl:template name="GridStyleResultsTableCell">
		<xsl:param name="showThumbnails" select="'0'"/>
		<xsl:param name="colsPerPage" />
				
		<xsl:variable name="resultIndex" select="position() + number(/webcenter_page/start_search_id) - 1"/>
		<xsl:variable name="project" select="key('projectKey', .)"/>
		<xsl:variable name="hrefValue">
			<xsl:call-template name="searchProjectDetailsHrefValue">
				<xsl:with-param name="projectID" select="$project/@id"/>
				<xsl:with-param name="resultIndex" select="$resultIndex"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="colCount1" select="floor(number(99) div number($colsPerPage))"/>
		<xsl:variable name="colCount2" select="$colCount1 + (99 mod number($colsPerPage))"/>
	
		<!-- All cells in the table divide the total width equally... -->
		<xsl:variable name="cellwidth" select="concat(floor(100 div $colsPerPage),'%')"/>
		
		<!-- Value align -->
		<xsl:variable name="valueAlign">
			<xsl:choose>
				<!-- when we are showing the labels: align left -->
				<xsl:when test="$colsPerPage &lt; '6' and not(/webcenter_page/search_criteria/displayPreferences/chkbox_ShowLabels='0')">
					<xsl:value-of select="'left'"/>
				</xsl:when>
				<!-- when we are not showing any labels: center -->
				<xsl:otherwise>
					<xsl:value-of select="'center'"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<xsl:if test = "(position()-1) mod number($colsPerPage)=0" >
			<xsl:choose>
				<xsl:when test="((number($resultIndex)-1) div number($colsPerPage)) mod 2 = 1">
 					<xsl:text disable-output-escaping="yes">&lt;tr class="alt"&gt;</xsl:text>
 				</xsl:when>
 				<xsl:otherwise>
 					<xsl:text disable-output-escaping="yes">&lt;tr&gt;</xsl:text>
 				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
		<td valign="top" align="center" width="{$cellwidth}">
			<xsl:choose>
				<xsl:when test="position() mod number($colsPerPage)=0">
					<xsl:attribute name="width"><xsl:value-of select="number($colCount2)"/>%</xsl:attribute>
				</xsl:when>
				<xsl:otherwise>
					<xsl:attribute name="width"><xsl:value-of select="number($colCount1)"/>%</xsl:attribute>
				</xsl:otherwise>
			</xsl:choose>
			<!-- Only show the row if we were able to retrieve the details. This might happen if it was deleted before the crawl. -->
			<xsl:if test="$project">
				<!-- For Grid View -->
				<table border="0" bordercolor="#334444" cellspacing="0" cellpadding="0" width="100%" class="searchresultsrow">
					<!-- 
					  New Search Architecture...
					  All data for this item gets passed to the JavaScript side. 
					-->
					<xsl:attribute name="data-rowdisplaydata">
						<xsl:value-of select="/webcenter_page/searchdata/resultsjson/result[@id=($project/@id)]"/>
					</xsl:attribute>
					<!-- 
					  Some values are currently still generated and needed in the xsl.
					  To not generate them twice, we will keep those values in the xsl for now and simply pass them to the JS side.
					-->
					<xsl:attribute name="data-xslgen-thumbhref"><xsl:value-of select="$hrefValue"/></xsl:attribute>
					<!-- end -->
					
					<tr>
						<td>
							<img border="0" src="images/clearpixel.gif" alt="" width="1" height="5"/>
						</td>
					</tr>
					<xsl:if test="$showThumbnails = 1">
						<tr valign="top">
							<td valign="top" align="center" class="datacell" data-fieldid="thumbnail">
								<!-- the content will be put here... -->
							</td>
						</tr>
					</xsl:if>
					
					<!-- Checkbox for Grid view in project, only for admin users  -->					
					<tr>
						<td align="center" valign="top">
							<img border="0" src="images/clearpixel.gif" alt="" width="5" height="1"/>
							<input type="checkbox">
								<xsl:attribute name="name">
									<xsl:value-of select="'selectproject'"/>
								</xsl:attribute>									
								<xsl:attribute name="value">
									<xsl:value-of select="$project/@id"/>
								</xsl:attribute>
								<xsl:attribute name="projectid">
								  <xsl:value-of select="$project/@id"/>
								</xsl:attribute>	
								<xsl:attribute name="duedate">
								  <xsl:value-of select="$project/@id"/>
								</xsl:attribute>	
								<xsl:attribute name="fullname">  <!-- for feedback dialog of search result operations TO DO Encoding-->
									<xsl:value-of select="$project/name"/>
								</xsl:attribute>
							</input>
						</td>
					</tr>
					
					<tr>
						<td valign="top" align="center">
								
							<div class="searchgridinformationtable showastable">
								
								<!--  Name of the project -->
								<div class="gridinforow">
									<xsl:if test="$colsPerPage &lt; '6'">
										<div class="gridinfolabel" align="right">
											<xsl:call-template name="searchResultsGridLabel">
											  	<xsl:with-param name="columnName" select="'db_name'"/>
	 												<xsl:with-param name="langKey" select="'NAME'"/>																						
											</xsl:call-template>
										</div>
									</xsl:if>
									<div class="gridinfocontent" align="{$valueAlign}">
										<a>
											<xsl:attribute name="href">
												<xsl:value-of select="$hrefValue"/>
											</xsl:attribute>
											<xsl:value-of select="$project/name"/>
										</a>
									</div>
								</div>
				
								<!-- 
									Write all the rows with information...
								-->
								
								<xsl:for-each select="/webcenter_page/searchdata/columns/column">
									<xsl:sort data-type="number" order="ascending" select="@sequence"/>
									<xsl:variable name="fieldid" select="@id"/>
									
									<div class="gridinforow">
										<xsl:if test="$colsPerPage &lt; '6'">
											<div class="gridinfolabel" align="right">
												<xsl:call-template name="searchResultsGridLabel">
													<xsl:with-param name="columnName" select="$fieldid"/>
													<xsl:with-param name="fullString" select="@label"/>
												</xsl:call-template>
											</div>
										</xsl:if>	
										<div class="gridinfocontent" align="{$valueAlign}">
											<!-- Display using javascript... -->
											<div class="datacell" data-fieldid="{$fieldid}">
												<!-- the content will be put here... -->
											</div>
										</div>
									</div>
				                    
								</xsl:for-each>
								
							</div>
							
						</td>
					</tr>
				</table>
			</xsl:if>
		</td>
		<xsl:if test = "position()=last() and (position() mod number($colsPerPage)!=0)">
			<td>
				<xsl:attribute name="colspan">
					<xsl:value-of select="number($colsPerPage) - (position() mod number($colsPerPage))"/>
				</xsl:attribute>
			</td>
		</xsl:if>
		<xsl:if test="position() mod number($colsPerPage)=0 or position()=last()">
			<xsl:text disable-output-escaping="yes">&lt;/tr &gt;</xsl:text>
		</xsl:if>
	</xsl:template>
	
	
		<!-- 
  
            template that displays the project result row
            
	-->
	<xsl:template name="ListStyleResultsTable">
		<xsl:param name="showActions"/>
		<xsl:param name="stickyActions"/>
		<xsl:param name="hpSectionId"/>		
		<xsl:param name="withShowHideThumbnailsButton"/>
		
		<!-- parameters of this layout -->
		<xsl:variable name="showThumbnails" select="number(/webcenter_page/show_thumbnails)"/>
		<xsl:variable name="resultsStyle" select="/webcenter_page/results_style"/>
		
		<!-- table component -->
        <div class="wcr-table no-margin wcr161_apply_floatingscroll" data-init-whensearchready="component/table/Table">
        	<xsl:attribute name="data-checkbox-selector">input[data-hpSectionId='<xsl:value-of select="$hpSectionId"/>'][name='selectproject']</xsl:attribute>
        	<!-- Check whether the action menu bar needs to be shown. Do we have actions to display? + Do we display actions? -->
         	<xsl:variable name="hasTableBarActionsInMenu"><xsl:call-template name="ResultTableActionMenuHasMenuItems"/></xsl:variable>
         	<xsl:variable name="showTableActionBar" select="$showActions = '1' and $hasTableBarActionsInMenu = 'true'"/>
         	
         	<xsl:if test="$showTableActionBar">
		        <div class="wcr-table-filter">
		            <div>
		            	<xsl:attribute name="class">wcr-table-actions-row no-filter <xsl:if test="not($stickyActions = 'true')">no-sticky-actions</xsl:if></xsl:attribute>
		            	<!-- actions -->
		            	<xsl:call-template name="ResultsTableActionMenu">
		            		<xsl:with-param name="showActions" select="true()"/>
		            		<xsl:with-param name="showSelectAction" select="false()"/>
		            	</xsl:call-template>
		            </div>
		        </div>
		    </xsl:if>
	        
	        <!-- actual table -->
	        <div class="wcr-table-section"><!-- begin of table section -->
				<table class="ordtable searchresultstable" width="100%" id="SearchResultsTable"
					data-showThumbnails="{$showThumbnails}"
					data-resultsStyle="{$resultsStyle}">
					<thead>
						<!-- Column headers -->
						<tr class="searchResultsHeader">
							<th class="td-checkbox"><input type="checkbox" name="selectAllDoc" data-toggle-all="1"/></th>
				
							<xsl:call-template name="ThumbnailNameHeader2">
								<xsl:with-param name="showThumbnails" select="$showThumbnails"/>
								<xsl:with-param name="menuName"><xsl:call-template name="menuName"/></xsl:with-param>
							</xsl:call-template>
				
							<!-- All other headers... -->
							<xsl:for-each select="/webcenter_page/searchdata/columns/column">
								<xsl:sort data-type="number" order="ascending" select="@sequence"/>
								
								<xsl:call-template name="SearchResultsColumnHeader">
									<xsl:with-param name="columninfo" select="."/>
								</xsl:call-template>
								
							</xsl:for-each>
							
						</tr>
					</thead>

					<!-- Table contents -->
					<tbody>
						<xsl:for-each select="search_result_id_list/search_result_id">  <!-- for each search result -->
							<xsl:call-template name="ListStyleResultsTableContentRow">
								<xsl:with-param name="showThumbnails" select="$showThumbnails"/>
								<xsl:with-param name="stickyActions" select="$stickyActions"/>
								<xsl:with-param name="hpSectionId" select="$hpSectionId"/>
							</xsl:call-template>
						</xsl:for-each>
					</tbody>
				</table>
		
  			</div><!-- end of table section -->
  			
			<!-- footer of the table -->
			<xsl:call-template name="ResultsTableFooter">
				<xsl:with-param name="withShowHideThumbnailsButton" select="$withShowHideThumbnailsButton"/>
			</xsl:call-template>
  			
  		</div><!-- end of table component -->
	</xsl:template>

	
	<!-- 
  
            template that controls the generation of a project link in a row format
	-->
	<xsl:template name="ListStyleResultsTableContentRow">
		<xsl:param name="showThumbnails" select="'0'"/>
		<xsl:param name="hpSectionId" />

		<xsl:variable name="resultIndex" select="position() + number(/webcenter_page/start_search_id) - 1"/>
		<xsl:variable name="project" select="key('projectKey', .)"/>
		
		<xsl:variable name="hrefValue">
			<xsl:call-template name="searchProjectDetailsHrefValue">
				<xsl:with-param name="projectID" select="$project/@id"/>
				<xsl:with-param name="resultIndex" select="$resultIndex"/>
			</xsl:call-template>
		</xsl:variable>
		
		<!-- Only show the row if we were able to retrieve the details. This might happen if it was deleted before the crawl. -->
		<xsl:if test="$project">
			<tr>
				<!-- 
				  New Search Architecture...
				  All data for this row gets passed to the JavaScript side. 
				-->
				<xsl:attribute name="data-rowdisplaydata">
					<xsl:value-of select="/webcenter_page/searchdata/resultsjson/result[@id=($project/@id)]"/>
				</xsl:attribute>
				<!-- 
				  Some values are currently still generated and needed in the xsl.
				  To not generate them twice, we will keep those values in the xsl for now and simply pass them to the JS side.
				-->
				<xsl:attribute name="data-xslgen-thumbhref"><xsl:value-of select="$hrefValue"/></xsl:attribute>
				<!-- end -->
				
				<xsl:attribute name="class">searchresultsrow<xsl:if test="position() mod 2 = 0"> alt</xsl:if></xsl:attribute>
				
				<!-- First col, show the toggle selection -->
				<xsl:call-template name="ToggleThisProject">
					<xsl:with-param name="docVerID" select="$project/@id"/>
					<xsl:with-param name="docName" select="$project/name"/>
					<xsl:with-param name="checkBoxName" select="'selectproject'"/>
					<xsl:with-param name="attributecategoryid" select="$project/category_id"/>
					<xsl:with-param name="duedate" select="$project/due_date"/>
					<xsl:with-param name="statusID" select="$project/status_id"/>					
					<xsl:with-param name="hpSectionId" select="$hpSectionId"/>				
				</xsl:call-template>
				
				
				<!-- Thumbnail and name -->
				<xsl:call-template name="DisplayThumbnailName">
					<xsl:with-param name="showThumbnails" select="$showThumbnails"/>
					<xsl:with-param name="hrefValue" select="$hrefValue"/>
					<xsl:with-param name="urlKeyName" select="$project"/>
					<xsl:with-param name="useThumbnailCellHtml" select="'1'"/>
					<xsl:with-param name="thumbnailCellHtml">
						<td valign="middle" width="56" class="datacell" data-fieldid="thumbnail">
							<!-- the content will be put here... -->
						</td>
					</xsl:with-param>
					<xsl:with-param name="useDrilldown" select="/webcenter_page/search_criteria/displayPreferences/chkbox_ShowDrillDownColumn = '1'"/>
					<xsl:with-param name="drilldownCell">
						    <div class="datacell drilldown" data-fieldid="drilldown">
						          <!-- the content will be put here... -->
						    </div>
					</xsl:with-param>
					
				</xsl:call-template>
				
				<!-- Handle custom Display Criteria columns -->
				<xsl:for-each select="/webcenter_page/searchdata/columns/column">
					<xsl:sort data-type="number" order="ascending" select="@sequence"/>
					
					<xsl:call-template name="SearchResultsCell">
						<xsl:with-param name="id" select="./@id"/>
						<xsl:with-param name="typeclass" select="./@typeclass"/>
					</xsl:call-template>

				</xsl:for-each>
			</tr>
			
			<tr class="expandablerow" style="display:none">
			 	<xsl:if test="position() mod 2 = 0">
					<xsl:attribute name="class"><xsl:value-of select="'expandablerow alt'"/></xsl:attribute>
				</xsl:if>
			 	
			 	<xsl:variable name="detailsColspan" select="count(/webcenter_page/search_criteria//column_display_criterion) + 1 + count(/webcenter_page/search_criteria/displayPreferences/chkbox_ShowDrillDownColumn[.='1'])"/>
				
				<td/>
				<td colspan="{$detailsColspan}" class="contentcell">
				</td>
			</tr>
		</xsl:if>
	</xsl:template>
	
	<!-- The items in the action menu -->
	<xsl:template name="ResultsTableActionMenu">
	    <xsl:param name="showActions" select="'1'"/>
        <xsl:param name="showSelectAction" select="false()"/>
        
		<div class="action-menu-component"
	        data-init-whensearchready="component/actionmenu/ActionMenu">
	        <xsl:if test="$showSelectAction">
	        	<xsl:call-template name="selectallaction"/>
	        </xsl:if>
	        <xsl:if test="$showActions='1'">
	        	<xsl:call-template name="ResultsTableActionMenuItems"/>
	        </xsl:if>
	    </div>
	</xsl:template>
	
	<!-- Whether there are items to display in the action menu -->
	<xsl:template name="ResultTableActionMenuHasMenuItems">
		<!-- 
          Simple check to see if we need to show the action bar... 
          We could have done more checks here but we don't think it is worth it vs the effort of maintaining it.
        -->
        <xsl:value-of select="count(key('menuItemKey', 'PROJ_SEARCHRESULTS_LIST_ACTIONS')/menuitem)>0"/>
	</xsl:template>
	
	<!-- The items in the action menu -->
	<xsl:template name="ResultsTableActionMenuItems">
		<xsl:for-each select="key('menuItemKey', 'PROJ_SEARCHRESULTS_LIST_ACTIONS')/menuitem">
			<!-- get the unique id of this customized menu item -->
			<xsl:variable name="customizedMenuItem" select="."/>
			
			<!-- check if this is a builtin action -->
			<xsl:if test="action/actiontype/builtin/builtin_name">
		
				<!-- which type of builtin action? -->
				<xsl:variable name="id" select="action/actiontype/builtin/builtin_name"/>
			
				<!-- run through all the search actions that work on this type of menu item -->
				<xsl:for-each select="/webcenter_page/searchdata/actionmenu/menuitem[@id=$id]">
					<!-- get the label or allow customization by menu -->
					<xsl:variable name="label">
						<xsl:choose>
							<xsl:when test="@label"><xsl:value-of select="@label"/></xsl:when>
							<xsl:otherwise><xsl:value-of select="Lang:getStr(&lk;,$customizedMenuItem/labeltag)"/></xsl:otherwise>
						</xsl:choose>
					</xsl:variable>
				
					<!-- add the builtinaction -->
					<xsl:call-template name="builtinaction">
						<xsl:with-param name="menuitem" select="$customizedMenuItem"/>
						<xsl:with-param name="name" select="@id"/>
						<xsl:with-param name="action" select="@action"/>
						<xsl:with-param name="label" select="$label"/>
						<xsl:with-param name="jsonoptions" select="@actionconfig"/>
					</xsl:call-template>
				</xsl:for-each>
			</xsl:if>

			<xsl:if test="not(/webcenter_page/search_criteria/displayPreferences/chkbox_CustomActions = '0')">
				<xsl:call-template name="startworkflowaction">
					<xsl:with-param name="itemidsel" select="'value'"/>
					<xsl:with-param name="itemidname" select="'projectid'"/>
			 		<xsl:with-param name="tags"><xsl:call-template name="GetActionMenuTagsFromSearch"/></xsl:with-param>
				</xsl:call-template>
			 	<xsl:call-template name="javascriptaction">
					<xsl:with-param name="itemidsel" select="'value'"/>
			 		<xsl:with-param name="tags"><xsl:call-template name="GetActionMenuTagsFromSearch"/></xsl:with-param>
				</xsl:call-template>
			</xsl:if>
			
			<!-- The children delete option should only be shown in saved searches regarding children => 
			 a context is necessary -->
			<xsl:if test="/webcenter_page/search_context/project_context and (/webcenter_page/is_admin or /webcenter_page/project_user_permissions/permission/update = '1') and /webcenter_page/search_criteria/displayPreferences/chkbox_DeleteChildProject = '1'">
				<xsl:call-template name="builtinaction">
					<xsl:with-param name="name" select="'PROJ_SEARCHRESULTS_DELETE_CHILD'"/>
					<xsl:with-param name="action" select="'UnlinkChildProject'"/>
					<xsl:with-param name="jsonoptions">{"projectId": <xsl:value-of select="XSLUtils:encodeJSONString(/webcenter_page/search_context/project_context)"/>, "successMessage" :"<xsl:value-of select="Lang:getStr(&lk;,'ON_LINK_DELETED')"/>" }</xsl:with-param>
				</xsl:call-template>
			</xsl:if>
			
		</xsl:for-each>

			
    </xsl:template>
    
    <!-- 
    	Footer of the results table
     -->
    <xsl:template name="ResultsTableFooter">
    	<xsl:param name="withShowHideThumbnailsButton" select="true()"/>
   		<!-- table footer -->
		<div class="wcr-table-footer">
			<div class="wcr-table-paging">
				<xsl:call-template name="SearchResultsPager"/>
			</div>
			<div class="wcr-table-results">
				<xsl:call-template name="SearchResultsCountDisplay"/>
			</div>
			<div class="wcr-table-view-options">
				<xsl:call-template name="SearchResultsToggleResultsStyleButton">
					<xsl:with-param name="supportsGridMode" select="true()"/>
					<xsl:with-param name="supportsCardMode" select="false()"/>
				</xsl:call-template>
				
				<xsl:if test="$withShowHideThumbnailsButton = 'true'">
                	<xsl:call-template name="SearchResultsShowHideThumbnailsButton"/>
                </xsl:if>
                
             </div>
		</div>
    </xsl:template>
    
    <!-- 
		Which page is this? 
			= used when submitting a search action from the menu
	-->
	<xsl:template name="SourcePageGenerateInputs">
		<xsl:variable name="sourcePageWithoutIndices">
			<xsl:choose>
				<xsl:when test="/webcenter_page/Source_URL"><xsl:value-of select="/webcenter_page/Source_URL"/></xsl:when>			
				<xsl:when test="count(/webcenter_page/search_context/project_context)=1">dosavedsearch.jsp?searchName=<xsl:value-of select="XSLUtils:urlEncode(/webcenter_page/saved_search_name)"/>&amp;menuitem3=<xsl:value-of select="nav/menu3/@menuitemname"/>&amp;menusel3=<xsl:value-of select="nav/menu3/@selected"/>&amp;projectID=<xsl:value-of select="search_context/project_context"/>&amp;menu_file=<xsl:value-of select="/webcenter_page/menu_file"/></xsl:when>
				<xsl:when test="count(/webcenter_page/search_context/docversion_context)=1">dosavedsearch.jsp?searchName=<xsl:value-of select="XSLUtils:urlEncode(/webcenter_page/saved_search_name)"/>&amp;menuitem3=<xsl:value-of select="nav/menu3/@menuitemname"/>&amp;menusel3=<xsl:value-of select="nav/menu3/@selected"/>&amp;docVerID=<xsl:value-of select="search_context/docversion_context"/>&amp;menu_file=<xsl:value-of select="/webcenter_page/menu_file"/></xsl:when>
				<xsl:when test="string-length(/webcenter_page/hp_section_id) &gt; 0">mytodolist.jsp</xsl:when>
				<xsl:otherwise>projsearchresults.jsp</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		<!-- 
			Calculating information for the sourcePage url
			Note: code duplicated in all xsl templates starting with "SourcePage" in the name. 
		-->
		
		<xsl:variable name="resultsStyle" select="/webcenter_page/results_style"/>
		<xsl:variable name="showThumbnails" select="number(/webcenter_page/show_thumbnails)"/>

		<!-- Which page (as in paging) are we on? -->
		<xsl:variable name="colsPerPage" select="number(/webcenter_page/cols_per_page)"/>
		<xsl:variable name="rowsPerPage" select="number(/webcenter_page/rows_per_page)"/>
		<xsl:variable name="resultsPerPage" select="number($rowsPerPage * $colsPerPage)"/>
		
		<!-- pagination logic (duplicated code, can be found in "SearchResultsPager" and "SourcePage*" templates) -->
		<xsl:variable name="firstIndex" select="number(/webcenter_page/start_search_id)"/>
		<xsl:variable name="curPageNumMin" select="ceiling($firstIndex div $resultsPerPage)"/>
		<xsl:variable name="curPageNum">
			<xsl:choose>
				<xsl:when test="($firstIndex &gt; 1) and ($curPageNumMin &lt; 2)">
					<xsl:value-of select="2"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$curPageNumMin"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
 		<xsl:variable name="startIndex" select="$firstIndex"/>
  		<xsl:variable name="endIndex" select="number($curPageNum) * $resultsPerPage"/>
		
		<!-- make the inputs -->
		<input type="hidden" name="sourcePage"><xsl:attribute name="value"><xsl:value-of select="$sourcePageWithoutIndices"/></xsl:attribute></input>
		<input type="hidden" name="showThumbnails" value="{$showThumbnails}"/>
		<xsl:call-template name="menuFileHiddenInput"/>
		<input type="hidden" name="resultsStyle" value="{$resultsStyle}"/>
	</xsl:template>

	<!-- 
  
            template that controls the generation of a project link.
			Warning! Do not put a space in front of projectdetails.jsp 
			
	-->
	<xsl:template name="searchProjectDetailsHrefValue">
		<xsl:param name="projectID"/>
		<xsl:param name="resultIndex"/>
	    <xsl:variable name="showSimpleGUI" select="/webcenter_page/showSimpleGUI"/>
		<xsl:choose>
			<xsl:when test="$showSimpleGUI='1'">javascript:ShowProjectDetails('<xsl:value-of select="$projectID"/>');</xsl:when>
			<xsl:when test="count(/webcenter_page/saved_search_name)=0">projdetails.jsp?projectSearchIndex=<xsl:value-of select="$resultIndex"/>&amp;searchProjectID=<xsl:value-of select="$projectID"/>&amp;<xsl:call-template name="menuFileUrlParameter"/></xsl:when>
			<xsl:otherwise>projdetails.jsp?projectID=<xsl:value-of select="$projectID"/>&amp;<xsl:call-template name="menuFileUrlParameter"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="ThumbnailNameHeader2">
		<xsl:param name="showThumbnails"/>
		<xsl:param name="menuName" select="'menu'"/>
		<xsl:param name="columnName" select="'db_name'"/>
  		<xsl:param name="langKey" select="'NAME'"/>

	    <th align="left" data-columnid="{$columnName}">
   		    <xsl:call-template name="addSearchResultsColumnSortingAttributes">
  	   		  <xsl:with-param name="columnName" select="$columnName"/>
     		</xsl:call-template>
     		
			<xsl:choose>
				<xsl:when test="key('labelKey',$columnName)/label"> 
					<xsl:value-of select="key('labelKey',$columnName)/label"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="Lang:getStr(&lk;,$langKey)"/>
				</xsl:otherwise>
		    </xsl:choose>
		    
		    <xsl:text> </xsl:text><xsl:call-template name="SearchResultsCountBadge"></xsl:call-template><i class="icon-sorting"/>
		</th>
	</xsl:template>

	<xsl:template name="ToggleThisProject">
		<xsl:param name="docVerID"/>
		<xsl:param name="docName"/>
		<xsl:param name="attributecategoryid"/>
		<xsl:param name="checkBoxName" select="selectedDocs"/>
		<xsl:param name="hpSectionId"/>
		<xsl:param name="duedate" select="''"/>
		<xsl:param name="statusID" select="''" />

		<td class="td-checkbox">
			<input type="checkbox">
				<xsl:attribute name="name">
					<xsl:value-of select="$checkBoxName"/>
				</xsl:attribute>
				<xsl:attribute name="value">
					<xsl:value-of select="$docVerID"/>
				</xsl:attribute>
				<xsl:attribute name="projectid">
					<xsl:value-of select="$docVerID"/>
				</xsl:attribute>
				<xsl:attribute name="fullname">
					<xsl:value-of select="$docName"/>
				</xsl:attribute>
				<xsl:attribute name="attributecategoryid">
					<xsl:value-of select="$attributecategoryid"/>
				</xsl:attribute>
				<xsl:attribute name="duedate">
					<xsl:value-of select="$duedate"/>
				</xsl:attribute>
				<xsl:attribute name="statusid">
					<xsl:value-of select="$statusID"/>
				</xsl:attribute>				
				<xsl:attribute name="data-hpSectionId">
					<xsl:value-of select="$hpSectionId"/>
				</xsl:attribute>	
			</input>
		</td>
	</xsl:template>

	<!-- 	
            template that controls the inclusion of javascript functionality used in both normal page and hp section
            called from scriptincs_hp_section	
	-->
	<xsl:template name="scriptincs_common">
		<xsl:variable name="menuName"><xsl:call-template name="menuName"/></xsl:variable>
		<xsl:variable name="actionFormName"><xsl:call-template name="actionFormName"/></xsl:variable>
		
		<xsl:call-template name="SearchLangArr"/>
		
		function SubmitBOMSingleDocumentAction(actionVal, docVerID, docID, folderID, projectID) 
		{
			document.<xsl:value-of select="$actionFormName"/>.actionVal.value = actionVal;
			document.<xsl:value-of select="$actionFormName"/>.actionDocVerID.value = docVerID;
			document.<xsl:value-of select="$actionFormName"/>.actionDocID.value = docID;
			document.<xsl:value-of select="$actionFormName"/>.folderID.value = folderID;
			document.<xsl:value-of select="$actionFormName"/>.projectID.value = projectID;
			document.<xsl:value-of select="$actionFormName"/>.submit();
		}
	</xsl:template>
	
	<!-- 
  
            template that controls the inclusion of javascript functionality 
            
	-->
	<xsl:template name="ProjSearchResultsJavaScript">
		<xsl:call-template name="jqueryUIScriptImports" />&#xA; 
		<xsl:call-template name="doctemplatesJavaScript"/>&#xA;
		<xsl:call-template name="DateJavaScript"/>&#xA;
		<style>
		#ui-datepicker-div
        {
        z-index: 9999999 !important;
        }
		</style>		
		<script src="javascript/webcenter_xml.js" type="text/javascript"/>
		<script src="javascript/validate.js" type="text/javascript"/>
		<script src="javascript/detailswin.js" type="text/javascript"/>
		<script src="javascript/popup.js" type="text/javascript"/>
		<script src="javascript/hover.js" type="text/javascript"/>
		<script src="javascript/extpopup.js" type="text/javascript"/>
		<script src="javascript/webcenter_html.js" type="text/javascript"/>
		
		<xsl:call-template name="scriptincs_search_results"/>
		

		<script type="text/javascript">&#xA;//Contents for menu 1
		
		  <xsl:call-template name="SearchLangArr"/>
		  
		  <xsl:call-template name="RoleSearchLangArr" />

          function SaveSearch()
          {
            document.savesearchform.actionVal.value="SaveFromProjSearchResults";

            // post the request&#xA;
            document.savesearchform.submit();
          }
          
        
          function downloadsearchresult()
          {
			submitdownloadsearchresult("DownloadFromProjSearchResults");
          }
		  
			function SubmitBOMSingleDocumentAction(actionVal, docVerID, docID, folderID, projectID) 
			{
				document.actionform.actionVal.value = actionVal;
				document.actionform.actionDocVerID.value = docVerID;
				document.actionform.actionDocID.value = docID;
				document.actionform.folderID.value = folderID;
				document.actionform.projectID.value = projectID;
				document.actionform.submit();
			}

        </script>
          
	</xsl:template>
	
</xsl:stylesheet>
