<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE xsl:stylesheet [
  <!ENTITY copy "&#169;">
  <!ENTITY nbsp "&#160;">
  <!ENTITY lk "/webcenter_page/user_lang_key">
]>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:java="http://xml.apache.org/xslt/java" xmlns:XSLUtils="com.esko.webcenter.jsp.XSLUtils" xmlns:Lang="com.esko.webcenter.jsp.LanguageMgr" exclude-result-prefixes="XSLUtils Lang">
  <xsl:import href="template.xsl"/>
  <xsl:import href="templatedate.xsl"/>
  <xsl:import href="searchresultstemplate.xsl"/>
  <xsl:import href="projwctasktemplates.xsl"/>

  <xsl:template name="header"/>
  <xsl:template name="bodyheader">
	<!-- search results header -->
	<xsl:call-template name="searchResultsHeader"/>
  </xsl:template>

<!-- 
  
            template that controls the generation of the body content
            
-->
<xsl:template name="bodycontent">
	<!-- Form for re run of search -->
	<xsl:call-template name="SearchResultsStoredValues"/>
	
  <xsl:variable name="resultCount" select="number(result_count)"/>
  <xsl:variable name="resultsPerPage" select="number(rows_per_page)"/>  
  <xsl:variable name="pageCount" select="ceiling($resultCount div $resultsPerPage)"/>
  <xsl:variable name="curPageNum" select="ceiling(number(start_search_id) div $resultsPerPage)"/>
  <xsl:variable name="hpSectionId" select="/webcenter_page/hp_section_id"/>
  <xsl:variable name="showSimpleGUI" select="/webcenter_page/showSimpleGUI"/>

	<!--
	
		The search results javascript component
		
	 -->
	<div 
		data-init="component/searchresults/internal/SearchResultsControl" 
		data-searchdata="{/webcenter_page/searchdata/datajson}"
		data-hpsectionid="{$hpSectionId}" 
		data-rerunurl="{/webcenter_page/searchdata/saved_search_re_run_url}"
		id="searchresultscontrol{$hpSectionId}" 
		class="wcr-search mainsearchresultscontrol"
		>
		<!-- 
			NEW Search Architecture...
		
			This textarea contains the complete search setup as JSON 
			(communicated forward and back between server &amp; client)
		-->
		<textarea style="display:none;" name="searchSetupModel"><xsl:value-of select="/webcenter_page/searchdata/searchsetupdatajson"/></textarea>
		
		<!-- Loading indicator -->
		<div class="loadingcontainer"><center><img src="images/loaderTransparent.gif" alt="{Lang:getStr(&lk;,'LOADINGINPROGRESS')}"/></center></div>
		
		<!-- 
			# Placeholders #
			
			In these placeholders the functionality will be initialized.
			
			The dashboard will then later move these placeholders to different places inside the dashboard.
			
			FUTURE: Simply generate these placeholders in the code. There is no real reason why this should happen in xsl... 
			(makes it less flexible -> can only have the component once (only one placeholder) and cannot easily be re-used on different search pages => have to duplicate the placeholders to different xsl files)
		-->
		<xsl:if test="not(/webcenter_page/search_re_run)">
			<div class="searchplaceholders" style="display:none;">
					
				<!-- Placeholder for the attribute category that we need to load -->
				<table>
				 	<tbody class="attributecategorycells">
				 	
				 		<!-- HERE we will put some hidden cells to attach the Attribute Category object, which will handle cascading dropdowns -->
				 		
		          	</tbody>
				</table>
		
				<!-- Placeholder for the top parameter panel -->
				<xsl:call-template name="searchResultsSavedSearchParms"/>
			
			</div>
		</xsl:if>
	
		<!-- 
			This table contains the actual search results (+ dashboard).
			
			.searchloadingarea => only becomes visible when loaded
		 -->
		<div width="100%" class="searchloadingarea" style="display:none;">
		  	<div class="searchdashboardcontainer">
			
	  	<div width="100%" class="searchreruncontainer" data-additionalfielddata="{/webcenter_page/searchdata/resultsjson/additionaldata}">
		  <xsl:choose>
		  	<xsl:when test="/webcenter_page/result_count=0">
		      	<xsl:call-template name="searchNoResultsMessage"/>
		    </xsl:when>
		     <xsl:when test="/webcenter_page/search_error_message">
		     	<table width="100%" cellspacing="0" cellpadding="0" border="0">
					<xsl:call-template name="searchErrorMessage">
						<xsl:with-param name="error"><xsl:value-of select="/webcenter_page/search_error_message"/></xsl:with-param>
					</xsl:call-template>
				</table>
			</xsl:when>
		    <xsl:otherwise>
			  <xsl:variable name="sourcePage">
				<xsl:choose>
					<xsl:when test="$hpSectionId"><xsl:value-of select="'mytodolist.jsp'"/></xsl:when>
					<xsl:otherwise><xsl:value-of select="'wctasksearchresults.jsp'"/></xsl:otherwise>
				</xsl:choose>
			  </xsl:variable>
			  
			  <!-- List style -->
		  		<!--  Unused - we don't have any actions on tasks search results page yet...
				  <form name="{$actionFormName}" class="searchresultsactionform" method="post" action="???.jsp">
				        <input type="hidden" name="actionVal" value=""/>
				        <input type="hidden" name="projectID" value=""/>
				        <input type="hidden" name="sourcePage" value="wctasksearchresults.jsp"/>
						<input type="hidden" name="showThumbnails" value="0"/>
			  	-->
		  	
				  <xsl:call-template name="ListStyleResultsTable">
				    <xsl:with-param name="posOffset" select="$resultsPerPage * ($curPageNum - 1)"/>
					<xsl:with-param name="showSimpleGUI" select="$showSimpleGUI"/>
					<xsl:with-param name="sourcePage" select="$sourcePage"/>
				  </xsl:call-template>
				  
				<!-- Unused
				  </form>
				-->
	        </xsl:otherwise>
		  </xsl:choose>
	  </div>
	</div>
	</div>
	</div>
</xsl:template>


	<!--
	
      Displaying the Task Search Results Table!
	  
	  NOTE: Code branched off from projwctasktemplates.xsl:DisplayToDoListDetails
	  
  	-->
	<xsl:template name="ListStyleResultsTable">
		<xsl:param name="taskTag" select="'wc_task_list'"/>
		<xsl:param name="sort" select="0"/>
		<xsl:param name="posOffset"/>
		<xsl:param name="showRadioButton" select="false()"/>
		<xsl:param name="showSimpleGUI"/>
		<xsl:param name="sourcePage"/>


		<!-- table component -->
        <div class="wcr-table no-margin wcr161_apply_floatingscroll" data-init-whensearchready="component/table/Table" data-checkbox-selector="input[name='selectproject']">
        	<!-- Check whether the action menu bar needs to be shown. Do we have actions to display? + Do we display actions? -->
         	<xsl:variable name="hasTableBarActionsInMenu"><xsl:call-template name="ResultTableActionMenuHasMenuItems"/></xsl:variable>
         	<xsl:variable name="showTableActionBar" select="$hasTableBarActionsInMenu = 'true'"/>
         	
         	<xsl:if test="$showTableActionBar">
		        <div class="wcr-table-filter">
		            <div class="wcr-table-actions-row no-filter">
		            	<!-- actions -->
		            	<xsl:call-template name="ResultsTableActionMenu"/>
		            </div>
		        </div>
		    </xsl:if>
	        
	        <!-- actual table -->
	        <div class="wcr-table-section"><!-- begin of table section -->
				<table class="ordtable searchresultstable" width="100%" id="searchResultsTable"
					data-showThumbnails="1"
					data-resultsStyle="list">
					<!-- Write the header -->
					<thead>
					    <!-- Column headers -->
					    <tr>
							<th width="20" align="center">#</th>
							
							<!-- Task name is always the left most column -->
							<xsl:call-template name="ThumbnailNameHeader">
							  <xsl:with-param name="showThumbnails" select="false()" />  
							  <xsl:with-param name="langKey" select="'TASK'"/>
							</xsl:call-template>
							
							<!-- All other headers... -->
							<xsl:for-each select="/webcenter_page/searchdata/columns/column">
								<xsl:sort data-type="number" order="ascending" select="@sequence"/>
								
								<xsl:call-template name="SearchResultsColumnHeader">
									<xsl:with-param name="columninfo" select="."/>
								</xsl:call-template>
								
							</xsl:for-each>
							
						</tr>
					</thead>
					
					<!-- Table contents -->
					<tbody>
						<xsl:for-each select="search_results/wc_task_list/project_wctask">
							<xsl:call-template name="ListStyleResultsTableContentRow">
								<xsl:with-param name="projectWcTask" select="."/>																								
								<xsl:with-param name="icon" select="task_type_icon"/>												
								<xsl:with-param name="showSimpleGUI" select="$showSimpleGUI"/>
								<xsl:with-param name="sourcePage" select="$sourcePage"/>
							</xsl:call-template>
						</xsl:for-each>
					</tbody>
					
				</table>
  			</div><!-- end of table section -->
  			
			<!-- footer of the table -->
			<xsl:call-template name="ResultsTableFooter"/>
  			
  		</div><!-- end of table component -->
	</xsl:template>
	
	<!-- a row for the list style results table -->
	<xsl:template name="ListStyleResultsTableContentRow">
		<xsl:param name="projectWcTask"/>	
		<xsl:param name="icon" select="''"/>
		<xsl:param name="showSimpleGUI" select="'0'"/>
		<xsl:param name="sourcePage" select="'projdetailswctasks.jsp'"/>		
	
		<tr>
			<!-- 
			  New Search Architecture...
			  All data for this row gets passed to the JavaScript side. 
			-->
			<xsl:attribute name="data-rowdisplaydata">
				<xsl:value-of select="/webcenter_page/searchdata/resultsjson/result[@id=($projectWcTask/@id)]"/>
			</xsl:attribute>
			<!-- end -->
		
			<xsl:attribute name="class">searchresultsrow<xsl:if test="position() mod 2 = 0"> alt</xsl:if></xsl:attribute>

			<td class="darktext_darklink_11" align="center">
				<xsl:value-of select="position()"/>
			</td>

			<!-- Task name, always first column (with a link to the TEP page)-->
			<xsl:call-template name="ProjectWcTaskDetailsName">
				<xsl:with-param name="taskName" select="name"/>
				<xsl:with-param name="projectTaskID" select="@id"/>
				<xsl:with-param name="projectID" select="project_id"/>
				<xsl:with-param name="page" select="'wctaskexecutionpage.jsp'"/>
				<xsl:with-param name="icon" select="$icon"/>	
				<xsl:with-param name="sourcePage" select="$sourcePage"/>						
			</xsl:call-template>
				
			<!-- Handle custom Display Criteria columns -->
			<xsl:for-each select="/webcenter_page/searchdata/columns/column">
				<xsl:sort data-type="number" order="ascending" select="@sequence"/>
				
				<xsl:call-template name="SearchResultsCell">
					<xsl:with-param name="id" select="./@id"/>
					<xsl:with-param name="typeclass" select="./@typeclass"/>
				</xsl:call-template>

			</xsl:for-each>
		</tr>
	
	</xsl:template>

	<!-- The items in the action menu -->
	<xsl:template name="ResultsTableActionMenu">
		<div class="action-menu-component"
	        data-init-whensearchready="component/actionmenu/ActionMenu">
	        
	        <xsl:call-template name="ResultsTableActionMenuItems" />
	        
	    </div>
	</xsl:template>
	
	<!-- Whether there are items to display in the action menu -->
	<xsl:template name="ResultTableActionMenuHasMenuItems">
		
		<!-- We don't have any items in the action menu yet!!! -->		
		
        <xsl:value-of select="false()"/>
	</xsl:template>
	
	<!-- The items in the action menu -->
	<xsl:template name="ResultsTableActionMenuItems">
		
		
		<!-- We don't have any items in the action menu yet!!! -->
		
	    
    </xsl:template>
    
    <!-- 
    	Footer of the results table
     -->
    <xsl:template name="ResultsTableFooter">
   		<!-- table footer -->
		<div class="wcr-table-footer">
			<div class="wcr-table-paging">
				<xsl:call-template name="SearchResultsPager"/>
			</div>
			<div class="wcr-table-results">
				<xsl:call-template name="SearchResultsCountDisplay"/>
			</div>
		</div>
    </xsl:template>
    
 <!-- 
  
            template that controls the inclusion of javascript functionality 
            
-->
<xsl:template name="WCTaskSearchResultsJavaScript">
  <script src="javascript/webcenter_xml.js"/>&#xA;
  <script src="javascript/webcenter_html.js"/>&#xA;
  <script src="javascript/validate.js"/>&#xA;
  <script src="javascript/detailswin.js"/>&#xA;
  <script src="javascript/popup.js"/>&#xA;
  
  
  <xsl:call-template name="scriptincs_search_results"/>
  
  <script type="text/javascript">&#xA;
        function SaveSearch()
        {
          document.savesearchform.actionVal.value="SaveFromWctaskSearchResults";

          // post the request&#xA;
          document.savesearchform.submit();
        }
        function downloadsearchresult()
        {
		  submitdownloadsearchresult("DownloadFromWctaskSearchResults");
        }
        if (typeof window.langArr == "undefined" || window.langArr === null){
		  	window.langArr = {};
		  }
        	  <xsl:call-template name="i18n">
           <xsl:with-param name="keys">
              SEARCH_RESULTS_LOADING_FAILED
           </xsl:with-param>
           <xsl:with-param name="nested" select="1" />
           <xsl:with-param name="langVar" select="'langArr'"/>
       </xsl:call-template>
        
        
  </script>
</xsl:template>
  
</xsl:stylesheet>
  
