/**
		 * This is the entry point towards having an Approval setup page
		 * @param {string} displayId                   element used to render the approval
		 * @param {string} readURL                     url used to read information about approval
		 * @param {string} actionURL                   url used to store information
		 * @param {string} getProjectFolderSetupURL    url used to read project/folder approval setups
		 * @param {object} currentUser                 contains information about the logged in user
		 * @param {boolean} nextVersion                true if setup for next version is enabled
		 * @param {boolean} stagedApprovalAllowed      true if the license is available that allows to add stages
		 * @param {boolean} isViewFile                 true if file is viewable
		 * @param {boolean} isEncapsulated             true if the page should not reload when saving approval information
		 * @param {function} afterInitializationCallback callback that is called when approval has finished initializing
		 * @param {function} onUpdateCallback            callback tht is called whenever a client side change happens to the approval setup
		 */

define("approval/ApprovalConstants",[],function(){var b={STOPS_APPROVAL_IMMEDIATE:"RejectStopsApprovalImmediate",STOPS_APPROVAL_AFTER_STEP:"RejectStopsApprovalAfterStep",DOES_NOT_STOP:"RejectDoesNotStopApproval"},a={NO:"NoDueDates",FIXED:"FixedDueDates",LEAD_TIMES:"LeadTimes",LEAD_TIMES_WITH_FINAL_DATE:"LeadTimesFinalDueDate"};return{images:{ForceApproved:"icon icon-normal icon-WCR_ForceApprove",ForceApprovedConditional:"icon icon-normal icon-WCR_ApprovedConditional",ForceRejected:"icon icon-normal icon-WCR_ForceReject",
Approved:"icon icon-normal icon-WCR_Approved",ApprovedConditional:"icon icon-normal icon-WCR_ApprovedConditional",Rejected:"icon icon-normal icon-WCR_Rejected",Pending:"icon icon-normal icon-WCR_Pending",Approve:"icon icon-normal icon-WCR_Approved",Reject:"icon icon-normal icon-WCR_Rejected",Comment:"icon icon-normal icon-WCR_Comment",ForceApprove:"icon icon-normal icon-WCR_ForceApprove",ForceReject:"icon icon-normal icon-WCR_ForceReject",Spinner:"icon icon-normal icon-WCR_WF-Reload"},imageColors:{ForceApproved:"icon-green",
ForceApprovedConditional:"icon-green",ForceRejected:"icon-red",Approved:"icon-green",ApprovedConditional:"icon-green",Rejected:"icon-red",Pending:"icon-blue",Approve:"icon-green",Reject:"icon-red",Comment:"",ForceApprove:"icon-green",ForceReject:"icon-red",Spinner:""},statusLabels:{NotDefined:"label label-default",NotStarted:"label label-primary",Pending:"label label-info",Approved:"label label-success",ForceApproved:"label label-success",ApprovedConditional:"label label-warning",ForceApprovedConditional:"label label-warning",
Rejected:"label label-danger",ForceRejected:"label label-danger"},ApprovalStatus:{NOT_DEFINED:"NotDefined",NOT_STARTED:"NotStarted",PENDING:"Pending",APPROVED:"Approved",FORCE_APPROVED:"ForceApproved",CONDITIONAL_APPROVED:"ApprovedConditional",FORCE_CONDITIONAL_APPROVED:"ForceApprovedConditional",REJECTED:"Rejected",FORCE_REJECTED:"ForceRejected"},NotificationType:{NO_NOTIFICATIONS:"NoNotifications",DEFAULT_NOTIFICATIONS:"DefaultNotifications",CUSTOM_NOTIFICATIONS:"CustomNotifications"},RejectHandler:b,
rejectionHandlersComplex:[b.STOPS_APPROVAL_IMMEDIATE,b.STOPS_APPROVAL_AFTER_STEP,b.DOES_NOT_STOP],rejectionHandlersSimple:[b.STOPS_APPROVAL_IMMEDIATE,b.STOPS_APPROVAL_AFTER_STEP],requireReviewHandlers:["RequireReviewNo","RequireReviewAny","RequireReviewCurrent"],DueDateType:a,dueDateOptions:[a.NO,a.FIXED,a.LEAD_TIMES,a.LEAD_TIMES_WITH_FINAL_DATE],dueDateOptionsFolderProject:[a.NO,a.LEAD_TIMES],ApprovalMasterType:{PROJECT_MANAGER:"ProjectManager",USER:"User",UPLOADER:"Uploader",GROUP:"Group"},ApprovalType:{USER:"User",
ONE_OF_GROUP:"OneOfGroup",ALL_OF_GROUP:"AllOfGroup",ONE_OF_ROLE:"OneOfRole"},notificationTypeArr:["approvalStageStarted","approvalSubmitted","userRejected","approvalStageFinished","approvalCycleFinished"]}});
define("utils/datetools",["jquery"],function(b){return{getFormattedDate:function(a){var b=Array(12);b[0]="Jan";b[1]="Feb";b[2]="Mar";b[3]="Apr";b[4]="May";b[5]="Jun";b[6]="Jul";b[7]="Aug";b[8]="Sep";b[9]="Oct";b[10]="Nov";b[11]="Dec";null==a&&(a=new Date);var e=a.getMonth(),d=a.getDate(),a=a.getFullYear();return""+b[e]+" "+d+", "+a},getShortFormattedDate:function(a){var b=a.getDate(),e=a.getMonth()+1;return(10>e?"0":"")+e+"/"+(10>b?"0":"")+b+"/"+a.getFullYear()},getDate:function(a){if(null!=a&&("string"==
typeof a&&(a=""+this.convertDateForJSDateClass(a)),a=new Date(a),"NaN"!=a.toLocaleDateString()&&"Invalid Date"!=a.toLocaleDateString())){var b=a.getFullYear();1970>b&&a.setFullYear(b+100);return a}return null},convertDateForJSDateClass:function(a){var b,e=a+"",d;b=a.indexOf("/");if(0<=b){b=e.split("/");if(3==b.length)return e=parseInt(b[0],10),a=parseInt(b[1],10),d=parseInt(b[2],10),null==e||0>=e||31<e||null==a||0>=a||12<a||null==d||0>d||9999<d?"":b=b[1]+"/"+b[0]+"/"+b[2];b=e.split(",");if(2==b.length){d=
parseInt(b[1],10);if(null==d||0>d||9999<d)return"";d=b[0].split("/");if(2==d.length)return e=parseInt(d[0],10),a=parseInt(d[1],10),null==e||0>=e||31<e||null==a||0>=a||12<a?"":b=d[1]+"/"+d[0]+"/"+b[1]}}else if(b=a.indexOf(","),0<=b){if(b=a.split(","),d=b[0].split(" "),2==d.length)return e=parseInt(d[1],10),null==e||0>=e||31<e?"":a}else return a;return""},getNumber:function(a){return null!=a&&(a=parseInt(a,10),"NaN"!=a)?a:null},getDateString:function(a){return null!=a&&(a=this.getDate(a),null!=a)?this.getFormattedDate(a):
null},checkDate:function(a){var c=this.getDateString(b("#"+a).val());null!=c?b("#"+a).val(c):(null!=b("#"+a).val()&&""!==b("#"+a).val()&&window.alert('Enter date formatted as: "16 January, 2008", "16/1/2008" "16/1/08" or "16/1, 2008"'),b("#"+a).focus())},dateAddMonths:function(a,b){var e=a.getDate(),d=a.getMonth(),i=a.getFullYear(),d=d+b;11<d&&(i+=d/12,d%=12);var h=new Date(i,d,e);return h.getMonth()!=d?new Date(i,d,e-h.getDate()):h},dateAddDays:function(a,b){var e=a.valueOf(),e=e+864E5*parseInt(b,
10);return new Date(e)},minDate:function(a,b){return null==a?b:null==b?a:a.valueOf()<b.valueOf()?a:b},dateAddWorkDays:function(a,b){if(!a)return null;var e=[0,5,4,3,2,1,0],d=a.getDay(),i=a.getDate();0>b&&(b=0);0===d?(i+=1,d=1):6==d&&(i+=2,d=1);for(;b>=e[d];)i+=e[d]+2,b-=e[d],d=1;e=new Date(a);e.setDate(i+b);return e},dateSubWorkDays:function(a,b){if(!a)return null;var e=[0,1,2,3,4,5,0],d=a.getDay(),i=a.getDate();0>b&&(b=0);0===d?(i-=2,d=5):6==d&&(i-=1,d=5);for(;b>=e[d];)i-=e[d]+2,b-=e[d],d=5;e=new Date(a);
e.setDate(i-b);return e},dateAddWorkHoursMins:function(a,b,e){if(!a)return null;var d=new Date(a);0>b&&(b=0);0>e&&(e=0);if(0===b&&0===e)return d;d.setHours(a.getHours()+b);d.setMinutes(a.getMinutes()+e);a=d.getDay();b=d.getDate();0===a?b+=1:6==a&&(b+=2);d.setDate(b);return d},dateSubWorkHoursMins:function(a,b,e){if(!a)return null;var d=new Date(a);0>b&&(b=0);0>e&&(e=0);if(0===b&&0===e)return d;d.setHours(a.getHours()-b);d.setMinutes(a.getMinutes()-e);a=d.getDay();b=d.getDate();0===a?b-=2:6==a&&(b-=
1);d.setDate(b);return d},getSummerTimeOffset:function(){var a=new Date;a.setMonth(0);var b=a.getTimezoneOffset();a.setMonth(6);return a.getTimezoneOffset()-b},getSummerWinterTimeOffset:function(a){var b=(new Date).getTimezoneOffset();return a.getTimezoneOffset()-b},isSummerTime:function(a){var b=new Date(a),a=b.getTimezoneOffset();b.setMonth(0);var e=b.getTimezoneOffset();b.setMonth(6);b=b.getTimezoneOffset();return e!=b&&a==Math.min(e,b)},fixDateSummerWinterTime:function(b,c){var e=null;null!=b&&
(e=6E4*this.getSummerWinterTimeOffset(b),e=c?new Date(b.getTime()-e):new Date(b.getTime()+e));return e}}});
define("approval/ApprovalUtils",["wcr/webcenter_html","utils/webi18n!Approval","utils/datetools"],function(b,a,c){return{findMemberObj:function(b,a,c){try{var h=null;if(!c)return null;for(var j=0;j<c.length&&!h;j++)"User"==c[j].memberType?"User"==b&&c[j].userId==a&&(h=c[j]):("Group"==b&&c[j].groupId==a&&(h=c[j]),!h&&c[j].members&&(h=this.findMemberObj(b,a,c[j].members)));return h}catch(g){window.alert("Problem in findMemberObj: "+g)}},getDateHourString:function(a){try{var d=c.fixDateSummerWinterTime(a,
!1),i=b.getDateString(d),h=d.getHours();10>h&&(h="0"+h);var j=d.getMinutes();10>j&&(j="0"+j);return i+("  "+h+":"+j)}catch(g){return a}},getApprovalTypeLangTag:function(b){var a="CApp"+b.approvalType;b.memberObj&&!0===b.memberObj.isRole&&("OneOfGroup"==b.approvalType&&(a="CAppAllOfRoleOneOfGroup"),"AllOfGroup"==b.approvalType&&(a="CAppAllOfGroup"));return a},getNewCurrentTime:function(){var b=new Date;23>b.getHours()&&b.setHours(b.getHours()+1);b.setMinutes(0);b.setSeconds(0);return b},getUserRepresentation:function(c){var d=
{name:""};if(!c)return d;d.isGroup=void 0!==c.groupName;d.isRole=c.isRole;d.isUser=void 0!==c.lastName;d.isUser&&(d.name=b.getUserNameStringActiveHTML(null,c.firstName,c.lastName,c.userName,c.isActive,a.t("CAppUserDeactivated"),!0));d.isGroup&&(d.name=c.groupName);return d}}});
define("approval/model/ApprovalNotifications",["approval/ApprovalConstants","utils/Observable","wcr/webcenter_xml","underscore"],function(b,a,c,e){function d(c){a.mixin(this,"notifications");this.approvalModel=c;this.notificationType=b.NotificationType.NO_NOTIFICATIONS;this.projectNotificationsArr=this.defaultNotificationsArr=this.notificationsArr=null}d.fromXML=function(b,a){var c=new d(a);c.readNotificationInfoFromXML(b);return c};d.prototype.readNotificationInfoFromXML=function(a){var d=c.GetFirstFirstLevelChild(a,
"general"),e=c.GetFirstFirstLevelChild(a,"project"),a=c.GetFirstFirstLevelChild(a,"folder");d&&(this.notificationType=c.GetElementText(d,"notificationType"),this.notificationType===b.NotificationType.CUSTOM_NOTIFICATIONS?(this.notificationsArr=this.readNotificationsFromXML(d),0===this.notificationsArr.length&&(this.notificationType=b.NotificationType.NO_NOTIFICATIONS)):this.notificationType||(this.notificationType=b.NotificationType.NO_NOTIFICATIONS));if(e&&(this.defaultNotificationsArr=this.readNotificationsFromXML(e),
!this.defaultNotificationsArr||0===this.defaultNotificationsArr.length))this.defaultNotificationsArr=null;a&&(d=this.readNotificationsFromXML(a),this.projectNotificationsArr=this.defaultNotificationsArr,d&&0<d.length&&(this.defaultNotificationsArr=d));this._emit("update")};d.prototype.readNotificationsFromXML=function(a){var d=[];if(a=c.GetFirstFirstLevelChild(a,"notifications"))for(var e=0;e<b.notificationTypeArr.length;e++){var g={},l=c.GetFirstFirstLevelChild(a,b.notificationTypeArr[e]);l&&(g.projectManager=
c.GetElementBoolean(l,"projectManager"),g.involvedPeople=c.GetElementBoolean(l,"involvedPeople"),g.projectMembers=c.GetElementBoolean(l,"projectMembers"));d.push(g)}return d};d.prototype.toggleNotification=function(b,a,c){if(this.notificationsArr[b])switch(b=this.notificationsArr[b],a){case 0:b.projectManager=null!=c?c:!0!==b.projectManager;break;case 1:b.involvedPeople=null!=c?c:!0!==b.involvedPeople;break;case 2:b.projectMembers=null!=c?c:!0!==b.projectMembers;break;default:throw"notification "+
a+" does not exist";}this._emit("update")};d.prototype.toggleNotificationColumn=function(a,c){e.each(b.notificationTypeArr,function(b,g){this.toggleNotification(g,a,c)}.bind(this))};d.prototype.setNotificationType=function(a){this.notificationType=a;switch(this.notificationType){case b.NotificationType.NO_NOTIFICATIONS:break;case b.NotificationType.DEFAULT_NOTIFICATIONS:null!=this.projectNotificationsArr&&(this.notificationsArr=this.projectNotificationsArr.slice());break;case b.NotificationType.CUSTOM_NOTIFICATIONS:!this.notificationsArr&&
this.defaultNotificationsArr&&(this.notificationsArr=this.defaultNotificationsArr.slice());break;default:throw"Notification type unknown"+this.notificationType;}this._emit("update")};d.prototype.writeToXML=function(){var a="";this.notificationType&&(a+=c.ElementEncode("notificationType",this.notificationType));this.notificationType===b.NotificationType.CUSTOM_NOTIFICATIONS&&this.notificationsArr&&(a+="<notifications>",e.each(b.notificationTypeArr,function(b,d){var g=this.notificationsArr[d];g&&(a+=
"<"+b+">",a+=c.ElementEncodeBoolean("projectManager",g.projectManager),a+=c.ElementEncodeBoolean("involvedPeople",g.involvedPeople),a+=c.ElementEncodeBoolean("projectMembers",g.projectMembers),a+="</"+b+">")}.bind(this)),a+="</notifications>");return a};return d});
define("approval/model/ApprovalMember",["approval/ApprovalConstants","utils/Observable","wcr/webcenter_xml","jquery","underscore"],function(b,a,c){function e(){}e.readMembers=function(a,b){var e=[],j;if(a){var g=c.GetFirstLevelChilds(a,"member");if(g)for(var l=0;l<g.length;l++){var n=c.GetElementText(g[l],"userId");if(n)j={},j.userId=n,j.userName=c.GetElementText(g[l],"userName"),j.firstName=c.GetElementText(g[l],"firstName"),j.lastName=c.GetElementText(g[l],"lastName"),j.eMail=c.GetElementText(g[l],
"eMail"),j.canBeApprovalMaster=c.GetElementBoolean(g[l],"canBeApprovalMaster"),j.isActive=c.GetElementBoolean(g[l],"is_active"),j.memberType="User",j.isMember=b,e.push(j);else if(n=c.GetElementText(g[l],"groupId")){j={};j.groupId=n;j.groupName=c.GetElementText(g[l],"groupName");j.canBeApprovalMaster=c.GetElementBoolean(g[l],"canBeApprovalMaster");j.memberType="Group";n=c.GetElementText(g[l],"isRole");j.isRole="1"==n;j.isMember=b;if((n=c.GetFirstLevelChilds(g[l],"groupMembers"))&&0<n.length)j.members=
this.readMembers(n[0],b);e.push(j)}}return e}};return e});
define("approval/model/Approver",["approval/ApprovalConstants","approval/ApprovalUtils","wcr/webcenter_xml","underscore"],function(b,a,c){function e(b,a){this.approvalType=b;this.approvalTime=this.approvedByUserId=this.approvedVersion=this.approvalStatus=null;this.memberObj=a;this.commentArr=[]}e.fromXML=function(d,i,h){var j=!0,g=new e;g.approvalType=c.GetElementText(d,"approvalType");g.approvalStatus=c.GetElementText(d,"approvalStatus");g.approvedVersion=c.GetElementText(d,"approvedVersion");var l=
c.GetFirstLevelChilds(d,"approvalComment");if(l)for(var n=0;n<l.length;n++){var f={};f.commentText=c.GetElementText(l[n],"comment");f.commentByUserId=c.GetElementText(l[n],"commentByUserId");var k=parseInt(c.GetElementText(l[n],"commentTime"));f.commentTime=k&&!isNaN(k)?new Date(k):null;f.commentVersion=c.GetElementText(l[n],"commentVersion");f.commentText&&g.commentArr.push(f)}g.approvedByUserId=c.GetElementText(d,"approvalApprovedByUserId");l=parseInt(c.GetElementText(d,"approvalTime"));g.approvalTime=
l&&!isNaN(l)?new Date(l):null;g.approvalType===b.ApprovalType.USER?(d=c.GetElementText(d,"userId"),g.memberObj=a.findMemberObj("User",d,i),g.memberObj||(g.memberObj=a.findMemberObj("User",d,h),g.memberObj||(j=!1))):(d=c.GetElementText(d,"groupId"),g.memberObj=a.findMemberObj("Group",d,i),g.memberObj||(g.memberObj=a.findMemberObj("Group",d,h),g.memberObj||(j=!1)));return j?g:null};e.prototype.writeToXML=function(){var a=this.approvalType,e;e="<approver>"+c.ElementEncode("approvalType",a);if(a===b.ApprovalType.USER){if(!this.memberObj){window.alert("No memberObj for approver");
return}if(!this.memberObj.userId)throw"No userId for approver";e+=c.ElementEncode("approverId",this.memberObj.userId)}else if(a===b.ApprovalType.ONE_OF_GROUP||a===b.ApprovalType.ALL_OF_GROUP||a===b.ApprovalType.ONE_OF_ROLE){if(!this.memberObj.groupId)throw"No groupId for approver";e+=c.ElementEncode("approverId",this.memberObj.groupId)}else window.alert("Problem writing approvers.  Unexpected approvalType: "+a);return e+"</approver>"};return e});
define("approval/model/ApprovalStage","approval/model/Approver approval/ApprovalConstants utils/Observable utils/Observer utils/webi18n!Approval wcr/webcenter_xml underscore".split(" "),function(b,a,c,e,d,i,h){function j(b){c.mixin(this,["Approval",b.getId(),"stage",h.uniqueId()],"Approval");e.mixin(this);this.id=null;this.name="";this.leadTime=this.dueDate=null;this.approvalStatus=a.ApprovalStatus.NOT_STARTED;this.condApp=!0;this.rejectHandle="RejectStopsApprovalAfterStep";this.requireReviewHandle=
"RequireReviewNo";this.approvers=[];this.approvalModel=b;this._observe(this.approvalModel,"changed.stages.*",h.partial(this._emit,"changed.number"));this._observe(this.approvalModel,"changed.stages.deleted",function(){h.contains(arguments,this)&&(this._emit("deleted"),this._stopObserveAll())}.bind(this));this._observe(this.approvalModel,"changed.stages.added",function(a){h.isEmpty(this.name)&&(this!==a&&2===h.size(this.approvalModel.getStages()))&&this.setStageName(d.t("CAppStage")+" 1")}.bind(this));
Object.defineProperty(this,"number",{get:function(){return this.approvalModel?this.approvalModel.getStageNumber(this):"undefined"}.bind(this)})}j.fromXML=function(a,c,e,d){var k=new j(d);k.id=i.GetElementText(a,"stageId");k.name=i.GetElementText(a,"stageName");d=parseInt(i.GetElementText(a,"stageDueTimeStamp"));k.dueDate=d?new Date(d):null;k.leadTime=parseInt(i.GetElementText(a,"stageLeadTime"));k.approvalStatus=i.GetElementText(a,"stageApprovalStatus");k.condApp=i.GetElementBoolean(a,"allowConditionalApproval");
k.rejectHandle=i.GetElementText(a,"uponRejection");k.requireReviewHandle=i.GetElementText(a,"requireReviewState");if(a=i.GetFirstFirstLevelChild(a,"approvers"))a=i.GetFirstLevelChilds(a,"approver"),h.each(a,function(a){a&&(a=b.fromXML(a,c,e))&&k.approvers.push(a)}.bind(this));k._emit("update");return k};j.prototype.canModifyDueDate=function(){return this.approvalStatus===a.ApprovalStatus.NOT_STARTED};j.prototype.canModifyApprovers=function(){return this.approvalStatus===a.ApprovalStatus.NOT_STARTED||
this.approvalStatus===a.ApprovalStatus.PENDING};j.prototype.writeToXML=function(a){var b="<stage>",b=b+i.ElementEncode("stageId",this.id),b=b+i.ElementEncode("stageName",this.approvalModel.isStagedApprovalAllowed()?this.name:""),b=b+i.ElementEncode("stageNumber",a+1);this.dueDate&&this.dueDate.constructor==Date&&(b+=i.ElementEncode("stageDueDateStamp",this.dueDate.getTime()));this.leadTime&&(b+=i.ElementEncode("stageLeadTime",this.leadTime));b+=i.ElementEncode("stageApprovalStatus",this.approvalStatus);
b+=i.ElementEncode("uponRejection",this.rejectHandle);b+=i.ElementEncode("requireReviewState",this.requireReviewHandle);b=this.approvalModel.systemCondApprovalAllowed?b+i.ElementEncode("allowConditionalApproval",this.condApp):b+i.ElementEncode("allowConditionalApproval",!1);b+="<approvers>";this.approvers&&h.each(this.approvers,function(a){b+=a.writeToXML()});b+="</approvers>";return b+="</stage>"};j.prototype.remove=function(){this.approvalModel.removeStage(this)};j.prototype.removeApprover=function(a){var b=
this.approvers;if(!b)throw"appArr is null";if(a<b.length&&0<=a)b.splice(a,1),this._emit("changed.approvers.removed");else throw"approverIndex out of bounds of approvers array";};j.prototype.removeAllApprovers=function(){h.isEmpty(this.approvers)||(this.approvers=[],this._emit("changed.approvers.removeall"))};j.prototype.changeGroupApprover=function(a,b){var c=this.approvers[a];c&&b&&(c.approvalType=b,this._emit("changed.approvers.modified",c))};j.prototype.setDueDate=function(b){this.dueDate!==b&&
(this.dueDate=b,this._emit("changed.duedate"))};j.prototype.setLeadTime=function(b){this.leadTime!==b&&(this.leadTime=b,this._emit("changed.leadtime"))};j.prototype.getStageName=function(){return this.name};j.prototype.setStageName=function(b){this.name===b||"string"!==typeof b||(this.name=b,this._emit("changed.name"))};j.prototype.hasValidStageName=function(){return this.approvalModel.isComplexApproval()&&(!this.name||!this.name.trim())?"CAppEmptyNameNotAllowed":this.approvalModel.isValidStageName(this)?
"":"CAppSameNameNotAllowed"};j.prototype.getLeadTimeInDaysAndHours=function(){var b=this.leadTime/36E5,a=Math.floor(b/24),b=Math.round(b-24*a);return{days:a,hours:b}};j.prototype.setRejectHandle=function(b){this.rejectHandle!==b&&(this.rejectHandle=b,this._emit("changed.rejecthandle"))};j.prototype.setRequireReviewHandle=function(b){this.requireReviewHandle!==b&&(this.requireReviewHandle=b,this._emit("changed.requirereviewhandle"))};j.prototype.setConditionalApproval=function(b){this.condApp!==b&&
(this.condApp=b,this._emit("changed.condapp"))};j.prototype.addApprover=function(a){if(a&&!h.some(this.approvers,function(b){b=b.memberObj;return a.userId&&a.userId===b.userId||a.groupId&&a.groupId===b.groupId})){var c=new b(a.userId?"User":a.isRole?"OneOfRole":"OneOfGroup",a);this.approvers.push(c);this._emit("changed.approvers.added",c)}};j.prototype.getApprovers=function(){return this.approvers};j.prototype.canModifyStageName=function(){return!this.approvalModel.readOnly&&this.approvalModel.approvalStatus===
a.ApprovalStatus.NOT_STARTED&&this.approvalStatus===a.ApprovalStatus.NOT_STARTED};return j});
define("utils/dateShift",[],function(){return{addDaysHours:function(b,a,c,e,d,i){var h=24;i&&(h=8);b=b.constructor==Date?b.getTime():parseInt(b);try{var j=parseInt(a),g=parseInt(c);e&&(j=Math.floor(e/864E5),g=(e-864E5*j)/36E5);var l=Math.floor(j/5),a=j-5*l,b=this.normalizeDateHour(b,i);g>h&&(j+=Math.floor(g/h),g-=Math.floor(g/h)*h);if(0>j||0>g)throw"No negative days or hours allowed";var n=new Date(b),f=n.getDay()-1;-1==f&&(f=6);f+=a;4<f&&(a+=2);b+=864E5*(7*l+a);i&&17<n.getHours()+g&&(g+=16);b+=36E5*
g;f=(new Date(b)).getDay();if(0==f||6==f)b+=1728E5}catch(k){alert("Problem in  addDaysHours: "+k)}return!0==d?new Date(b):b},subtractDaysHours:function(b,a,c,e,d,i){var h=24;i&&(h=8);b=b.constructor==Date?b.getTime():parseInt(b);try{var j=parseInt(a),g=parseInt(c);e&&(j=Math.floor(e/864E5),g=(e-864E5*j)/36E5);var l=Math.floor(j/5),a=j-5*l,b=this.normalizeDateHour(b,i);g>h&&(j+=Math.floor(g/h),g-=Math.floor(g/h)*h);if(0>j||0>g)throw"No negative days or hours allowed";var n=new Date(b),f=n.getDay()-
1;-1==f&&(f=6);f-=a;0>f&&(a+=2);b-=864E5*(7*l+a);i&&9>n.getHours()-g&&(g+=16);b-=36E5*g;f=(new Date(b)).getDay();if(0==f||6==f)b-=1728E5}catch(k){alert("Problem in  subtractDaysHours: "+k)}return!0==d?new Date(b):b},getWorkingTimeDifference:function(b,a,c){try{b.constructor==Date&&(b=b.getTime());a.constructor==Date&&(a=a.getTime());var e=!1;if(0>a-b)var e=!0,d=a,a=b,b=d;var b=this.normalizeDateHour(b,c),a=this.normalizeDateHour(a,c),i=new Date(b),h=new Date(a),j;if(c){var g=i.getDay();0==g&&(g=7);
var l=5-g;0>l&&(l=0);var n=new Date(b);n.setHours(17);n.setMinutes(0);var f=864E5*l+n.getTime()-i.getTime(),g=h.getDay();0==g&&(g=7);l=g-1;4<l&&(l=4);var k=new Date(a);k.setHours(9);k.setMinutes(0);var m=864E5*l+h.getTime()-k.getTime(),s=Math.floor((a-m-(b+f))/6048E5);j=0;j=0>s?h.getTime()-i.getTime():432E6*s+f+m}else{var q=Math.floor((a-b)/864E5),l=Math.floor(q/7),h=q-7*l,n=2*l,g=i.getDay();0==g&&(g=7);5<g+h&&(n+=2);j=a-b-864E5*n}e&&(j=-j);return j}catch(p){alert("Problem in getWorkingTimeDifference: "+
p)}},normalizeDateHour:function(b,a,c,e){var d=b.constructor,i=0,e=e?e:18;a&&(i=9,e=17);var h=null,h=d!=Date?new Date(b):b;6==h.getDay()?(c?(h=new Date(h.getTime()-864E5),h.setHours(e)):(h=new Date(h.getTime()+1728E5),h.setHours(i)),h.setMinutes(0),h.setSeconds(0),h.setMilliseconds(0)):0==h.getDay()&&(c?(h=new Date(h.getTime()-1728E5),h.setHours(e)):(h=new Date(h.getTime()+864E5),h.setHours(i)),h.setMinutes(0),h.setSeconds(0),h.setMilliseconds(0));a&&(17<=h.getHours()&&(h.setHours(17),h.setMinutes(0),
h.setSeconds(0)),h.setMilliseconds(0),9>h.getHours()&&(h.setHours(9),h.setMinutes(0),h.setSeconds(0)),h.setMilliseconds(0));return d!=Date?h.getTime():h},getLeadTime:function(b,a){var c=0;try{c=864E5*Number(b)+36E5*Number(a)}catch(e){alert("Problem in getLeadTime: "+e)}return new Number(c)},getLeadTimeDays:function(b){var a=0;try{0<b&&(a=Math.floor(b/864E5))}catch(c){alert("Problem in getLeadTimeDays: "+c)}return a},getLeadTimeHours:function(b){var a=0;try{if(0<b)var c=this.getLeadTimeDays(b),a=Math.floor((b-
864E5*c)/36E5)}catch(e){alert("Problem in getLeadTimeHours: "+e)}return a},roundTimeToHours:function(b){var a=b;try{a=36E5*Math.floor((b+18E5)/36E5)}catch(c){alert("Problem in roundTimeToHours method: "+c)}return a},roundTimeToDays:function(b){var a=b;try{a=864E5*Math.floor((b+432E5)/864E5)}catch(c){alert("Problem in roundTimeToDays method: "+c)}return a}}});
define("approval/stageFactory/SimpleApprovalStageFactory",["approval/model/ApprovalStage","utils/dateShift"],function(b,a){var c=function(b){this._model=b};c.prototype.createApprovalStage=function(){var c=new b(this._model);c.dueDate=a.addDaysHours(new Date,1,0,null,!0);return c};return c});
define("approval/stageFactory/ComplexApprovalStageFactory",["approval/model/ApprovalStage","approval/ApprovalConstants","underscore","utils/webi18n!approval","utils/dateShift"],function(b,a,c,e,d){var i=function(b){this._model=b};i.prototype.createApprovalStage=function(h){var i=new b(this._model);i.condApp=!0;if(this._model.dueDateType===a.DueDateType.FIXED){var g=new Date;g.setMinutes(0);g.setSeconds(0);h&&h.dueDate&&(g=h.dueDate);i.dueDate=d.addDaysHours(g,1,0,null,!0)}if((g=this._model.getStages())&&
0<g.length){for(var g=c.pluck(g,"name"),h=this._model.getStageNumber(h),l=e.t("CAppStage")+" "+(h+1),h=function(b){return b===l};c.find(g,h);)l+="_2";i.name=l}return i};return i});
define("approval/model/ApprovalModel","approval/ApprovalConstants approval/ApprovalUtils approval/model/ApprovalNotifications approval/model/ApprovalMember approval/model/ApprovalStage approval/stageFactory/SimpleApprovalStageFactory approval/stageFactory/ComplexApprovalStageFactory utils/Observable utils/Observer utils/dateShift wcr/webcenter_html wcr/webcenter_xml underscore".split(" "),function(b,a,c,e,d,i,h,j,g,l,n,f,k){function m(a,c,e,d,f,l,n){this._id=k.uniqueId();j.mixin(this,["Approval",
this._id],"Approval");g.mixin(this);this.on("stage.*.changed.approvers.added",this._onStageApproverAdded.bind(this));this.onAll(["changed.*","stage.*.changed.**"],function(){this.approvalRuleChanged=!0}.bind(this));this.steps=[];this.actionURL=e;this.currentUser=d;this.approvalStatus=b.ApprovalStatus.NOT_DEFINED;this.stagedApprovalAllowed=f;this.isViewFile=n;this._stageFactory=f?new h(this):new i(this);this.dueDateType=b.DueDateType.NO;this.hasNextVersionSetup=this.hasFolderApprovalSetup=this.hasProjectApprovalSetup=
this.passwordValidation=this.approvalRuleChanged=!1;this.nextVersion=!!c;this.readOnly=!(d&&!0===d.canChangeSetup);this.canSubmitApprovalStatus=!0;this.documentVersion=1;this.uponNewVersion="InheritApproval";this.submitAllowed=!0;this.submitDisabled=!1;this.getProjectFolderSetupURL=l;this.viewerApprovalCommentType="Prompt";this.readURL=a;this.isMultiDocSetup=!1;a?this.readFromXML(this.readURL):this._emit("update")}m.prototype.setError=function(b){this.errorObj=b;this._emit("error",b)};m.prototype.getId=
function(){return this._id};m.prototype._onStageApproverAdded=function(b){a.findMemberObj(b.memberObj.memberType,b.memberObj.userId||b.memberObj.groupId,this.getProjectMembers())||(this.projectMembers.push(b.memberObj),this._emit("member.added"))};m.prototype.readApprovalFromURL=function(b,a){this.canSubmitApprovalStatus=!0;$.ajax({url:b,type:"GET",data:"xml"}).done(k.bind(function(b){this.reset();a?this.readProjectFolderReturnXML(b):this.readReturnXML(b);this.approvalRuleChanged=a;this._emit("initialized")},
this)).fail(k.bind(function(){this.reset();this.setError("An error occured when loading the approval setup")},this))};m.prototype.readReturnXML=function(a){var q=f.GetFirstFirstLevelChild(a,"error");if(q)a=f.GetElementText(q,"errorMessage"),this.setError({errors:[{tag:a,inline:!0}]});else{this.errorMsg=null;if(a=f.GetFirstFirstLevelChild(a,"approvalSetup")){this.notificationInfo&&this._stopObserveObject(this.notificationInfo);this.notificationInfo=c.fromXML(a,this);this._observe(this.notificationInfo,
"update",k.partial(this._emit,"changed.notifications"));if(q=f.GetFirstFirstLevelChild(a,"general"))this.uponNewVersion=f.GetElementText(q,"uponNewVersion"),this.dueDateType=f.GetElementText(q,"dueDateType"),""===this.dueDateType&&(this.dueDateType=b.DueDateType.NO),this.dueDateType===b.DueDateType.LEAD_TIMES_WITH_FINAL_DATE&&(this.finalDueDate=(this.finalDueDate=parseInt(f.GetElementText(q,"finalDueDate")))?new Date(this.finalDueDate):null),this.approvalStatus=f.GetElementText(q,"generalApprovalStatus"),
this.viewerApprovalCommentType=f.GetElementText(q,"viewerApprovalCommentType"),this.approvalMasterType=f.GetElementText(q,"approvalMasterType"),this.approvalMaster=f.GetElementText(q,"approvalMaster"),this.hasNextVersionSetup=f.GetElementBoolean(q,"hasNextDocumentVersionApprovalSetup"),this.passwordValidation=f.GetElementBoolean(q,"passwordValidation"),this.systemCondApprovalAllowed=f.GetElementBoolean(q,"systemCondApprovalAllowed");if(q=f.GetFirstFirstLevelChild(a,"project")){this.projectId=f.GetElementText(q,
"projectId");this.projectName=f.GetElementText(q,"projectName");this.projectManagerUserId=f.GetElementText(q,"projectManagerUserId");f.GetFirstFirstLevelChild(q,"CannotSubmitAppStatusProjInactive")&&(this.canSubmitApprovalStatus=!1);var p=f.GetFirstFirstLevelChild(q,"projectMembersWithAccess");p&&(this.projectMembers=e.readMembers(p,!0));if(p=f.GetFirstFirstLevelChild(q,"project_role_assignment_map_list"))this.roleAssignments=[],this.assignedRolesID=[],this.readRoleAssignmentData(p,this.roleAssignments,
this.assignedRolesID);if(q=f.GetFirstFirstLevelChild(q,"usersWithNoAccess"))this.usersWithNoAccess=e.readMembers(q,!1)}if(q=f.GetFirstFirstLevelChild(a,"folder"))this.folderId=f.GetElementText(q,"folderId"),this.folderName=f.GetElementText(q,"folderName"),this.hasProjectApprovalSetup=f.GetElementBoolean(q,"hasProjectApprovalSetup");if(q=f.GetFirstFirstLevelChild(a,"isMultiDocApprovalSetup")){this.isMultiDocSetup=!0;if(null==f.GetFirstFirstLevelChild(q,"projIsTemplate")&&(null==this.currentUser.canStartApproval||
!0===this.currentUser.canStartApproval))this.currentUser.canStartApproval=!0;this.hasProjectApprovalSetup=f.GetElementBoolean(q,"hasProjectApprovalSetup");this.hasFolderApprovalSetup=f.GetElementBoolean(q,"hasFolderApprovalSetup")}if(q=f.GetFirstFirstLevelChild(a,"document"))this.documentId=f.GetElementText(q,"documentId"),this.documentName=f.GetElementText(q,"documentName"),this.documentVersion=f.GetElementText(q,"documentVersion"),this.hasFolderApprovalSetup=f.GetElementBoolean(q,"hasFolderApprovalSetup"),
!0!==this.hasProjectApprovalSetup&&(this.hasProjectApprovalSetup=f.GetElementBoolean(q,"hasProjectApprovalSetup"));this.steps=[];(a=f.GetFirstFirstLevelChild(a,"stages"))&&k.each(f.GetFirstLevelChilds(a,"stage"),function(b){this.addStage(d.fromXML(b,this.projectMembers,this.usersWithNoAccess,this))}.bind(this));this.approvalRuleChanged=!1}this.nextVersion&&(this.hasNextVersionSetup&&(this.approvalStatus=b.ApprovalStatus.NOT_STARTED),k.each(this.steps,function(a){a&&(a.approvalStatus=b.ApprovalStatus.NOT_STARTED,
a.approvers=k.chain(a.approvers).filter(function(b){return b.memberObj&&b.memberObj.canBeApprovalMaster}).each(function(a){a.approvalStatus=b.ApprovalStatus.NOT_STARTED;a.approvedVersion=null;a.approvalDate=null;a.approvalHour=null;a.commentArr=[]}).value())}.bind(this)));this.globalStatus={status:this.approvalStatus,userStatus:void 0};this.globalStatus.status!==b.ApprovalStatus.NOT_DEFINED&&this.globalStatus.status!==b.ApprovalStatus.NOT_STARTED&&(this.globalStatus.userStatus=this.currentUserApprovalStatus(0))}};
m.prototype.readRoleAssignmentData=function(b,a,c){if(b){var e=function(b){var a=f.GetElementText(b,"first_name"),c=f.GetElementText(b,"last_name"),s=f.GetElementText(b,"name");return{firstName:a,lastName:c,userName:s,name:c+(a?", "+a:" ")+"("+s+")",isActive:f.GetElementBoolean(b,"is_active"),ID:f.GetElementAttribute(b,"id")}},b=f.GetFirstLevelChilds(b,"project_role_assignment_map");k.each(b,function(b){var s=f.GetFirstFirstLevelChild(b,"role_group"),d=f.GetElementAttribute(s,"id"),g=f.GetElementSelfTextContent(s),
s={};s.roleID=d;s.roleName=g;c.push(d);var h=[];if(d=f.GetFirstFirstLevelChild(b,"assigned_users_list"))(d=f.GetFirstLevelChilds(d,"assigned_user"))&&k.each(d,function(b){b=e(f.GetFirstFirstLevelChild(b,"user"));h.push(b)});h&&0<h.length&&(s.userRoleAssignments=h);var i=[];if(b=f.GetFirstFirstLevelChild(b,"assigned_groups_list"))(b=f.GetFirstLevelChilds(b,"assigned_group"))&&k.each(b,function(b){var a=f.GetElementText(b,"assigned_group_name"),c=f.GetElementAttribute(b,"id"),s={};s.name=a;s.ID=c;if(b=
f.GetFirstFirstLevelChild(b,"assigned_group_assignee"))s.assignee=e(f.GetFirstFirstLevelChild(b,"user"));i.push(s)});i&&0<i.length&&(s.groupRoleAssignments=i);a.push(s)}.bind(this))}};m.prototype.loadProjectFolderApproval=function(b){var a=this.getProjectFolderSetupURL;if(!a)throw"getProjectFolderSetupURL is null";a=-1==a.indexOf("?")?a+"?":a+"&";this.readApprovalFromURL(!0===b?a+"folder=true":a+"folder=false",!0)};m.prototype.readProjectFolderReturnXML=function(a){var c=f.GetFirstFirstLevelChild(a,
"error");if(c)a=f.GetElementText(c,"errorMessage"),this.setError({errorMsg:"CAppCouldNotLoad",errors:[{tag:a,inline:!0}]});else if(this.errorMsg=null,this.reset(),a=f.GetFirstFirstLevelChild(a,"approvalSetup")){if(c=f.GetFirstFirstLevelChild(a,"stages")){c=f.GetFirstLevelChilds(c,"stage");if(0===c.length){this.setError({errorMsg:"CAppNoProjectApproval"});return}this.steps=[];k.each(c,function(b){this.addStage(d.fromXML(b,this.projectMembers,this.usersWithNoAccess,this))}.bind(this))}this.approvalStatus=
b.ApprovalStatus.NOT_STARTED;this.notificationInfo.setNotificationType(b.NotificationType.DEFAULT_NOTIFICATIONS);if(a=f.GetFirstFirstLevelChild(a,"general"))this.uponNewVersion=f.GetElementText(a,"uponNewVersion"),this.dueDateType=f.GetElementText(a,"dueDateType"),this.approvalMasterType=f.GetElementText(a,"approvalMasterType"),this.approvalMaster=f.GetElementText(a,"approvalMaster");this.approvalRuleChanged=!0}};m.prototype.editSetupForNextVersion=function(){this.nextVersion=!0;if(this.hasNextVersionSetup){var a=
this.readURL,a=-1==a.indexOf("?")?a+"?":a+"&";this.readApprovalFromURL(a+"nextDocVersion=true",!1)}else this.approvalStatus===b.ApprovalStatus.NOT_DEFINED?(this.setApprovalStatus(b.ApprovalStatus.NOT_STARTED),a=this._stageFactory.createApprovalStage(),this.addStage(a,0)):(k.each(this.steps,function(a){a.approvalStatus=b.ApprovalStatus.NOT_STARTED;a.id=null;k.each(a.approvers,function(a){a.approvalStatus=b.ApprovalStatus.NOT_STARTED;a.approvedVersion=null;a.approvalDate=null;a.approvalHour=null;a.commentArr=
[];a.approvedByUserId=null;a.approvalTime=null}.bind(this))}.bind(this)),this.approvalStatus!==b.ApprovalStatus.NOT_DEFINED&&this.setApprovalStatus(b.ApprovalStatus.NOT_STARTED)),this.approvalRuleChanged=!0,this._emit("initialized")};m.prototype.cancel=function(){this.readFromXML(this.readURL)};m.prototype.clear=function(){this.removeAllStages();this.approvalStatus=b.ApprovalStatus.NOT_DEFINED;this.dueDateType=b.DueDateType.NO;this.currentUser&&this.currentUser.userid&&(this.approvalMasterType=b.ApprovalMasterType.USER,
this.approvalMaster=this.currentUser.userid);(this.documentId||this.folderId)&&this.notificationInfo.setNotificationType(b.NotificationType.DEFAULT_NOTIFICATIONS);this.approvalRuleChanged=!0;this._emit("update")};m.prototype.backToCurrentVersion=function(){this.nextVersion=!1;this.readFromXML(this.readURL)};m.prototype.findRoleUserObj=function(b,c){try{var e=null;if(!this.roleAssignments)return null;for(var d=0;d<this.roleAssignments.length&&!e;d++)if(this.roleAssignments[d].roleID==c){if(this.roleAssignments[d].userRoleAssignments)for(var g=
this.roleAssignments[d].userRoleAssignments,h=0;h<g.length&&!e;h++)g[h].ID==b&&(e=a.findMemberObj("User",g[h].ID,this.projectMembers));if(this.roleAssignments[d].groupRoleAssignments)for(var i=this.roleAssignments[d].groupRoleAssignments,h=0;h<i.length&&!e;h++)var k=a.findMemberObj("Group",i[h].ID,this.projectMembers),e=a.findMemberObj("User",b,k.members)}return e}catch(f){window.alert("Problem in findRoleUserObj: "+f)}};m.prototype.getApprovalActions=function(a){var c={list:[],text:void 0,showContent:!0},
e,d;a&&this.globalStatus&&(e=this.globalStatus.status,d=this.globalStatus.userStatus);try{if(!this.canSubmitApprovalStatus&&e!==b.ApprovalStatus.PENDING||this.approvalStatus===b.ApprovalStatus.NOT_STARTED||this.globalStatus&&this.globalStatus.status===b.ApprovalStatus.NOT_STARTED)return c;var a=0,g=this.currentUser;if(g){var h=g.mustApprove;if(null==g.mustApprove){if(void 0!==this.forcedStep)a=this.forcedStep;else{for(var i=!1,a=0;a<this.steps.length&&!i;a++)this.steps[a]&&this.steps[a].approvalStatus===
b.ApprovalStatus.PENDING&&(i=!0);if(i){a--;var k=this.steps[a].approvers;k&&0<k.length&&(h=this.currentUserApprovalStatus(a))}}if(a>=this.steps.length&&"Pending"!=e)return c}var f;"MustApprove"==h||"MustApprove"==d?(c.text="CAppApprovalYouMustApprove",f="MustApprove"!=h?"Remaining":"",c.list.push({name:"Approve"+f,text:"CAppApprove"+f,internalName:"Approved",step:a}),c.list.push({name:"Reject"+f,text:"CAppReject"+f,internalName:"Rejected",step:a}),c.list.push({name:"Comment"+f,text:"CAppComment"+
f,internalName:"Comment",step:a})):null!=h&&(c.text="CAppYouHave"+h);f=this.approvalStatus!==b.ApprovalStatus.PENDING?"Remaining":"";g.canForceApprove&&c.list.push({name:"ForceApprove"+f,text:"CAppForceApprove"+f,internalName:"ForceApproved",step:a});g.canForceReject&&c.list.push({name:"ForceReject"+f,text:"CAppForceReject"+f,internalName:"ForceRejected",step:a})}}catch(l){window.alert("Problem in Approval.getApprovalActions: "+l)}c.showContent=!0;return c};m.prototype.currentUserApprovalStatus=function(c,
e){try{for(var d=null,g=this.currentUser,h=this.steps[c].approvers,i=0;i<h.length;i++)if(!(null!=e&&e!=i))if(h[i].approvalType===b.ApprovalType.USER)h[i].memberObj.userId==g.userId&&(h[i].approvalStatus===b.ApprovalStatus.PENDING&&(d="MustApprove"),"MustApprove"!=d&&(d=h[i].approvalStatus));else{if((h[i].approvalType===b.ApprovalType.ONE_OF_ROLE?this.findRoleUserObj(g.userId,h[i].memberObj.groupId):a.findMemberObj("User",g.userId,h[i].memberObj.members))&&h[i].approvalStatus===b.ApprovalStatus.PENDING)d=
"MustApprove";"MustApprove"!=d&&h[i].approvedByUserId==g.userId&&(d=h[i].approvalStatus)}return d}catch(f){return window.alert("Problem in Approval.currentUserApprovalStatus: "+f),"MustApprove"}};m.prototype.reset=function(){this.approvalStatus=b.ApprovalStatus.NOT_DEFINED;this.documentVersion=1;this.uponNewVersion="InheritApproval";this.removeAllStages();this.canSubmitApprovalStatus=!0};m.prototype.addTimeToStages=function(a,b){if(!isNaN(a)&&!isNaN(b)&&!(0>a||0>b||24<=b)){var c=new Date;k.each(this.steps,
function(d){d.canModifyDueDate()&&(c=l.addDaysHours(c,a,b,null,!0),d.setDueDate(c))}.bind(this));return!0}return!1};m.prototype.shiftDueDatesOfStages=function(a,b){return!isNaN(a)&&!isNaN(b)&&!(0>a*b||24<=b||-24>=b)?(k.each(this.steps,function(c){c.dueDate&&c.dueDate.constructor==Date&&c.canModifyDueDate()&&(0<=a&&0<=b?c.setDueDate(l.addDaysHours(c.dueDate,a,b,null,!0)):c.setDueDate(l.subtractDaysHours(c.dueDate,Math.abs(a),Math.abs(b),null,!0)))}.bind(this)),!0):!1};m.prototype.shiftDueDatesToLatest=
function(a){var b=k.last(this.steps),c=l.getWorkingTimeDifference(b.dueDate,a);b.setDueDate(a);k.each(this.steps.slice().reverse(),function(a,b){0<b&&a.dueDate&&a.dueDate.constructor==Date&&a.canModifyDueDate()&&(0<c?a.setDueDate(l.addDaysHours(a.dueDate,0,0,c,!0)):a.setDueDate(l.subtractDaysHours(a.dueDate,0,0,-c,!0)))}.bind(this));return!0};m.prototype.shiftDueDatesToFirst=function(a){var b=l.getWorkingTimeDifference(this.steps[0].dueDate,a);k.each(this.steps,function(a){a.dueDate&&a.dueDate.constructor==
Date&&a.canModifyDueDate()&&(0<b?a.setDueDate(l.addDaysHours(a.dueDate,0,0,b,!0)):a.setDueDate(l.subtractDaysHours(a.dueDate,0,0,-b,!0)))}.bind(this));return!0};m.prototype.distributeDueDatesEvenly=function(a,b){var c=l.getWorkingTimeDifference(a,b);if(0>c)return!1;var d=k.filter(this.steps,function(a){return!a.dueDate?!1:a.canModifyDueDate()});if(0<d.length){var e=a;k.each(d,function(a){e=l.addDaysHours(e,0,0,c/d.length,!0);a.setDueDate(e)}.bind(this))}return!0};m.prototype.changeDueDateType=function(c){var d=
this.dueDateType;if(d!==c){this.dueDateType=c;if(this.dueDateType===b.DueDateType.FIXED){var e=a.getNewCurrentTime();d===b.DueDateType.LEAD_TIMES||d===b.DueDateType.LEAD_TIMES_WITH_FINAL_DATE?k.each(this.steps,function(a){if(a.canModifyDueDate()){var b=a.leadTime;b&&0<b&&(e=l.addDaysHours(e,0,0,b,!0));a.setDueDate(e)}}.bind(this)):d==b.DueDateType.NO&&k.each(this.steps,function(a){a.canModifyDueDate()&&(e=l.addDaysHours(e,1,0,0,!0),a.setDueDate(e))}.bind(this))}else this.dueDateType===b.DueDateType.LEAD_TIMES_WITH_FINAL_DATE&&
!this.finalDueDate&&(this.finalDueDate=a.getNewCurrentTime());this._emit("changed.duedatetype")}};m.prototype.setFinalDueDate=function(a){this.finalDueDate!==a&&(this.finalDueDate=a,this._emit("changed.finalduedate"))};m.prototype.changeInheritApproval=function(a){this.uponNewVersion!==a&&(this.uponNewVersion=a,this._emit("changed.uponnewversion"))};m.prototype.changeApprovalMaster=function(a){"$Me$"==a.substring(0,4)?this.currentUser?(this.approvalMasterType=b.ApprovalMasterType.USER,this.approvalMaster=
this.currentUser.userId):this.setError({errorMsg:"No current user while trying to put the approval master on Me"}):"$PM$"==a.substring(0,4)?(this.approvalMasterType=b.ApprovalMasterType.PROJECT_MANAGER,this.approvalMaster=null):"$Uploader$"==a.substring(0,10)?(this.approvalMasterType=b.ApprovalMasterType.UPLOADER,this.approvalMaster=null):"$Group$"==a.substring(0,7)?(this.approvalMasterType=b.ApprovalMasterType.GROUP,this.approvalMaster=a.substring(7,a.length)):(this.approvalMasterType=b.ApprovalMasterType.USER,
this.approvalMaster=a);this._emit("changed.approvalmaster")};m.prototype.readFromXML=function(a){a&&(this.nextVersion&&(a=-1==a.indexOf("?")?a+"?":a+"&",a+="nextDocVersion=true"),this.readApprovalFromURL(a))};m.prototype.validate=function(){var a={errorMsg:"CAppCouldNotSave",errors:[],warnings:[]},c=(new Date).getTime()-72E5,d=-1;this.isComplexApproval()&&k.some(this.steps,function(a){return k.isEmpty(a.getStageName().trim())}.bind(this))&&a.errors.push({tag:"CAppEmptyNameNotAllowed"});var e=k.filter(this.steps,
function(a){return a.getStageName().trim()});k.uniq(e,function(a){return a.getStageName()}).length!==e.length&&a.errors.push({tag:"CAppSameNameNotAllowed"});if(this.approvalStatus!==b.ApprovalStatus.NOT_DEFINED)if(!this.steps||0===this.steps.length)!0!==this.approvalRuleChanged&&a.errors.push({tag:"CAppCannotSaveOrStartAnEmptyApprovalSetup"});else{for(e=0;e<this.steps.length;e++){var g=this.steps[e];if(!g||!g.approvers||0===g.approvers.length)0===e&&""===g.name?a.errors.push({tag:"CAppPleaseSelectApprovers"}):
a.errors.push({tag:"CAppEmptyStage",parameters:[e+1+": "+g.name]});this.dueDateType===b.DueDateType.FIXED&&g.canModifyDueDate()&&(!g.dueDate||g.dueDate.constructor!=Date?a.warnings.push({tag:"CAppFixedDueDateEmpty"}):(g.dueDate.getTime()<c&&(0===e&&""===g.name?a.warnings.push({tag:"CAppDueDateInPast"}):a.warnings.push({tag:"CAppStageDueDateInPast",parameters:[e+1+": "+g.name]})),g.dueDate.getTime()<d?a.warnings.push({tag:"CAppDueDateBeforePreviousStage",parameters:[e+1+": "+g.name]}):d=g.dueDate.getTime()))}this.dueDateType===
b.DueDateType.LEAD_TIMES_WITH_FINAL_DATE&&((!this.finalDueDate||this.finalDueDate.constructor!=Date)&&a.errors.push({tag:"CAppFinalDueDateEmpty"}),this.finalDueDate.constructor==Date&&this.finalDueDate.getTime()<c&&a.warnings.push({tag:"CAppDueDateInPast"}))}return a};m.prototype.writeToXML=function(){var a;a="<approvalSetup>";this.projectId&&(a=a+"<project>"+f.ElementEncode("projectId",this.projectId),a+=f.ElementEncode("projectName",this.projectName),a+=f.ElementEncode("projectManagerUserId",this.projectManagerUserId),
a+="</project>");this.folderId&&(a+="<folder>",a+=f.ElementEncode("folderId",this.folderId),a+=f.ElementEncode("folderName",this.folderName),a+="</folder>");this.documentId&&(a+="<document>",a+=f.ElementEncode("documentId",this.documentId),a+=f.ElementEncode("documentName",this.documentName),a+=f.ElementEncode("documentVersion",this.documentVersion),a+="</document>");a+="<general>";a+=f.ElementEncode("dueDateType",this.dueDateType);this.dueDateType===b.DueDateType.LEAD_TIMES_WITH_FINAL_DATE&&(this.finalDueDate&&
this.finalDueDate.constructor==Date)&&(a+=f.ElementEncode("finalDueDate",this.finalDueDate.getTime()));a+=f.ElementEncode("uponNewVersion",this.uponNewVersion);a+=f.ElementEncode("generalApprovalStatus",this.approvalStatus);a+=f.ElementEncode("approvalMasterType",this.approvalMasterType);this.approvalMaster&&(a+=f.ElementEncode("approvalMaster",this.approvalMaster));a+=this.notificationInfo.writeToXML();a+="</general>";if(this.steps&&0<this.steps.length){a+="<stages>";for(var c=0;c<this.steps.length;c++){var e=
this.steps[c];if(e)a+=e.writeToXML(c);else throw"Inconsistency in steps, stepObj == null";}a+="</stages>"}return a+="</approvalSetup>"};m.prototype.addNewStage=function(a){var b=this._stageFactory.createApprovalStage();this.addStage(b,a)};m.prototype.addStage=function(a,b){if(-1<this.steps.indexOf(a))throw"Stage already in steps";"number"===typeof b&&0<=b&&b<this.steps.length?this.steps.splice(b,0,a):this.steps.push(a);this._emit("changed.stages.added",a)};m.prototype.addStageAfter=function(a){var b=
this._stageFactory.createApprovalStage(a),a=this.steps.indexOf(a);-1<a&&this.addStage(b,a+1)};m.prototype.removeStage=function(a){var c=this.steps.indexOf(a);-1<c&&this.steps.splice(c,1);0===this.steps.length&&this.setApprovalStatus(b.ApprovalStatus.NOT_DEFINED);this._emit("changed.stages.deleted",a)};m.prototype.removeAllStages=function(){var a=["changed.stages.deleted"];Array.prototype.push.apply(a,this.steps);this.steps=[];this.setApprovalStatus(b.ApprovalStatus.NOT_DEFINED);this._emit.apply(this,
a)};m.prototype.setApprovalStatus=function(a){this.approvalStatus!==a&&(this.approvalStatus=a,this._emit("changed.approvalstatus"))};m.prototype.getStageNumber=function(a){return this.steps.indexOf(a)+1};m.prototype.getStageAtIndex=function(a){return this.steps[a]};m.prototype.getStageCount=function(){return this.steps.length};m.prototype.getStages=function(){return this.steps};m.prototype.moveStage=function(a,b){b>=this.steps.length&&(b=this.steps.length-1);if(a!==b){var c=this.steps[a];c&&(this.steps.splice(a,
1),this.steps.splice(b,0,c),this._emit("changed.stages.moved",c))}};m.prototype.getCurrentUserString=function(){var b="";if(this.currentUser&&this.currentUser.userId){var c=a.findMemberObj("User",this.currentUser.userId,this.projectMembers);c&&(b+=n.getUserNameString(c.firstName,c.lastName,c.userName))}return b};m.prototype.isValidStageName=function(a){return!k.find(this.steps,function(b){return a&&b&&b!==a&&b.getStageName()===a.getStageName()})};m.prototype.getApprovalStatus=function(){return this.approvalStatus===
b.ApprovalStatus.PENDING&&this.globalStatus&&this.globalStatus.status===b.ApprovalStatus.NOT_STARTED?this.globalStatus.status:this.approvalStatus};m.prototype.getApprovalDetailsData=function(){var c={};c.isComplexApproval=this.isComplexApproval();c.steps=[];k.each(this.steps,function(e,d){var g={};c.steps.push(g);g.internalNumber=d;g.number=d+1;g.name=e.name;g.status=e.approvalStatus;if(e.approvalStatus!==b.ApprovalStatus.NOT_STARTED&&e.approvalStatus!==b.ApprovalStatus.PENDING){var h=-1;k.each(e.approvers,
function(a){(a=a.approvalTime)&&a.constructor==Date&&(a=a.getTime());a>h&&(h=a)}.bind(this));0<h&&(g.approvalTime=new Date(h))}g.approvers=[];if(e.approvers)for(var i=0;i<e.approvers.length;i++){var f={};g.approvers.push(f);var l=e.approvers[i];if(l){var j=l.memberObj;j&&(f.user=a.getUserRepresentation(j),f.internalNumber=i,f.type=l.approvalType,f.isRole&&(f.type=f.type.replace("Group","Role")),f.typeLangTag=a.getApprovalTypeLangTag(l),f.status=l.approvalStatus,l.approvedVersion&&(f.approvedVersion=
l.approvedVersion,f.isDifferentVersionApproved=l.approvedVersion!=this.documentVersion),f.approvalTime=l.approvalTime,l.approvedByUserId&&((j=a.findMemberObj("User",l.approvedByUserId,this.projectMembers))||(j=a.findMemberObj("User",l.approvedByUserId,this.usersWithNoAccess)),f.approvedBy=a.getUserRepresentation(j)),l.commentArr&&0<l.commentArr.length&&(f.comments=l.commentArr))}}}.bind(this));return c};m.prototype.isApprovalStarted=function(){return!(this.approvalStatus===b.ApprovalStatus.NOT_STARTED||
this.approvalStatus===b.ApprovalStatus.NOT_DEFINED)};m.prototype.forceStep=function(a){this.forcedStep=a};m.prototype.getActiveStep=function(){for(var a=0;a<this.steps.length;a++)if(this.steps[a]&&this.steps[a].approvalStatus===b.ApprovalStatus.PENDING)return a;return-1};m.prototype.isUserPendingApprover=function(){return 0<=this.getActiveStep()?"MustApprove"===this.currentUserApprovalStatus(this.getActiveStep()):!1};m.prototype.isUserApprover=function(){for(var c=this.currentUser.userId,e=0;e<this.steps.length;e++){var d=
this.steps[e];if(d.approvers)for(var g=0;g<d.approvers.length;g++){var h=d.approvers[g];if(h.approvalType===b.ApprovalType.USER&&h.memberObj.userId==c||h.approvalType===b.ApprovalType.ONE_OF_ROLE&&this.findRoleUserObj(c,h.memberObj.groupId)||a.findMemberObj("User",c,h.memberObj.members))return!0}}return!1};m.getApprovalInfo=function(a){window.gProjectId&&$.ajax({url:"complexapproval.jsp?action=GetBootInfo&projectID="+window.gProjectId+"&docVerID="+window.gDocVersionId,type:"GET",data:"xml",debug:!1,
timeout:12E4,synchronous:!1,cache:!1,success:function(b){b=f.xml2obj(b);if(!b.error){var c=b.complexApprovalBootInfo;if(c&&"1"!=c.isLinkedDocument){var e="complexapproval.jsp?projectID="+window.gProjectId+"&docVerID="+window.gDocVersionId+"&returnURL=docdetailsapprovers.jsp&urlwanted=docdetailsapprovers.jsp&menu_file=&docID="+window.gDocId+"&folderID=",b="1"===c.isViewable,c=new m(e,!1,e,{userId:c.userId,userName:c.userName,lastName:c.lastName,firstName:c.firstName,isProjectManager:"1"==c.isProjectManager,
isAdmin:"1"==c.isAdmin,canForceApprove:"1"==c.canForceApprove,canForceReject:"1"==c.canForceReject,canChangeSetup:"1"==c.canChangeSetup,canStartApproval:"1"==c.canStartApproval,canSeeOthers:"1"==c.canSeeOthers,canCreateUsers:"1"==c.canCreateUsers},"1"==c.stagedApprovalAllowed,e+"&action=Inherit");c.on("initialized",k.partial(a,c));c.isViewFile=b}}},error:function(a,b,c){"SESSION_EXP"==c&&null!=window.loginForm?window.loginForm.submit():window.alert("Error in loadApprovalUser: "+a)}})};m.prototype.getProjectMembers=
function(){return this.projectMembers};m.prototype.getProjectId=function(){return this.projectId};m.prototype.getFolderId=function(){return this.folderId};m.prototype.submit=function(a){this._emit("submit",a)};m.prototype.isStagedApprovalAllowed=function(){return this.stagedApprovalAllowed};m.prototype.isComplexApproval=function(){return 1<this.steps.length};m.prototype.isProjectSetupAvailable=function(){return(this.documentId||this.folderId||!0===this.isMultiDocSetup)&&this.hasProjectApprovalSetup};
m.prototype.isFolderSetupAvailable=function(){return(this.documentId||!0===this.isMultiDocSetup)&&this.hasFolderApprovalSetup};return m});
define("approval/model/ApproveRejectViewModel",["utils/Observable","underscore"],function(b){function a(a,e,d,i){b.mixin(this,"approval");this.actionURL=a;this.isEncapsulated=e;this.isViewFile=d;this.onUpdateCallback=i;this.pageRange=this.approveRejectCallback=null}a.prototype.setPageRange=function(a,b,d){var i="";void 0!==a&&(a=String(a));if(!a||!a.trim()){if(d)return"CAppEmptyPageRange";this.pageRange=null}else{if("all"!=a.trim())for(var d=!0,h=a.trim().split(","),j=0;j<h.length;j++){d?d=!1:i+=
",";var g=h[j].trim().split("-");if(1>g.length||2<g.length)return"CAppInvalidPageRangeExample";for(var l=0;l<g.length;l++){var n=g[l].trim();if(isNaN(parseInt(n)))return"CAppInvalidPageRangeExample";if(1===l){var f=g[0].trim();if(parseInt(n)<parseInt(f))return"CAppInvalidPageRangeExample";i+="-"}i+=parseInt(g[l])-1}}this.pageRange=b?i:a}return""};a.prototype.setBeforeSubmitAction=function(a){this.beforesubmit=a};a.prototype.setAdjustPopupHeight=function(a,b){this.adjustPopupHeight=a;this.toggleAction=
b};a.prototype.submit=function(a){this._emit("submit",a)};return a});
define("approval/controller/SortableController",["jquery","jqueryUI","jqueryUITouchPunch"],function(){var b=function(a,b){var e=null,d=null;this._approvalView=a;a.getStagesContainer().sortable({axis:"y",items:".approval-stage-container-sortable",cancel:"input,select,a,label",scroll:"false",cursor:"grabbing",containment:"body",placeholder:"approval-stage-container-sortable-placeholder",forcePlaceholderSize:!0,handle:".sortable-handler",tolerance:"intersect",start:function(a,b){b.item.addClass("being-sorted");
e=b.item.index()},stop:function(a,h){d=h.item.index();h.item.removeClass("being-sorted");b.moveStage(e,d)}.bind(this)})};b.prototype.disable=function(){this._approvalView.getStagesContainer().sortable("disable")};b.prototype.enable=function(){this._approvalView.getStagesContainer().sortable("enable")};return b});
define("approval/view/NotificationView",["approval/ApprovalConstants","utils/webi18n!Approval","underscore","wcr/webcenter_xml"],function(b,a,c,e){function d(a,b){this._model=a;this._showNotifications=!0;this._editable=b;this._editMode=!1;this._model.on("update",c.bind(this.render,this))}d.prototype.setElement=function(a){this.elem=a;this.render()};d.prototype.render=function(){if(this.elem){var e=$("<div />").addClass("form-group");if(this._editMode){e.append($("<label />").text(a.t("CAppNotifications")));
this.notificationSelector=this._displayNotificationsSelector();e.append($("<div />").addClass("form-entry").html(this.notificationSelector));if(this._model.notificationType!==b.NotificationType.NO_NOTIFICATIONS){var d=$("<div />").addClass("form-group");d.append($("<label />").addClass("offset-label"));var j=$('<a href="#" />').click(c.bind(function(a){this._toggleShowNotifications();a.preventDefault()},this)).text(this._showNotifications?a.t("CAppHideNotifications"):a.t("CAppShowNotifications"));
d.append($("<div />").addClass("form-entry").append($("<p />").append(j)));e.append(d)}this._showNotifications&&e.append(this._displayNotifications())}else if(d=this._model.notificationType,$("<label>",{text:a.t("CAppNotifications")}).appendTo(e),j=$("<div/>",{"class":"form-entry"}).appendTo(e),d=$("<p>",{text:this._getLabel(d)}).appendTo(j),this._editable)d.append($("<a>",{"class":"btn btn-no-border","data-sahi-id":"approval_notif_select_edit"}).append($("<i>",{"class":"icon icon-WCR_Actions-Edit12"}))).on("click",
c.bind(function(){this._editMode=!0;this.render()},this));this.elem.html(e)}};d.prototype._displayNotificationsSelector=function(){var a=[b.NotificationType.NO_NOTIFICATIONS,b.NotificationType.DEFAULT_NOTIFICATIONS,b.NotificationType.CUSTOM_NOTIFICATIONS];!this._model.approvalModel.documentId&&!this._model.approvalModel.folderId&&(a=[b.NotificationType.NO_NOTIFICATIONS,b.NotificationType.CUSTOM_NOTIFICATIONS]);var e=$("<select>",{"class":"form-control","data-sahi-id":"approval_notif_select"});e.change(c.bind(this._changeNotificationSelector,
this));c.each(a,function(a){var b=$("<option>",{value:a,text:this._getLabel(a)});this._model.notificationType===a&&b.prop("selected","true");e.append(b)}.bind(this));return e};d.prototype._displayNotifications=function(){var d=null,h=!1;this._model.notificationType===b.NotificationType.DEFAULT_NOTIFICATIONS&&(d=null!=this._model.approvalModel.folderId&&null==this._model.approvalModel.documentId?this._model.projectNotificationsArr:this._model.defaultNotificationsArr,h=!0);this._model.notificationType==
b.NotificationType.CUSTOM_NOTIFICATIONS&&(d=this._model.notificationsArr);if(!d)return"";var j=$("<div />").addClass("form-group");j.append($("<label />").addClass("offset-label"));var g=$("<table>",{"class":"table",name:"CAppNotificationTable"}),l=$("<tr />");g.append($("<thead />").append(l));j.append($("<div />").addClass("form-entry").append(g));l.append($("<th />").text(a.t("CAppNotification")));for(var n,f=b.notificationTypeArr,k=["projectManager","involvedPeople","projectMembers"],m,s=0;s<
k.length;s++){var q=!0;for(m=0;m<f.length;m++)if(!1===d[m][k[s]]){q=!1;break}n='<th class="td-checkbox"><div><div>';"projectManager"==k[s]?n+=e.xmlencode(a.t("CAppManager")):"involvedPeople"==k[s]?n+=e.xmlencode(a.t("CAppInvolvedPeople")):"projectMembers"==k[s]&&(n+=e.xmlencode(a.t("CAppMembers")));n+="</div>";!1===h&&(n+='<div><input id="notification_'+s+'_All" type="checkbox"',q&&(n+=" checked "),n+="></div>");n+="</div>";n+="</th>";m=$(n);n=s;m.find("#notification_"+s+"_All").click(c.bind(function(a,
b){this._model.toggleNotificationColumn(a,b.is(":checked"))},this,n,m.find("#notification_"+s+"_All")));l.append(m)}for(m=0;m<f.length;m++){l=m;n="<tr>";n+="<td>"+e.xmlencode(a.t("CApp"+f[m]))+"</td>";k="notificationCheck_"+m;n+='<td class="td-checkbox"><input id="'+k+'_0" data-sahi-id='+k+'_0" type="checkbox"';!0===d[m].projectManager&&(n+=" checked ");h&&(n+=' disabled="disabled" ');n+="></td>";n+='<td class="td-checkbox"><input id="'+k+'_1" data-sahi-id='+k+'_1" type="checkbox"';!0===d[m].involvedPeople&&
(n+=" checked ");h&&(n+=' disabled="disabled" ');n+="></td>";n+='<td class="td-checkbox"><input id="'+k+'_2" data-sahi-id='+k+'_2" type="checkbox"';!0===d[m].projectMembers&&(n+=" checked ");h&&(n+=' disabled="disabled" ');n+='"></td>';n+="</tr>";n=$(n);for(k=0;3>k;k++)s=k,n.find("#notificationCheck_"+l+"_"+s).click(c.bind(c.bind(function(a,b,c){this._model.toggleNotification(a,b,c.is(":checked"))},this,l,s,n.find("#notificationCheck_"+l+"_"+s))));g.append(n)}return j};d.prototype._toggleShowNotifications=
function(){this._showNotifications=!this._showNotifications;this.render()};d.prototype._changeNotificationSelector=function(){this._model.setNotificationType(this.notificationSelector.val())};d.prototype._getLabel=function(c){if(c===b.NotificationType.DEFAULT_NOTIFICATIONS)return this._model.approvalModel.documentId&&this._model.approvalModel.folderId&&this._model.approvalModel.hasFolderApprovalSetup?a.t("CAppFolderNotifications"):a.t("CAppProjectNotifications");if(c===b.NotificationType.CUSTOM_NOTIFICATIONS)return!this._model.approvalModel.documentId&&
!this._model.approvalModel.folderId?a.t("CAppProjectNotifications"):a.t("CAppCustomNotifications");if(c===b.NotificationType.NO_NOTIFICATIONS)return a.t("CAppNoNotifications")};return d});
define("tpl!approval/view/template/ApproversTableCommentHover",function(){return function(b){var a;return b=""+('<table class="stdtable" name="comment-hover-table">\r\n\t<tr>\r\n\t\t<th style="text-align:left">'+(null==(a=b.i18n("CAppUser"))?"":_.escape(a))+'</th>\r\n\t\t<th style="text-align:center">'+(null==(a=b.i18n("CAppCommentTime"))?"":_.escape(a))+'</th>\r\n\t\t<th style="text-align:center">'+(null==(a=b.i18n("CAppVersion"))?"":_.escape(a))+"</th>\r\n\t\t<th>"+(null==(a=b.i18n("CAppComment"))?
"":_.escape(a))+"</th>\r\n\t</tr>\r\n</table>")}});
define("approval/view/CommentHoverView","approval/ApprovalUtils tpl!approval/view/template/ApproversTableCommentHover utils/webi18n!Approval Template underscore wcr/webcenter_html".split(" "),function(b,a,c,e,d,i){function h(a){this.model=a}h.prototype.open=function(h,g){if(!d.isEmpty(this.model.approvers)){var l=this.model.approvers[h];if(l&&!d.isEmpty(l.commentArr)){var n=new e(c,a),f=$(n.getRenderedHtml());d.each(l.commentArr,function(a){var e="",d=b.findMemberObj("User",a.commentByUserId,this.model.approvalModel.projectMembers);
d&&(e=i.getUserNameStringActiveText(d.firstName,d.lastName,d.userName,d.isActive,c.t("CAppUserDeactivated"),!1));d="";a.commentTime&&(d=b.getDateHourString(a.commentTime));f.append($("<tr>").append($('<td valign="top">').text(e)).append($('<td valign="top" style="text-align:center">').text(d)).append($('<td valign="top" style="text-align:center">').text(a.commentVersion)).append($('<td valign="top">').text(a.commentText)))}.bind(this));l=f.wrap("<div/>").parent().html();dropdownmenu(g.target,g,[l],
600,null,null,!0,"#ffffcc",!1)}}};return h});
define("tpl!approval/view/template/ApproversTable",function(){return function(b){var a,c;c=""+('<div class="wcr-table no-margin" data-init="component/table/Table" >\r\n\t<div class="wcr-table-section">\r\n\t\t<table class="ordtable" data-sahi-id="CAppObjApprovalTable_'+(null==(a=b.stageIndex)?"":_.escape(a))+'">\r\n\t\t\t<thead>\r\n\t\t\t\t<tr>\r\n\t\t\t\t\t');b.showRemoveColumn&&(c+='\r\n\t\t\t\t\t\t<th class="td-narrow">\r\n\t\t\t\t\t\t\t<i class="icon icon-normal icon-WCR_Remove show-cursor-pointer" name="approvers-remove-all" title="'+(null==
(a=b.i18n("CAppRemoveAllApprovers"))?"":_.escape(a))+'"></i>\r\n\t\t\t\t\t\t</th>\r\n\t\t\t\t\t');c+="\r\n\r\n\t\t\t\t\t<th>"+(null==(a=b.i18n("CAppApprover"))?"":_.escape(a))+"</th>\r\n\t\t\t\t\t<th>"+(null==(a=b.i18n("CAppUserType"))?"":_.escape(a))+"</th>\r\n\t\t\t\t\t";b.showAllColumns&&(c+="\r\n\t\t\t\t\t\t<th>"+(null==(a=b.i18n("CAppStatusVersion"))?"":_.escape(a))+'</th>\r\n\t\t\t\t\t\t<th class="td-date">'+(null==(a=b.i18n("CAppApprovalDate"))?"":_.escape(a))+"</th>\r\n\t\t\t\t\t\t<th>"+(null==
(a=b.i18n("CAppApprovedBy"))?"":_.escape(a))+"</th>\r\n\t\t\t\t\t\t<th>"+(null==(a=b.i18n("CAppApprovalCommentCondition"))?"":_.escape(a))+"</th>\r\n\t\t\t\t\t");return c+'\r\n\t\t\t\t</tr>\r\n\t\t\t</thead>\r\n\t\t\t<tbody name="approvers-body">\r\n\t\t\t\t\t<\!-- Filled in by ApproversTable.js --\>\t\r\n\t\t\t</tbody>\r\n\t\t</table>\r\n\t</div>\r\n</div>'}});
define("tpl!approval/view/template/ApproversTableRoleHover",function(){return function(b){var a,c;c=""+('<table class="stdtable add-spacing-left role-hover" >\r\n\t<tr>\r\n\t\t<th>'+(null==(a=b.i18n("CAppRole"))?"":_.escape(a))+'</th>\r\n\t\t<th class="td-padding">'+(null==(a=b.roleObj.roleName)?"":_.escape(a))+"</th>\r\n\t</tr>\r\n\t");if(b.roleObj.userRoleAssignments){c+="\r\n\t\t";for(var e=0;e<b.roleObj.userRoleAssignments.length;e++)c+="\r\n\t\t\t<tr>\r\n\t\t\t\t<td>"+(null==(a=b.i18n("CAppUser"))?
"":_.escape(a))+'</td>\r\n\t\t\t\t<td class="td-padding">'+(null==(a=b.roleObj.userRoleAssignments[e].name)?"":_.escape(a))+"</td>\r\n\t\t\t</tr>\r\n\t\t";c+="\r\n\t"}c+="\r\n\t";if(b.roleObj.groupRoleAssignments){c+="\r\n\t\t";for(e=0;e<b.roleObj.groupRoleAssignments.length;e++)c+="\r\n\t\t\t<tr>\r\n\t\t\t\t<td>"+(null==(a=b.i18n("CAppGroup"))?"":_.escape(a))+'</td>\r\n\t\t\t\t<td class="td-padding">\r\n\t\t\t\t\t',b.roleObj.groupRoleAssignments[e].assignee&&(c+="\r\n\t\t\t\t\t\t"+(null==(a=b.roleObj.groupRoleAssignments[e].assignee.name)?
"":_.escape(a))+"&nbsp;&#64;&nbsp;\r\n\t\t\t\t\t"),c+="\r\n\t\t\t\t\t"+(null==(a=b.roleObj.groupRoleAssignments[e].name)?"":_.escape(a))+"\r\n\t\t\t\t</td>\r\n\t\t\t</tr>\r\n\t\t";c+="\r\n\t"}return c+"\r\n</table>"}});
define("approval/view/ApproversTable","approval/ApprovalConstants approval/ApprovalUtils approval/view/CommentHoverView utils/Observer tpl!approval/view/template/ApproversTable tpl!approval/view/template/ApproversTableRoleHover utils/webi18n!Approval Template jquery underscore wcr/webcenter_html".split(" "),function(b,a,c,e,d,i,h,j,g,l,n){function f(a){e.mixin(this);this.model=a;this._observe(this.model,"changed.approvers.*",this.render,this);this._observe(this.model,"deleted",this._stopObserveAll,
this);this._commentHoverView=new c(this.model)}f.prototype.setElement=function(a){this.elem=a;this.render()};f.prototype.render=function(){if(this.elem){var a=new j(h,d);a.d.showRemoveColumn=this._showRemoveColumn();a.d.showAllColumns=this._showAllColumns();a.d.stageIndex=this.model.number-1;a.setContext(this.elem);a.bind("click","[name=approvers-remove-all]",function(){this.model.removeAllApprovers()}.bind(this));var a=g(a.getRenderedHtml()),b=a.find("[name=approvers-body]");l.isEmpty(this.model.approvers)?
b.append(g("<tr>").append(g('<td colspan="7">').append(g("<em>",{text:h.t("CAppNoApproversInStep")})))):l.each(this.model.approvers,function(a,c){a&&a.memberObj&&b.append(this._generateRowElement(a,c))}.bind(this));this.elem.html(a)}};f.prototype._generateRowElement=function(c,e){var d=g("<tr>"),f=c.memberObj;this._showRemoveColumn()&&d.append(g('<td class="td-centered">').append(g("<i>",{"class":"icon icon-normal icon-WCR_Remove show-cursor-pointer",title:h.t("CAppRemove"),on:{click:function(){this.model.removeApprover(e)}.bind(this)}})));
if(f.lastName){var i=n.getUserNameStringActiveHTML(null,f.firstName,f.lastName,f.userName,f.isActive,h.t("CAppUserDeactivated"));d.append(g('<td class="td-nowrap">').append(g(i)))}else f.groupName?f.isRole?d.append(g("<td>",{"class":"td-nowrap",on:{mouseover:function(a){this._showRoleHover(a,e)}.bind(this),mouseout:function(){delayhidemenu()}}}).append(g("<i>",{"class":"icon icon-normal icon-blue icon-WCR_Assignee-Role"})).append("&nbsp;"+f.groupName)):(i=g('<td class="td-nowrap">').append(g("<i>",
{"class":"icon icon-normal icon-green icon-WCR_Assignee-Group",title:h.t("CAppGroup")})).append("&nbsp;"+f.groupName),f.isMember&&l.isEmpty(f.members)&&i.append(document.createTextNode(" "+h.t("CAppEmptyIndicator"))),d.append(i)):d.append(g("<td><em>Approver with no name</em></td>"));var i=!this.model.canModifyApprovers(),j="User"===c.approvalType||this.model.approvalModel.approvalStatus!==b.ApprovalStatus.NOT_STARTED||this.model.approvalModel.readOnly||i,i=g("<td>");d.append(i);j?i.append(h.t(a.getApprovalTypeLangTag(c))):
(j=g("<select>",{"class":"form-control",on:{change:function(a){this.model.changeGroupApprover(e,a.target.value)}.bind(this)}}),i.addClass("type-drop-down"),i.append(j),j.attr("data-sahi-id","CAppObjGroupApproverSelector_"+(this.model.number-1)+"_"+e),f.isRole&&j.append(g("<option>",{value:"OneOfRole",text:h.t("CAppOneOfRole")})),j.append(g("<option>",{value:"OneOfGroup",text:f.isRole?h.t("CAppAllOfRoleOneOfGroup"):h.t("CAppOneOfGroup")})),j.append(g("<option>",{value:"AllOfGroup",text:f.isRole?h.t("CAppAllOfRole"):
h.t("CAppAllOfGroup")})),j.val(c.approvalType));this._showAllColumns()&&(f=c.approvalStatus===b.ApprovalStatus.PENDING&&this.model.approvalStatus!==b.ApprovalStatus.PENDING,i=g("<td>"),d.append(i),c.approvalStatus&&(c.approvalStatus!==b.ApprovalStatus.NOT_STARTED&&!f)&&(i.append(g("<i>",{title:h.t("CApp"+this.model.approvalStatus),"class":b.images[c.approvalStatus]+" "+b.imageColors[c.approvalStatus]+" add-spacing-right"})),c.approvalStatus===b.ApprovalStatus.FORCE_APPROVED||c.approvalStatus===b.ApprovalStatus.FORCE_CONDITIONAL_APPROVED||
c.approvalStatus===b.ApprovalStatus.FORCE_REJECTED?i.append(g("<span>").append(h.t("CApp"+c.approvalStatus))):i.append(h.t("CApp"+c.approvalStatus)),c.approvedVersion&&(c.approvedVersion!==this.model.approvalModel.documentVersion?i.append(g("<span>").append("&nbsp;("+c.approvedVersion+")")):i.append("&nbsp;("+c.approvedVersion+")"))),f=g("<td>"),d.append(f),c.approvalTime&&(f.addClass("td-date"),f.append(a.getDateHourString(c.approvalTime))),f=g("<td>"),d.append(f),c.approvedByUserId&&((i=a.findMemberObj("User",
c.approvedByUserId,this.model.approvalModel.projectMembers))||(i=a.findMemberObj("User",c.approvedByUserId,this.model.approvalModel.usersWithNoAccess)),i?f.text(n.getUserNameString(i.firstName,i.lastName,i.userName)):f.text("User ID:"+c.approvedByUserId)),f=g("<td>"),d.append(f),l.isEmpty(c.commentArr)||(f.mouseover(function(a){this._commentHoverView.open(e,a)}.bind(this)),f.mouseout(function(){delayhidemenu()}),i=l.map(c.commentArr,function(a){return a.commentText}).join("<br>"),f.html(i)));return d};
f.prototype._showRoleHover=function(a,b){if(!l.isEmpty(this.model.approvers)){var c=this.model.approvers[b];if(c){var d=c.memberObj;if(d&&d.isRole){c=l.find(this.model.approvalModel.roleAssignments,function(a){return d.groupId===a.roleID});if(null==c)throw Error("cannot find role");var e=new j(h,i);e.d.roleObj=c;dropdownmenu(a.target,a,[e.getRenderedHtml()],"auto",null,null,!0,"#ffffcc",!1)}}}};f.prototype._showAllColumns=function(){return this.model.approvalModel.steps[0].approvalStatus!==b.ApprovalStatus.NOT_STARTED};
f.prototype._showRemoveColumn=function(){return!this.model.approvalModel.readOnly&&this.model.approvalModel.approvalStatus===b.ApprovalStatus.NOT_STARTED&&this.model.canModifyApprovers()};return f});
define("tpl!approval/view/template/ApprovalStage",function(){return function(b){var a,c;c=""+('<div class="wcr-approval-stage" data-sahi-id="Step_'+(null==(a=b.step)?"":_.escape(a))+'">\r\n\t<div class="collapseApprovalStage">\r\n\t\t<a class="pull-right '+(null==(a=b.model.canModifyApprovers()||!this.d.model.approvalModel.isComplexApproval()?"":"collapsed")?"":_.escape(a))+'" title="'+(null==(a=b.i18n("CAppShowStepConfigurationDetails"))?"":_.escape(a))+'" name="collapse-button">\r\n\t\t\t<i class="icon icon-normal" />\r\n\t\t</a>\r\n\t</div>\r\n\t<div class="wcr-approval-stage-panel-container">\r\n\t<div class="panel wcr-form form-labels-on-top '+
(null==(a=b.extraPanelClass)?"":_.escape(a))+'" name="'+(null==(a=b.panelName)?"":_.escape(a))+'" >\r\n\t\t<div class="panel-heading sortable-handler">\r\n\t\t\t<label class="stageNumber">'+(null==(a=b.step+1)?"":_.escape(a))+"</label>\r\n\t\t\t");if(b.showcollapse||b.stepEditable)c+='\r\n\t\t\t<a name="collapse-details-button" data-sahi-id="collapse-details_'+(null==(a=b.step)?"":_.escape(a))+'" class="pull-right add-spacing-right btn  approval-action" title="'+(null==(a=b.i18n("CAppShowStepConfigurationDetails"))?
"":_.escape(a))+'">\r\n\t\t\t\t<i class="icon icon-WCR_AE-min"></i>\r\n\t\t\t</a>\r\n\t\t\t';c+="\r\n\t\t\t";2===b.stepEditable&&!b.readOnly&&(c+='\r\n\t\t\t<a href="#" class="pull-right add-spacing-right btn approval-action action-remove-stage" title="'+(null==(a=b.i18n("CAppRemoveStage"))?"":_.escape(a))+'" data-sahi-id="remove_stage_'+(null==(a=b.step)?"":_.escape(a))+'">\r\n\t\t\t\t<i class="icon icon-normal icon-WCR_Trash"></i>\r\n\t\t\t</a>\r\n\t\t\t');c+='\r\n\t\t\t<label class="label statusLabel" \r\n\t\t\t\t   ';
b.approvalTime&&(c+='\r\n\t\t\t\t   data-toggle="tooltip" data-placement="top" data-title="'+(null==(a=b.approvalTime)?"":_.escape(a))+'"\r\n\t\t\t\t\t');c+="\r\n\t\t\t>\r\n\t\t\t\t";"NotStarted"!=b.approvalStatus&&(c+='\r\n\t\t\t\t\t<i title="'+(null==(a=b.i18n("CApp"+b.approvalStatus))?"":_.escape(a))+'" class="'+(null==(a=b.images[b.approvalStatus])?"":_.escape(a))+'"></i>&nbsp;\r\n\t\t\t\t');c+="\r\n\t\t\t\t"+(null==(a=b.i18n("CApp"+b.approvalStatus))?"":_.escape(a))+'\r\n\t\t\t</label>\r\n\t\t\t<div class="stage-name-container" name="stage-name" />\r\n\t\t</div>\r\n\t\t<div class="collapse '+
(null==(a=b.model.canModifyApprovers()||!this.d.model.approvalModel.isComplexApproval()?"in":"")?"":_.escape(a))+'" name="collapse-target">\r\n\t\t\t<div class="panel-body" id="'+(null==(a=b.model.id)?"":_.escape(a))+"panel_"+(null==(a=b.step)?"":_.escape(a))+'">\r\n\t\t\t\t';if(b.showcollapse||b.stepEditable){c+='\r\n\t\t\t\t\t<div name="collapse-details-target" class="collapse">\r\n\t\t\t\t\t\t<div class="'+(null==(a=b.showcollapse?"step-details-collapse-uneditable":"step-details-collapse")?"":
_.escape(a))+'">\r\n\t\t\t\t\t\t\t';b.showcollapse&&(c+='\r\n\t\t\t\t\t\t\t <div class="form-group">\r\n\t\t\t\t\t\t\t\t<label class="offset-label" />  \r\n\t\t\t\t\t\t\t\t<div class="form-entry">\r\n\t\t\t\t\t\t\t\t\t<div class="checkbox">\r\n\t\t\t\t\t\t\t\t\t\t<label>\r\n\t\t\t\t\t\t\t\t\t\t\t<input type="checkbox" class="Chkbx_CondApp" disabled="disabled" '+(null==(a=b.model.condApp?"checked":"")?"":_.escape(a))+" />   \r\n\t\t\t\t\t\t\t\t\t\t\t"+(null==(a=b.i18n("CAppAllowCondApp"))?"":_.escape(a))+
' \r\n\t\t\t\t\t\t\t\t\t\t</label>\r\n\t\t\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t\t</div>\r\n\r\n\t\t\t\t\t\t\t<div class="form-group">\r\n\t\t\t\t\t\t\t\t<label  style="width: inherit;">'+(null==(a=b.i18n("CAppWhenOneUserRejects"))?"":_.escape(a))+'</label>\r\n\t\t\t\t\t\t\t\t<div class="form-entry" style="width: inherit;">\r\n\t\t\t\t\t\t\t\t\t<p>'+(null==(a=b.rejectHandle?b.i18n("CApp"+b.rejectHandle):b.i18n("CAppStopApprovalAfterEverybodyDecided"))?"":_.escape(a))+'</p>\r\n\t\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t\t</div>\r\n\r\n\t\t\t\t\t\t\t<div class="form-group">\r\n\t\t\t\t\t\t\t\t<label style="width: inherit;">'+
(null==(a=b.i18n("CAppRequiresReviewState"))?"":_.escape(a))+'</label>\r\n\t\t\t\t\t\t\t\t<div class="form-entry" style="width: inherit;">\r\n\t\t\t\t\t\t\t\t\t<p>\r\n\t\t\t\t\t\t\t\t\t\t'+(null==(a=b.i18n("CApp"+b.model.requireReviewHandle))?"":_.escape(a))+"\r\n\t\t\t\t\t\t\t\t\t</p>\r\n\t\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t\t");c+="\r\n\r\n\t\t\t\t\t\t\t";if(2===b.stepEditable){c+='\r\n\t\t\t\t\t\t\t<div class="form-group '+(null==(a=!b.model.approvalModel.systemCondApprovalAllowed||
b.model.condApp&&b.readOnly?"hidden":"")?"":_.escape(a))+'">\r\n\t\t\t\t\t\t\t\t<label class="offset-label"></label>  \r\n\t\t\t\t\t\t\t\t<div class="form-entry">\r\n\t\t\t\t\t\t\t\t\t<div class="checkbox">\r\n\t\t\t\t\t\t\t\t\t\t<label>\r\n\t\t\t\t\t\t\t\t\t\t\t<input  type="checkbox" name="ConditionalApproval"\r\n\t\t\t\t\t\t\t\t\t\t\t  '+(null==(a=b.model.condApp&&(b.model.approvalModel.systemCondApprovalAllowed||b.readOnly)?"checked":"")?"":_.escape(a))+"\r\n\t\t\t\t\t\t\t\t\t\t\t  "+(null==(a=
b.readOnly?'disabled="disabled"':"")?"":_.escape(a))+'\r\n\t\t\t\t\t\t\t\t\t\t\t\tdata-sahi-id="Chkbx_CondApp_'+(null==(a=b.step)?"":_.escape(a))+'"\r\n\t\t\t\t\t\t\t\t\t\t\t/>\r\n\t\t\t\t\t\t\t\t\t\t\t'+(null==(a=b.i18n("CAppAllowCondApp"))?"":_.escape(a))+'\r\n\t\t\t\t\t\t\t\t\t\t</label>\r\n\t\t\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t\t</div>\r\n\r\n\t\t\t\t\t\t\t<\!-- At rejection dropdown label and dropdown --\>\r\n\t\t\t\t\t\t\t<div class="form-group">\r\n\t\t\t\t\t\t\t\t<label>'+
(null==(a=b.i18n("CAppWhenOneUserRejects"))?"":_.escape(a))+'</label>  \r\n\t\t\t\t\t\t\t\t<div class="form-entry">\r\n\t\t\t\t\t\t\t\t\t<div class="input-group">  \r\n\t\t\t\t\t\t\t\t\t\t<select class="form-control" name="RejectionSelect" data-sahi-id="RejectionSelect_'+(null==(a=b.step)?"":_.escape(a))+'"/>\r\n\t\t\t\t\t\t\t\t\t\t<div class="input-group-btn">\r\n\t\t\t\t\t\t\t\t\t\t\t<a class="inline_help" title="'+(null==(a=b.i18n("CAppHelp"))?"":_.escape(a))+'" help-info="CAppRejectionHandlerHelp">\r\n\t\t\t\t\t\t\t\t\t\t\t\t<i class="icon icon-WCR_Info-Balloon"></i>\r\n\t\t\t\t\t\t\t\t\t\t\t</a>\r\n\t\t\t\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t\t</div>\t\r\n\t\t\t\t\t\t\t<div class="form-group">\r\n\t\t\t\t\t\t\t\t<label class="">'+
(null==(a=b.i18n("CAppRequiresReviewState"))?"":_.escape(a))+'</label>  \r\n\t\t\t\t\t\t\t\t<div class="form-entry">\r\n\t\t\t\t\t\t\t\t\t<div class="input-group">\r\n\t\t\t\t\t\t\t\t\t\t<select class="form-control" name="RequireReviewSelect" data-sahi-id="RequireReviewSelect_'+(null==(a=b.step)?"":_.escape(a))+'">\r\n\t\t\t\t\t\t\t\t\t\t\t';for(var e=0;e<b.requireReviewHandlers.length;e++)c+='\r\n\t\t\t\t\t\t\t\t\t\t\t<option value="'+(null==(a=b.requireReviewHandlers[e])?"":_.escape(a))+'" '+(null==
(a=b.requireReviewHandlers[e]==b.model.requireReviewHandle?"selected":"")?"":_.escape(a))+" >\r\n\t\t\t\t\t\t\t\t\t\t\t\t"+(null==(a=b.i18n("CApp"+b.requireReviewHandlers[e]))?"":_.escape(a))+"\r\n\t\t\t\t\t\t\t\t\t\t\t</option>\r\n\t\t\t\t\t\t\t\t\t\t\t";c+='\t\t        \r\n\t\t\t\t\t\t\t\t\t\t</select>\r\n\t\t\t\t\t\t\t\t\t\t<div class="input-group-btn">\r\n\t\t\t\t\t\t\t\t\t\t\t<a class="inline_help"  title="'+(null==(a=b.i18n("CAppHelp"))?"":_.escape(a))+'" help-info="CAppRequireReviewStateHelp">\r\n\t\t\t\t\t\t\t\t\t\t\t\t<i class="icon icon-WCR_Info-Balloon"></i>\r\n\t\t\t\t\t\t\t\t\t\t\t</a>\r\n\t\t\t\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t\t'}c+=
"\r\n\t\t\t\t\t\t</div>\r\n\t\t\t\t\t</div>\r\n\t\t\t\t"}c+='\r\n\t\t\t\t<div name="ApproversTable" />\r\n\t\t\t</div>\r\n\t\t\t<div class="panel-footer hidden" name="footer">\r\n\t\t\t\t<div class="x-drop-form-entry form-entry">\r\n\t\t\t\t\t';b.stepEditable&&(c+='\r\n\t\t\t\t\t\t<div class="approvers-xdrop input-group">\r\n\t\t\t\t\t\t\t<div class="input-group-addon" name="xdrop-addon">\r\n\t\t\t\t\t\t\t\t<i class="icon icon-WCR_Actions-User-Add12" />\r\n\t\t\t\t\t\t\t</div>\r\n\t\t\t\t\t\t</div>\r\n\t\t\t\t\t');
return c+'\r\n\t\t\t\t</div>\r\n\t\t\t\t<div class="due-date-footer" name="due-date-footer" />\t\r\n\t\t\t</div>\r\n\t\t</div>\r\n\t</div>\r\n</div>\r\n</div>'}});
define("tpl!approval/view/template/HourDropDown",function(){return function(b){var a,c;c=""+('<div class="input-group">\r\n\r\n\t<select class="form-control" id="'+(null==(a=b.d.id)?"":_.escape(a))+'" data-sahi-id="'+(null==(a=b.d.id)?"":_.escape(a))+'" name="'+(null==(a=b.d.name)?"":_.escape(a))+'">\r\n\t');for(var e=0;24>e;e++)c+=' \r\n\t\t<option value="'+(null==(a=2*e)?"":_.escape(a))+'" '+(null==(a=b.d.dueHour==2*e?"selected":"")?"":_.escape(a))+" >"+(null==(a=(10>e?"0":"")+e)?"":_.escape(a))+
':00</option>\r\n\t\t<option value="'+(null==(a=2*e+1)?"":_.escape(a))+'" '+(null==(a=b.d.dueHour==2*e+1?"selected":"")?"":_.escape(a))+" >"+(null==(a=(10>e?"0":"")+e)?"":_.escape(a))+":30</option>\r\n\t";return c+='\r\n\t</select>\r\n\t<span for="'+(null==(a=b.d.id)?"":_.escape(a))+'" class="form-datetime-btn input-group-addon">\r\n\t\t<i class="icon icon-normal icon-WCR_Clock"></i>\r\n\t</span>\r\n</div>'}});
define("component/xdrop/dataproviders/ResultSet",["underscore","utils/Observable"],function(b,a){var c=function(){a.mixin(this,"ResultSet");this._pendingCommit=null;this._list=[]};c.prototype.clear=function(){this._list=[];this._deferredCommit()};c.prototype.getEntries=function(){return this._list.slice(0)};c.prototype.getEntriesImmutable=function(){return this._list};c.prototype.getEntry=function(a){return this._list[a]};c.prototype.setEntries=function(a){this._list=a.slice(0);this._deferredCommit()};
c.prototype.append=function(){this._list.push.apply(this._list,arguments);this._deferredCommit()};c.prototype.appendAll=function(a){this.append.apply(this,a)};c.prototype.prepend=function(a){this._list.unshift(a);this._deferredCommit()};c.prototype.getSize=function(){return this._list.length};c.prototype.indexOf=function(a){return b.indexOf(this._list,a)};c.prototype.splice=function(a,b){var c=this._list.splice.apply(this._list,arguments);this._deferredCommit();return c};c.prototype._deferredCommit=
function(){null===this._pendingCommit&&(this._pendingCommit=setTimeout(this.commitChanges.bind(this),10))};c.prototype.commitChanges=function(){null!==this._pendingCommit&&(clearTimeout(this._pendingCommit),this._pendingCommit=null);this._emit("changed")};return c});
define("component/xdrop/dataproviders/XDropDataProvider",["./ResultSet","utils/StringSet","utils/Observable","underscore"],function(b,a,c,e){var d=function(d){c.mixin(this,"dataprovider");this._resultSet=new b;this._options=e.extend({maxResults:-1},d);this._maxResults=this._options.maxResults;this._ongoingLoads=new a};d.prototype.getResultSet=function(){return this._resultSet};d.prototype.setQuery=function(){};d.prototype.setMaxResults=function(a){this._maxResults=a};d.prototype.getMaxResults=function(){return 0>
this._maxResults?this._options.maxResults:0<=this._options.maxResults?Math.min(this._maxResults,this._options.maxResults):-1};d.prototype._startLoading=function(a){var b=this.isLoading();this._ongoingLoads.add(a);b!=this.isLoading()&&this._emit("loading",this.isLoading())};d.prototype.isLoading=function(){return 0<this._ongoingLoads.size()};d.prototype._stopLoading=function(a){var b=this.isLoading();this._ongoingLoads.remove(a);b!=this.isLoading()&&this._emit("loading",this.isLoading())};return d});
define("webcenterapi/data/WebCenterGroup",["utils/FilterUtils","underscore"],function(b,a){var c=function(a,b,c){this._id=a;this._name=b;this._members=c};c.prototype.getId=function(){return this._id};c.prototype.getName=function(){return this._name};c.prototype.getMembers=function(){return this._members};c.prototype.match=function(c,d){var i=b.generateRegex(c,!0);return this._name.match(i)||d&&a.some(this._members,function(a){return a.match(c)})||this.getGroupAssignee()&&this.getGroupAssignee().match(c)};
c.getDisplayIcon=function(){return"icon-green icon-WCR_Assignee-Group"};c.prototype.getDisplayElement=function(a){var b=$("<span>",{text:this.getName()});a&&b.prepend($("<i>",{"class":"icon icon-normal "+this.getDisplayIcon()}));return b};c.prototype.setExtraSAHIMarkers=function(a){this._extraMarker=a};c.prototype.getSAHIMarker=function(){var a=this._extraMarker?" "+this._extraMarker:"";return"WCRGROUP "+this.getName()+a};c.prototype.setGroupAssignee=function(b){this._groupAssignee=b;a.find(this._members,
function(a){return a.getId()===b.getId()})||this.addMember(b)};c.prototype.getGroupAssignee=function(){return this._groupAssignee};c.prototype.addMember=function(a){this._members.push(a)};return c});
define("webcenterapi/data/WebCenterRole",["utils/FilterUtils","underscore"],function(b,a){var c=function(a,b,c){this._id=a;this._name=b;this._members=c};c.prototype.getId=function(){return this._id};c.prototype.getName=function(){return this._name};c.prototype.setMembers=function(a){this._members=a};c.prototype.getMembers=function(){return this._members};c.prototype.match=function(c,d){var i=b.generateRegex(c,!0);return this._name.match(i)||d&&a.some(this._members,function(a){return a.match(c,!1)})};
c.prototype.setExtraSAHIMarkers=function(a){this._extraMarker=a};c.prototype.getSAHIMarker=function(){var a=this._extraMarker?" "+this._extraMarker:"";return"WCRROLE "+this.getName()+a};return c});
define("approval/view/approvalXdrop/ApprovalXDropConversionUtils","webcenterapi/data/WebCenterUser webcenterapi/data/WebCenterGroup webcenterapi/data/WebCenterRole underscore component/xdrop/dataproviders/ResultEntry utils/FilterUtils".split(" "),function(b,a,c,e,d){function i(a){var b={};b.userId=a.getId();b.userName=a.getName();b.firstName=a.getFirstName();b.lastName=a.getLastName();b.memberType="User";b.isActive=a.isActiveUser();return b}function h(a){return{type:"user",data:new b(a.userId||a.ID,
a.userName,a.firstName,a.lastName,a.eMail,a.isActive)}}function j(c){var d=e.map(c.members,function(a){return new b(a.userId,a.userName,a.firstName,a.lastName,a.eMail,a.isActive)}),i=new a(c.groupId||c.ID,c.groupName||c.name,d);c.assignee&&(d=e.find(d,function(a){return a.getId()===c.assignee.ID}),d||(d=h(c.assignee).data),i.setGroupAssignee(d));return{type:"group",data:i}}return{convertToMember:function(d){var h={};if(d instanceof b)h=i(d);else if(d instanceof a)h.groupId=d.getId(),h.groupName=d.getName(),
h.memberType="Group",h.isRole=!1,h.members=e.map(d.getMembers(),i);else if(d instanceof c)h.groupId=d.getId(),h.groupName=d.getName(),h.memberType="Group",h.isRole=!0;else throw"Illegal argument: expected a WebCenterUser, WebCenterGroup or WebCenterRole";return h},transformWebCenterUserToMember:i,createMembersXDropData:function(a,b){var i=e.groupBy(a,function(a){return"Group"===a.memberType?a.isRole?"role":"group":"user"}),f=[];f.push.apply(f,e.flatten(e.map(i.role,function(a){var d=[],f=e.find(b,
function(b){return b.roleID===a.groupId});f&&(d.push.apply(d,e.pluck(e.map(f.userRoleAssignments,h),"data")),d.push.apply(d,e.pluck(e.map(f.groupRoleAssignments,j),"data")));f={type:"role",data:new c(a.groupId,a.groupName)};f.data.setMembers(d);return f})));f.push.apply(f,e.map(i.user,h));f.push.apply(f,e.map(i.group,j));return e.map(f,function(a){return new d(a.type,a.data)})},createWebCenterGroupFromMember:j,createWebCenterUserFromMember:h}});
define("approval/view/approvalXdrop/ApprovalMemberXDropDataProvider",["underscore","component/xdrop/dataproviders/XDropDataProvider","approval/view/approvalXdrop/ApprovalXDropConversionUtils","utils/Observer"],function(b,a,c,e){var d=function(b){a.call(this);e.mixin(this);this._approvalStage=b;this.setQuery("");this._observe(this._approvalStage.approvalModel,"stage.*.changed.approvers.*",function(){this.setQuery(this._query||"")}.bind(this));this._observe(b,"deleted",function(){this._stopObserveAll()}.bind(this))};
d.prototype=Object.create(a.prototype);d.prototype.constructor=d;d.prototype._memberInStage=function(a){return b.some(b.pluck(this._approvalStage.getApprovers(),"memberObj"),function(b){return a.userId&&a.userId===b.userId||a.groupId&&a.groupId===b.groupId})};d.prototype.setMaxResults=function(){};d.prototype.setQuery=function(a){this._query=a;this._resultSet.clear();this._resultSet.appendAll(b.filter(b.filter(this._getXDropReadyMembers(),this._notInStage.bind(this)),function(b){return b.getData().match(a,
!0)}));this._resultSet.commitChanges()};d.prototype._getXDropReadyMembers=function(){var a=b.map(b.clone(this._approvalStage.approvalModel.roleAssignments),b.clone);b.each(a,function(a){a.userRoleAssignments=b.filter(a.userRoleAssignments,b.compose(b.negate(this._memberInStage.bind(this)),function(a){return{userId:a.ID}}));a.groupRoleAssignments=b.filter(a.groupRoleAssignments,b.compose(b.negate(this._memberInStage.bind(this)),function(a){return{groupId:a.ID}}))},this);return c.createMembersXDropData(this._approvalStage.approvalModel.getProjectMembers(),
a)};d.prototype._notInStage=function(a){var d=c.convertToMember(a.getData()),e=!1,g=this._memberInStage(d);d.groupName&&(e=b.some(a.getData().getMembers(),b.compose(b.negate(this._memberInStage.bind(this)),c.convertToMember)),g&&a.setAllowSelection(!1));d.groupName&&(a.getData()._members=b.filter(a.getData().getMembers(),b.compose(b.negate(this._memberInStage.bind(this)),c.convertToMember)));return!g||e};return d});
define("component/xdrop/dataproviders/WCRUserDataProvider","underscore ./XDropDataProvider ./ResultEntry webcenterapi/data/WebCenterUser utils/FilterUtils utils/HTTPUtils wcr/webcenter_xml".split(" "),function(b,a,c,e,d,i,h){var j=function(c,d,e){a.call(this,e);this._data=[];this._dataProviderType=c;this._isActiveUsers=d;this._query="";this._throttledUpdate=b.throttle(this._getUsersList.bind(this),500,{leading:!1})};j.prototype=Object.create(a.prototype);j.prototype.constructor=j;j.prototype.setQuery=
function(a){this._query=a;this._throttledUpdate()};j.prototype.setMaxResults=function(a){this._maxResults=a;this._throttledUpdate()};j.prototype._getUsersListParam=function(){return{list:this._isActiveUsers?"Active":"Inactive",filter:d.preprocessPattern(this._query),maxcount:this.getMaxResults(),json:0}};j.prototype._getUsersList=function(){if(0!==this._maxResults){var a=this._getUsersListParam();this._startLoading("LoadingUsers");$.ajax({url:i.constructURL("GetUserList.jsp",{json:0}),type:"POST",
data:a,success:this._loadCompleted.bind(this),error:this._loadFailed.bind(this),dataType:"xml"})}else this._resultSet.clear()};j.prototype._loadCompleted=function(a){if(null!==a){var b=a.getElementsByTagName("error");if(0<b.length){var c=b[0].getElementsByTagName("message"),b="ERROR in response";0<c.length&&(b=h.GetElementSelfTextContent(c[0]));this._loadFailed(b)}b=[];if(a=a.getElementsByTagName("entry")){b=[];for(c=0;c<a.length;c++){var d=a[c].getElementsByTagName("id")[0].childNodes[0].nodeValue,
i=a[c].getElementsByTagName("name")[0].childNodes[0].nodeValue,j="";a[c].getElementsByTagName("firstname")[0].childNodes[0]&&(j=a[c].getElementsByTagName("firstname")[0].childNodes[0].nodeValue);var s=a[c].getElementsByTagName("lastname")[0].childNodes[0].nodeValue,q="";a[c].getElementsByTagName("email")[0].childNodes[0]&&(q=a[c].getElementsByTagName("email")[0].childNodes[0].nodeValue);var p=1==a[c].getElementsByTagName("status")[0].childNodes[0].nodeValue,d=new e(d,i,j,s,q,p);b.push({type:this._dataProviderType,
data:d,getData:function(){return this.data}})}}this.setData(b);this._stopLoading("LoadingUsers")}else this._loadFailed("Could not load list of users.")};j.prototype._loadFailed=function(a){if(0!==a){a||(a="XHR error");var b=a;"998"==a&&(b="Session expired");throw b;}this._stopLoading("LoadingUsers")};j.prototype.setData=function(a){if(b.some(a,function(a){return!a.type||!a.data}))throw"Data entry should have a type, data and filter property";this._data=a;this.setEntries()};j.prototype.setEntries=
function(){this._resultSet.clear();var a=b.map(this._data,function(a){return new c(a.type,a.data)});this._resultSet.appendAll(a);this._resultSet.commitChanges()};return j});
define("approval/view/approvalXdrop/ApprovalAllUserXDropDataProvider","underscore webcenterapi/data/WebCenterUser component/xdrop/dataproviders/WCRUserDataProvider component/xdrop/dataproviders/ResultEntry ./ApprovalXDropConversionUtils approval/ApprovalUtils utils/Observer utils/FilterUtils utils/webi18n!XDrop".split(" "),function(b,a,c,e,d,i,h,j,g){a=function(a,b,d,e){c.call(this,"user",d,e);h.mixin(this);this._approvalStage=a;this._projectID=b;this._observe(this._approvalStage.approvalModel,"stage.*.changed.approvers.*",
function(){this.setQuery(this._query||"")}.bind(this));this._observe(a,"deleted",function(){this._stopObserveAll()}.bind(this))};a.prototype=Object.create(c.prototype);a.prototype.constructor=a;a.prototype.setEntries=function(){this._resultSet.clear();var a=b.filter(this._data,this._notInProject.bind(this)),c=a;0<=this.getMaxResults()&&(c=b.first(a,this.getMaxResults()));c=b.map(c,function(a){return new e(a.type,a.data)}.bind(this));c=b.filter(c,function(a){a.getData().setExtraSAHIMarkers("not-invited");
return a.getData().match(this._query,!0)}.bind(this));this._resultSet.appendAll(c);0<this.getMaxResults()&&a.length>this.getMaxResults()&&(a=new e("label",g.t("TypeToRefineResults")),a.setAllowSelection(!1),this._resultSet.append(a));this._resultSet.commitChanges()};c.prototype._getUsersListParam=function(){var a=this._approvalStage.approvalModel.getProjectMembers(),a=b.reduce(a,function(a,c){if("User"===c.memberType)return a+(d.createWebCenterUserFromMember(c).data.match(this._query)?1:0);if(c.isGroup)return a+
b.reduce(d.createWebCenterGroupFromMember(c).data.getMembers(),function(a,b){return a+(b.match(this._query)?1:0)}.bind(this),0)}.bind(this),0),c=this.getMaxResults();0<c&&(c+=a+1);return{list:this._isActiveUsers?"Active":"Inactive",filter:j.preprocessPattern(this._query),maxcount:c,json:0}};a.prototype._notInProject=function(a){var b=this._approvalStage.approvalModel.getProjectMembers();return!i.findMemberObj("User",a.getData().getId(),b)};return a});
define("component/xdrop/dataproviders/CompositeDataProvider",["./XDropDataProvider","utils/Observer","underscore"],function(b,a,c){var e=function(d){b.call(this);a.mixin(this);this._providers=[];this._query=null;this._providerIdx=0;this._updateResultSet=c.debounce(this._updateResultSetImpl,20);this.setDataProviders.apply(this,arguments)};e.prototype=Object.create(b.prototype);e.prototype.constructor=e;e.prototype.setQuery=function(a){this._query=a;this._callMethodOnAllProviders("setQuery",a)};e.prototype.setMaxResults=
function(a){this._maxResults=a;this._callMethodOnAllProviders("setMaxResults",a)};e.prototype._callMethodOnAllProviders=function(a){var b=c.rest(arguments);c.each(this._providers,function(c){c.provider[a].apply(c.provider,b)},this)};e.prototype.setDataProviders=function(){var a=c.flatten(arguments,!0),b=this._providers;this._providers=[];c.each(a,function(a){var d=c.findWhere(b,{provider:a});d?(b=c.without(b,d),this._providers.push(d)):this.addDataProvider(a)},this);c.each(b,this._cleanProviderEntry,
this);this._updateResultSet()};e.prototype.addDataProvider=function(a){var b={name:"provider_"+this._providerIdx++,provider:a};this._observe(a,"loading",function(a){a?this._startLoading(name):this._stopLoading(name)});this._observe(a.getResultSet(),"changed",this._updateResultSet);this._providers.push(b);this._query&&a.setQuery(this._query);this._maxResults&&a.setMaxResults(this._maxResults);this._updateResultSet()};e.prototype.removeDataProvider=function(a){if(a=c.findWhere(this._providers,{provider:a}))this._providers=
c.without(this._providers,a),this._cleanProviderEntry(a),this._updateResultSet()};e.prototype._cleanProviderEntry=function(a){this._stopObserveObject(a.provider);this._stopObserveObject(a.provider.getResultSet());this._stopLoading(a.name)};e.prototype._generateResultList=function(){return c.flatten(c.map(this._providers,function(a){return a.provider.getResultSet().getEntriesImmutable()}),!0)};e.prototype._updateResultSetImpl=function(){var a=this._generateResultList();this._resultSet.setEntries(a);
this._resultSet.commitChanges()};return e});
define("component/xdrop/dataproviders/LimitResultsDataProvider",["./CompositeDataProvider","./ResultEntry","underscore","utils/webi18n!XDrop"],function(b,a,c,e){var d=function(d,h){b.apply(this,c.rest(arguments));this._options=c.extend({maxResults:50,extraEntriesShownOnClick:20,showMoreLabel:e.t("LoadMoreResults")},d);this._showExtra=0;var j=this;this._showMoreEntry=new a("button",{getLabel:function(){return j._options.showMoreLabel},getClassNames:function(){return"btn btn-showmore"},doAction:function(){j.setShowExtra(j._showExtra+
j._options.extraEntriesShownOnClick)}});this._showMoreEntry.setKeepSelected(!1);this._showMoreEntry.setDefaultSelectionIndex(70)};d.prototype=Object.create(b.prototype);d.prototype.constructor=d;d.prototype.setQuery=function(a){this._showExtra=0;b.prototype.setQuery.apply(this,arguments)};d.prototype.setShowExtra=function(a){this._showExtra!=a&&(this._showExtra=a,this._updateResultSet())};d.prototype._updateResultSetImpl=function(){this._currentResultList=this._generateResultList();if(this._currentResultList.length>
this._options.maxResults+this._showExtra){var a=this._options.maxResults+this._showExtra-1;this._currentResultList.splice(a,this._currentResultList.length-a,this._showMoreEntry)}this._resultSet.setEntries(this._currentResultList);this._resultSet.commitChanges()};return d});
define("component/xdrop/dataproviders/CreateUserDataProvider",["./XDropDataProvider","./ResultEntry","webcenterapi/data/WebCenterUser","utils/webi18n!UserCreationStrings","require"],function(b,a,c,e,d){c=function(a,c){b.call(this);this._projectId=a;this._folderId=c;this._init()};c.prototype=Object.create(b.prototype);c.prototype.constructor=c;c.prototype._init=function(){this._resultSet.append(this._generateEntry());setTimeout(function(){d(["component/usercreation/CreateNewUserPopup"],function(){})},
1500)};c.prototype.setQuery=function(a){this._query=a};c.prototype._generateEntry=function(){var b=this,c=new a("button",{getLabel:function(){return e.t("CREATE_AND_INVITE_NEW_USER")},doAction:function(c,e){d(["component/usercreation/CreateNewUserPopup"],function(c){c=new c(b._projectId,b._folderId);c.onSubmit(function(b){var c=new a("user",b);b.INCONTEXTCREATED=!0;e.selectResultEntry(c);e.closeXDrop()});c.show(b._query)})},getIcon:function(){return"icon icon-WCR_Actions-User-Add12"}});c.setDefaultSelectionIndex(80);
return c};return c});
define("component/xdrop/dataproviders/CategoryDataProvider",["./CompositeDataProvider","./ResultEntry","underscore","utils/webi18n!XDrop"],function(b,a,c,e){var d=function(d,h){b.apply(this,c.rest(arguments));this._options=c.extend({allowCollapse:!0,collapsedIfNoQuery:!1,expandWhenQueryIsSet:!1,isCollapsed:!1,hideIfNoResults:!0,noMatchesLabel:e.t("NoMatches"),title:"Category",className:"XDrop-category",indicateResultCount:!1},d);var j=this;this._categoryHeaderEntry=new a("categoryTitle",{getTitle:function(){return j._options.title},
allowCollapse:function(){return j._options.allowCollapse},isCollapsed:function(){return j.isCollapsed()},getClassName:function(){return j._options.className},toggle:function(){j._options.allowCollapse&&(j.setCollapsed(!j._options.isCollapsed),j._options.expandWhenQueryIsSet=!1,j._updateResultSet())}});this._categoryHeaderEntry.setDefaultSelectionIndex(0)};d.prototype=Object.create(b.prototype);d.prototype.constructor=d;d.prototype.setQuery=function(a){this._query=a;0<a.length&&this._options.expandWhenQueryIsSet?
(this._options.expandWhenQueryIsSet=!1,this.setCollapsed(!1)):this._pushMaxResults();b.prototype.setQuery.apply(this,arguments)};d.prototype.setMaxResults=function(a){this._maxResults=a;this._pushMaxResults()};d.prototype._pushMaxResults=function(){var a=this._maxResults;this.isCollapsed()&&(a=0);this._callMethodOnAllProviders("setMaxResults",a)};d.prototype.setCollapsed=function(a){this._options.isCollapsed!==a&&(this._options.isCollapsed=a,this._pushMaxResults(),this._updateResultSet())};d.prototype.isCollapsed=
function(){return this._options.allowCollapse&&(this._options.isCollapsed||this._options.collapsedIfNoQuery&&!this._query)};d.prototype._updateResultSetImpl=function(){this._currentResultList=this._generateResultList();var b=[];if(0<this._currentResultList.length||!this._options.hideIfNoResults){if(!this.isCollapsed()&&(b=this._currentResultList.slice(0),0===b.length)){var c=new a("label",this._options.noMatchesLabel);c.setAllowSelection(!1);b.push(c)}b.unshift(this._categoryHeaderEntry)}this._resultSet.setEntries(b);
this._resultSet.commitChanges()};return d});
define("component/xdrop/renderers/UserRenderer",["./Renderer","underscore","jquery"],function(b,a,c){var e=function(a,c,e){b.call(this,a,c,e);this._init()};e.prototype=Object.create(b.prototype);e.prototype.constructor=e;e.prototype._init=function(){var a=this._resultEntry.getData(),b=a.getEmail(),e=a.getDisplayIcon();this._element.append(c("<i>",{"class":"icon icon-normal "+e+" add-spacing-right"})).append(a.getDisplayElement(!1,!1));this._emailElem=c("<div class='more-details'>").append(b);this._element.append(this._emailElem);
this._element.attr("data-sahi-id",a.getSAHIMarker())};e.prototype.setQuery=function(a){this._previousQuery!==a&&(0<a.length&&0<=this._resultEntry.getData().getEmail().indexOf(a)?this._element.append(this._emailElem):this._emailElem.detach());b.prototype.setQuery.apply(this,arguments)};return{make:function(a,b,c){return new e(a,b,c)}}});
define("component/xdrop/renderers/GroupRoleRenderer","./Renderer underscore jquery webcenterapi/data/WebCenterUser component/xdrop/dataproviders/ResultEntry utils/webi18n!XDrop".split(" "),function(b,a,c,e,d,i){var h=function(a,c,d,e,f){b.call(this,a,c,d);this._maxMembers=e;this._iconClass=f;this._init()};h.prototype=Object.create(b.prototype);h.prototype.constructor=h;h.prototype._init=function(){this._element.addClass("group-renderer");this._membersList=c("<ul class='member-list group-member-list'>");
this._moreItem=c("<div class='more-item'>");this._moreItem.on("click",a.partial(function(a,b){var c=parseInt(this.getAttribute("data-start")),d=a._getFilteredMembers(this._previousQuery);a._addMembers(d,c,1<d.length-a._maxMembers?a._maxMembers:d.length);b.stopPropagation();b.preventDefault()},this));var b=this._resultEntry.getData().getName();this._element.append(c("<i>",{"class":"icon icon-normal "+this._iconClass+" add-spacing-right"})).append(c("<span>").text(b)).append(this._membersList).append(this._moreItem);
this._element.attr("data-sahi-id",this._resultEntry.getData().getSAHIMarker())};h.prototype._getMemberLink=function(a,b){return c("<a>",{"data-sahi-id":this._resultEntry.getData().getSAHIMarker()+" "+b.getSAHIMarker(),click:function(c){var e=new d(a,b);this._selectResultEntry(e);this._closeXDrop();c.stopPropagation();c.preventDefault()}.bind(this)}).append(b.getDisplayElement(!1,!0))};h.prototype._addMembers=function(b,d,h){a.each(a.first(a.rest(b,d),h),function(a){var b=a instanceof e?"user":"group",
d=c("<li>",{"class":"group-member "+b});"group"===b&&a.getGroupAssignee()&&(d.append(c("<i class='icon icon-WCR_Cont-Circle12 user'>")),d.append(this._getMemberLink("user",a.getGroupAssignee())),d.append(" @ "));d.append(c("<i class='icon icon-WCR_Cont-Circle12 "+b+"'>"));d.append(this._getMemberLink(b,a));this._membersList.append(d)},this);a.rest(b,d).length>h?(this._moreItem.addClass("has-more-results").text(i.t("LoadMoreResults")),this._moreItem.attr("data-start",h+d)):this._moreItem.removeClass("has-more-results").text("")};
h.prototype._getFilteredMembers=function(b){var b=b||"",c=a.filter(this._resultEntry.getData().getMembers(),function(a){return a.match(b,!1)});0===c.length&&(c=this._resultEntry.getData().getMembers());return c};h.prototype.setQuery=function(a){if(this._previousQuery!==a){this._previousQuery=a;this._membersList.empty();var b=this._getFilteredMembers(a);this._addMembers(b,0,1<b.length-this._maxMembers?this._maxMembers:b.length);this._resultEntry.allowSelection()?(this._element.removeHighlightText("xdrop-hightlightMatch"),
this._element.highlightText(a,"xdrop-hightlightMatch")):(this._membersList.removeHighlightText("xdrop-hightlightMatch"),this._membersList.highlightText(a,"xdrop-hightlightMatch"))}};return h});define("component/xdrop/renderers/GroupRenderer",["./GroupRoleRenderer","underscore","jquery","webcenterapi/data/WebCenterUser"],function(b){var a=function(a,e,d,i,h){b.call(this,a,e,d,i,h)};a.prototype=Object.create(b.prototype);a.prototype.constructor=a;return{make:function(b,e,d){return new a(b,e,d,5,"icon-green icon-WCR_Assignee-Group")}}});
define("component/xdrop/renderers/RoleRenderer",["./GroupRoleRenderer","underscore","jquery","webcenterapi/data/WebCenterUser"],function(b){var a=function(a,e,d,i,h){b.call(this,a,e,d,i,h)};a.prototype=Object.create(b.prototype);a.prototype.constructor=a;return{make:function(b,e,d){return new a(b,e,d,3,"icon-blue icon-WCR_Assignee-Role")}}});
define("component/xdrop/renderers/ButtonRenderer",["./Renderer","jquery"],function(b,a){var c=function(c,d,i){b.call(this,c,d,i);c=a("<a>",{"class":"btn btn-primary action-button",text:this._resultEntry.getData().getLabel()});d.getData().getClassNames&&(c.removeClass(),c.addClass(d.getData().getClassNames()),c.addClass("action-button"));d.getData().getIcon&&(c.prepend("&nbsp;"),c.prepend(a("<i>",{"class":d.getData().getIcon(),title:this._resultEntry.getData().getLabel()})));this._element.append(c)};
c.prototype=Object.create(b.prototype);c.prototype.constructor=c;c.prototype.activate=function(a){this._focusResultEntry(this._resultEntry);this._resultEntry.getData().doAction(a,this._api)};return{make:function(a,b,i){return new c(a,b,i)}}});
define("component/xdrop/renderers/CategoryTitleRenderer",["./Renderer","jquery"],function(b,a){var c=function(c,d,i){b.call(this,c,d,i);this._element.addClass(d.getData().getClassName());this._icon=a();d.getData().allowCollapse()&&(this._icon=a("<i>",{"class":"icon"}));this._title=a("<span>",{"class":"title",text:d.getData().getTitle()});this._element.attr("data-sahi-id","XDROPCATEGORY "+d.getData().getTitle());this._element.append(this._icon).append(this._title);this.render()};c.prototype=Object.create(b.prototype);
c.prototype.constructor=c;c.prototype.activate=function(){this._resultEntry.getData().toggle()};c.prototype.setQuery=function(){};c.prototype.render=function(){var a=this._resultEntry.getData().isCollapsed();this._icon.toggleClass("icon-WCR_Right-S",a).toggleClass("icon-WCR_Down-S",!a)};return{make:function(a,b,i){return new c(a,b,i)}}});
define("approval/view/ApprovalXDrop","underscore approval/view/approvalXdrop/ApprovalMemberXDropDataProvider approval/view/approvalXdrop/ApprovalAllUserXDropDataProvider component/xdrop/dataproviders/CompositeDataProvider component/xdrop/dataproviders/LimitResultsDataProvider component/xdrop/dataproviders/CreateUserDataProvider component/xdrop/dataproviders/CategoryDataProvider component/xdrop/renderers/UserRenderer component/xdrop/renderers/GroupRenderer component/xdrop/renderers/RoleRenderer component/xdrop/renderers/ButtonRenderer component/xdrop/renderers/CategoryTitleRenderer approval/view/approvalXdrop/ApprovalXDropConversionUtils approval/ApprovalUtils component/xdrop/XDrop utils/Observable utils/Observer utils/webi18n!Approval require".split(" "),function(b,
a,c,e,d,i,h,j,g,l,n,f,k,m,s,q,p,t,u){var v={user:j,group:g,role:l,button:n,categoryTitle:f},j=function(b,f){q.mixin(this,"ApprovalXDrop");p.mixin(this);this._approvalStage=b;this._projectMembersDataProvider=new a(b);var g=[],j=new h({title:t.t("CAppXDropCurrentProjectCategory"),hideIfNoResults:!1},this._projectMembersDataProvider);g.push(j);var k,j=b.approvalModel.currentUser;if(j.isProjectManager||j.isAdmin){this._allActiveUserXDropDataProvider=new c(b,f,!0,{maxResults:20});var l=new h({title:t.t("CAppXDropOtherCategory"),
isCollapsed:!0,hideIfNoResults:!1,expandWhenQueryIsSet:!0},this._allActiveUserXDropDataProvider);g.push(l);this._allInactiveUserXDropDataProvider=new c(b,f,!1,{maxResults:10});l=new h({title:t.t("CAppXDropDeactivatedUser"),isCollapsed:!0,expandWhenQueryIsSet:!0,hideIfNoResults:!0},this._allInactiveUserXDropDataProvider);g.push(l);if(j.canCreateUsers||j.isAdmin)k=b.approvalModel.getFolderId(),k=new i(f,k)}g=new d({maxResults:50},g);g=k?new e(g,k):g;this._xdrop=new s(g,v,{placeholder:t.t("CAppXDropPlaceholder")});
this.element=this._xdrop.getElement();this.element.attr("data-sahi-id","AddApproverXDrop_"+(b.number-1));this._observe(this._xdrop,"selected",this._handleXDropSelection)};j.prototype._handleXDropSelection=function(a){var c=this._approvalStage.approvalModel;if(a){var d=m.findMemberObj("group"===a.getType()||"role"===a.getType()?"Group":"User",a.getData().getId(),c.getProjectMembers()),e=!0;d||(e=!1,d=k.convertToMember(a.getData()));if("user"==a.getType()){var f=a.getData();if(!f.INCONTEXTCREATED&&
(!e||!f.isActiveUser())){var h=c.getProjectId(),g=c.getFolderId();u(["component/usercreation/InviteMemberPopup"],function(i){var j=e&&!f.isActiveUser(),i=new i(a.getData(),h,g,j);i.onSubmit(function(){d.isActive=!0;"User"===d.memberType&&(b.chain(c.getProjectMembers()).where({memberType:"Group",isRole:!1}).pluck("members").flatten().where({userId:d.userId}).each(function(a){a.isActive=!0}),b.chain(c.roleAssignments).pluck("userRoleAssignments").flatten().where({ID:d.userId}).each(function(a){a.isActive=
!0}));this._emit("selected",d)}.bind(this));i.onCancel(function(){this.setValue(null)}.bind(this));i.show()}.bind(this));return}}this._emit("selected",d)}};j.prototype.setValue=function(a){this._xdrop.setValue(a)};j.prototype.toggle=function(){this._xdrop.toggle(!this._xdrop.isOpen())};return j});
define("approval/view/ApprovalStageView","approval/ApprovalConstants approval/ApprovalUtils approval/view/ApproversTable component/tooltip/Tooltip Template tpl!approval/view/template/ApprovalStage tpl!approval/view/template/HourDropDown utils/Observer utils/webi18n!Approval approval/view/ApprovalXDrop utils/datetools jquery underscore".split(" "),function(b,a,c,e,d,i,h,j,g,l,n,f,k){function m(a){j.mixin(this);this.model=a;this._observe(this.model,"changed.number",this._updateNumber.bind(this));this._observe(this.model,
"changed.number",this._renderRejectHandleOptions.bind(this));var b=window.webcenterConfig.userLang||"en";this._helpArr={};this._helpArr.CAppRejectionHandlerHelp="./help/RejectionHandlerHelp_"+b+".htm";this._helpArr.CAppRequireReviewStateHelp="./help.jsp?topic=common/wc/task/ta_wc_RequireAnnotationsReview-Approval&lang="+b;this.approvalsTableView=new c(this.model);this.t=new d(g,i);this.t.bind("click","div.panel-heading .action-remove-stage",this.removeStepDialog,this);this.t.bind("click","a.inline_help",
function(a){a=f(a).attr("help-info");window.open(this._helpArr[a],a).focus()},this);this.t.bind("change","[name=ConditionalApproval]",this.changeCondApproval,this);this.t.bind("change","[name=RejectionSelect]",this.changeRejection,this);this.t.bind("change","[name=RequireReviewSelect]",this.changeRequireReview,this);this.t.bind("click","[name=collapse-button]",function(){f("[name=collapse-target]",this.elem).collapse("toggle")},this);this.t.bind("show.bs.collapse","[name=collapse-target]",function(a,
b){b.target===a&&f("[name=collapse-button]",this.elem).removeClass("collapsed")},this);this.t.bind("hide.bs.collapse","[name=collapse-target]",function(a,b){b.target===a&&f("[name=collapse-button]",this.elem).addClass("collapsed")},this);this.t.bind("click","[name=collapse-details-button]",function(){var a=f("[name=collapse-target]",this.elem),b=f("[name=collapse-details-target]",this.elem);"true"!==a.attr("aria-expanded")?b.add(a).collapse("show"):b.collapse("toggle")},this);this.t.bind("click",
"[name=xdrop-addon]",function(a,b){b.stopPropagation();this._approverXDrop.toggle()},this);this._observeAll(this.model.approvalModel,["stage.*.changed.name","changed.stages.**"],this._renderStageName.bind(this));this._observe(this.model.approvalModel,"changed.duedatetype",this._renderDueDate.bind(this));this._observeAll(this.model.approvalModel,["changed.stages.deleted","changed.stages.added"],this._updateActions.bind(this));this._observeAll(this.model,["changed.duedate","changed.leadtime"],this._renderDueDate.bind(this));
this._observe(this.model,"deleted",function(){this.elem.remove();this._stopObserveAll()}.bind(this));this._approverXDrop=new l(a,a.approvalModel.getProjectId());this._approverXDrop.on("selected",a.addApprover.bind(a));this._observe(this.model,"changed.approvers.added",function(){this._approverXDrop.setValue(null)}.bind(this));this.elem=f("<div>");this.t.setContext(this.elem)}m.prototype._updateNumber=function(){this.elem&&this.elem.find(".stageNumber").text(this.model.number)};m.prototype.render=
function(){this.elem&&(this._approverXDrop.element.detach(),this._renderStep(),this._renderApproverTable(),this._renderDueDate(),this._renderRejectHandleOptions(),this._renderXDrop(),this._renderStageName(),this._updateActions())};m.prototype._renderStep=function(){this._approverXDrop.element.detach();var c=this.model.number-1;this.t.d.step=c;this.t.d.model=this.model;this.t.d.readOnly=this.model.approvalModel.readOnly;var d=2;this.model.approvalModel.readOnly&&(d=0);this.model.approvalModel.approvalStatus!==
b.ApprovalStatus.NOT_STARTED&&(d=0);this.model.approvalStatus!==b.ApprovalStatus.NOT_STARTED&&this.model.approvalStatus!==b.ApprovalStatus.PENDING&&(d=0);2===d&&this.model.approvalStatus===b.ApprovalStatus.PENDING&&(d=1);this.t.d.stepEditable=d;this.t.d.approvalStatus=this.model.approvalStatus;this.t.d.images=b.images;this.t.d.approvalTime="";if(this.model.approvalStatus!=b.ApprovalStatus.NOT_STARTED&&this.model.approvalStatus!=b.ApprovalStatus.PENDING){for(var h=-1,g=0;g<this.model.approvers.length;g++){var i=
this.model.approvers[g].approvalTime;i&&i.constructor==Date&&(i=i.getTime());i>h&&(h=i)}0<h&&(this.t.d.approvalTime=a.getDateHourString(new Date(h)))}this.t.d.showcollapse=!1;if(this.model.approvalStatus!=b.ApprovalStatus.NOT_STARTED&&!1===this.model.approvalModel.readOnly){this.t.d.showcollapse=!0;this.t.d.allowConditional=!1;if(this.model.systemCondApprovalAllowed||this.model.condApp)this.t.d.allowConditional=!0;this.t.d.rejectHandle=null;if("RejectStopsApprovalAfterStep"!=this.model.rejectHandle||
this.model.approvalModel.isComplexApproval())this.t.d.rejectHandle=this.model.rejectHandle}this.t.d.optionArr=this.model===k.last(this.model.approvalModel.steps)?b.rejectionHandlersSimple:b.rejectionHandlersComplex;d&&(this.t.d.requireReviewHandlers=b.requireReviewHandlers);d="";this.t.d.showcollapse&&!this.t.d.showBottom&&(d+=" only-approvers-table");d+=" panel-"+this.model.approvalStatus;this.t.d.extraPanelClass=d;this.t.d.extraPanelName="panel_"+c;this.t.render();c=f('[data-toggle="tooltip"]',
this.elem);k.each(c,function(a){new e(void 0,f(a),this.elem,f("body"),!1,f(a).attr("data-title"),void 0,void 0,{prefPosition:f(a).attr("data-placement")})}.bind(this))};m.prototype._renderApproverTable=function(){this.approvalsTableView.setElement(f("[name=ApproversTable]",this.elem))};m.prototype.removeStepDialog=function(a,b){b.preventDefault();b.stopPropagation();this._confirm(g.t("CAppConfirmRemoveStep"),function(){this.model.remove()}.bind(this))};m.prototype._confirm=function(a,b,c){window.confirm(a)?
k.isFunction(b)&&b():k.isFunction(c)&&c()};m.prototype.changeCondApproval=function(a){this.model.setConditionalApproval(a.checked)};m.prototype.changeRejection=function(a){this.model.setRejectHandle(a.value)};m.prototype.changeRequireReview=function(a){this.model.setRequireReviewHandle(a.value)};m.prototype._renderDueDate=function(){var a=f("[name=due-date-footer]",this.elem);if(this.model.approvalModel.readOnly||this.model.approvalModel.approvalStatus!==b.ApprovalStatus.NOT_STARTED||this.model.approvalStatus!==
b.ApprovalStatus.NOT_STARTED)a.html(this._renderReadOnlyFooter()),a.removeClass("hidden");else{var c=this.model.approvalModel.dueDateType;"FixedDueDates"===c?(a.html(this._renderFixedDueDatesFooter()),a.removeClass("hidden")):"LeadTimes"===c||"LeadTimesFinalDueDate"===c?("NotStarted"==this.model.approvalStatus?a.html(this._renderLeadTimesFooter()):a.html(this._renderFixedDueDatesFooter()),a.removeClass("hidden")):a.addClass("hidden")}};m.prototype._renderXDrop=function(){var a=f("[name=footer]",this.elem);
f(".approvers-xdrop",this.elem).append(this._approverXDrop.element);a.removeClass("hidden")};m.prototype._renderFixedDueDatesFooter=function(){var a=f("<div>"),b=n.fixDateSummerWinterTime(this.model.dueDate,!1),c=new d(g,h);c.d.d={dueHour:2*b.getHours()+Math.floor(b.getMinutes()/30),name:"hourdropdown",id:"CAppDueHour_"+(this.model.number-1)};var e=f("<input>",{"class":"form-control","data-sahi-id":"CAppDueDateText_"+(this.model.number-1),value:n.getDateString(b),type:"text",name:"datepicker"}),b=
f(c.getRenderedHtml()),i=b.find("[name=hourdropdown]"),c=f('<span class="form-datetime-btn input-group-addon">');c.on("click",function(){f(e).datepicker("show")});a.append(b).append(f('<div class="input-group input-group-datepicker">').append(e).append(c.append(f('<i class="icon icon-WCR_Calendar" >'))));this._createCalendar(e,i);b=function(){var a=e.val(),b=i.val();if(a=n.getDateString(a)){var a=new Date(a),c=Math.floor(b/2),b=2*c==b?0:30;a.setHours(c);a.setMinutes(b);a.setSeconds(0);b=n.fixDateSummerWinterTime(a,
!0);isNaN(b.getTime())?e.val(n.getDateString(n.fixDateSummerWinterTime(this.model.dueDate,!1))):this.model.setDueDate(b)}else e.val(n.getDateString(n.fixDateSummerWinterTime(this.model.dueDate,!1)))}.bind(this);e.change(b);i.change(b);return a};m.prototype._renderLeadTimesFooter=function(){var a=f("<div>");this.model.leadTime||this.model.setLeadTime(864E5);var b=this.model.getLeadTimeInDaysAndHours(),c=f("<input>",{"class":"form-control","data-sahi-id":"leadTimeHours_"+(this.model.number-1),type:"text",
value:b.hours}),d=f("<input>",{"class":"form-control","data-sahi-id":"leadTimeDays_"+(this.model.number-1),type:"text",value:b.days});a.append(f('<div class="input-group input-group-leadtime">').append(c).append(f('<span class="input-group-addon">').append(g.t("CAppHours")))).append(f('<div class="input-group input-group-leadtime">').append(d).append(f('<span class="input-group-addon">').append(g.t("CAppDays"))));var e=function(){var a=this.model.getLeadTimeInDaysAndHours();d.val(a.days);c.val(a.hours)}.bind(this),
b=function(){var a=parseInt(d.val(),10),b=parseInt(c.val(),10);isNaN(a)||0>a?e():isNaN(b)||0>b?e():(a=24*a+b,8760>=a?this.model.setLeadTime(36E5*a):31536E6!==this.model.leadTime?this.model.setLeadTime(31536E6):e())}.bind(this);c.change(b);d.change(b);return a};m.prototype._renderReadOnlyFooter=function(){var b=f("<div>");if(this.model.dueDate)return b.append(f("<span>").append(f("<strong>").text(g.t("CAppDueDate"))).append(a.getDateHourString(this.model.dueDate)));if(this.model.leadTime){var c=this.model.getLeadTimeInDaysAndHours();
return b.append(f("<span>").append(f("<strong>").text(g.t("CAppLeadTime"))).append(c.days+g.t("CAppDaysAbbreviation")+" "+c.hours+g.t("CAppHoursAbbreviation")))}};m.prototype._createCalendar=function(a,b){f(a).datepicker({dateFormat:"M dd, yy",onClose:function(){var a=f(b)[0];a&&0===a.selectedIndex&&(a.selectedIndex=37)}})};m.prototype._renderRejectHandleOptions=function(){var a=f("[name=RejectionSelect]",this.elem),c;c=this.model===k.last(this.model.approvalModel.steps)?b.rejectionHandlersSimple:
b.rejectionHandlersComplex;var d=[];k.each(c,function(a){var b;b="RejectStopsApprovalAfterStep"===a&&!this.model.approvalModel.isComplexApproval()?g.t("CAppStopApprovalAfterEverybodyDecided"):g.t("CApp"+a);d.push(f("<option>",{value:a,text:b}))}.bind(this));a.html(d);a.val(this.model.rejectHandle)};m.prototype._renderStageName=function(){var a=f("[name=stage-name]",this.elem);if(0<a.length&&(a.empty(),this.model.approvalModel.isStagedApprovalAllowed()))if(this.model.canModifyStageName()){a.addClass("editable");
var b=this.model.hasValidStageName();b?a.addClass("has-error"):a.removeClass("has-error");a.append(f("<input>",{"class":"form-control stageNameEditable",type:"text",value:this.model.name,on:{change:function(a){this.model.setStageName(a.currentTarget.value)}.bind(this)},"data-sahi-id":"stepName_"+(this.model.number-1),placeholder:g.t("CAppStage")})).append(f("<span>",{"class":"stageNameErrorMsg danger",text:g.t(b)}))}else a.removeClass("editable"),a.append(f("<label>",{"class":"stageName",text:this.model.name}))};
m.prototype._updateActions=function(){var a=f(".action-remove-stage",this.elem);1<this.model.approvalModel.steps.length?a.removeClass("displayNone"):a.addClass("displayNone")};return m});
define("approval/view/AddApprovalStageView",["jquery","approval/model/ApprovalStage","utils/webi18n!Approval","utils/Observer"],function(b,a,c,e){a=function(a,i){e.mixin(this);this._model=a;this._stage=i;this._observe(this._model,"changed.stages.*",this._updateAlwaysVisible.bind(this));this._observe(this._stage,"deleted",function(){this._stopObserveAll();this._container.remove()},this);this._alwaysVisible=null;this._element=b("<div>",{"class":"add-approval-stage"});this._icon=b("<span>",{}).text(" "+
c.t("CAppInsertStep")).prepend(b("<i>",{"class":"icon icon-WCR_Actions-Add"})).appendTo(this._element);this._container=b("<div>",{"class":"add-approval-stage-container"});this._element.appendTo(this._container);this._element.attr("data-sahi-id","add_stage_"+(this._stage.number-1));this._element.on("click",function(a){a&&(this._timeout&&(window.clearInterval(this._timeout),this._timeout=null),a.stopPropagation(),a.preventDefault(),this._container.removeClass("add-approval-stage_expanded"));this._addNewStage()}.bind(this));
this._element.on("touchstart",function(a){a.stopPropagation();a.preventDefault();this._container.removeClass("add-approval-stage_expanded");this._addNewStage()}.bind(this));this._container.on("touchstart",function(a){a.preventDefault();this._container.addClass("add-approval-stage_expanded");window.setTimeout(function(){this._container.removeClass("add-approval-stage_expanded")}.bind(this),1750)}.bind(this));this._container.on("mouseenter",function(){this._timeout=window.setTimeout(function(){this._timeout=
null;this._container.addClass("add-approval-stage_expanded")}.bind(this),100)}.bind(this));this._container.on("mouseleave",function(){this._collapsePlaceholder()}.bind(this));this._updateAlwaysVisible()};a.prototype.getElement=function(){return this._container};a.prototype._addNewStage=function(){this._model.addStageAfter(this._stage)};a.prototype._collapsePlaceholder=function(){this._timeout&&(window.clearInterval(this._timeout),this._timeout=null);this._container.removeClass("add-approval-stage_expanded")};
a.prototype._updateAlwaysVisible=function(){var a=this._model.getStageNumber(this._stage)===this._model.getStageCount();a!==this._alwaysVisible&&((this._alwaysVisible=a)?(this._container.addClass("add-approval-stage_always-visible"),this._icon.text(" "+c.t("CAppAddStep")).prepend(b("<i>",{"class":"icon icon-WCR_Actions-Add"}))):(this._container.removeClass("add-approval-stage_always-visible"),this._icon.text(" "+c.t("CAppInsertStep")).prepend(b("<i>",{"class":"icon icon-WCR_Actions-Add"}))))};return a});
define("approval/view/ApprovalStageContainer","jquery approval/view/ApprovalStageView approval/view/AddApprovalStageView approval/ApprovalConstants utils/Observer utils/AnimationFrameRenderer".split(" "),function(b,a,c,e,d,i){var h=function(c,e){d.mixin(this);i.mixin(this);this.element=b("<div>",{"class":"approval-stage-container"});this._approvalModel=c;this.stageModel=e;this._approvalStageView=new a(e);this._observe(e,"deleted",function(){this.element.remove();this._stopObserveAll()}.bind(this))};
h.prototype.render=function(){this._render()};h.prototype._doRender=function(){!this._approvalModel.readOnly&&this._approvalModel.isStagedApprovalAllowed()&&(this._approvalModel.approvalStatus===e.ApprovalStatus.NOT_STARTED||this._approvalModel.approvalStatus===e.ApprovalStatus.NOT_DEFINED)&&(this.stageModel.approvalStatus===e.ApprovalStatus.NOT_STARTED||this.stageModel.approvalStatus===e.ApprovalStatus.PENDING)?this._addApprovalStageView||(this._addApprovalStageView=new c(this._approvalModel,this.stageModel),
this.stageModel.approvalStatus!==e.ApprovalStatus.PENDING?this.element.addClass("approval-stage-container-sortable"):this.element.removeClass("approval-stage-container-sortable"),this.element.addClass("approval-stage-container-insertable")):(this._addApprovalStageView=null,this.element.removeClass("approval-stage-container-sortable"));this._approvalStageView.elem.detach();this._addApprovalStageView&&this._addApprovalStageView.getElement().detach();this.element.empty();this.element.append(this._approvalStageView.elem);
this._addApprovalStageView&&this.element.append(this._addApprovalStageView.getElement());this._approvalStageView.render();return this.element};return h});
define("tpl!approval/view/template/ApproveRejectDialog",function(){return function(b){var a,c;c=""+('<div class="add-spacing-left add-spacing-right add-spacing-top add-spacing-bottom">\r\n\t<form="" name="approveRejectDialog" onsubmit="return false;">\r\n\t\t<span class="help-block">\r\n\t\t\t<strong>'+(null==(a=b.i18n("CApp"+b.approvalStatus))?"":_.escape(a))+'</strong>\r\n\t\t</span>\r\n\t\t<div id="extraApprovalContent"></div>\r\n\t\t');"Approved"===b.approvalStatus||"ForceApproved"===b.approvalStatus?
(c+="\t\r\n\t\t\t",b.conditionApproval?c+='\r\n\t\t\t\t<div>\r\n\t\t\t\t\t<label>\r\n\t\t\t\t\t\t<input type="checkbox" name="approvalConditionChkBx">&nbsp;'+(null==(a=b.i18n("CAppSetApprovalCondition"))?"":_.escape(a))+'\r\n\t\t\t\t\t</label>\r\n\t\t\t\t</div>\r\n\t\t\t\t<textarea class="form-control" style="display:none;" rows="4" name="ApprovalComments" id="ApproveRejectComments"></textarea>\r\n\t\t\t\t<span id="UseAnnotationsMsg" class="help-block" style="display: none;">'+(null==(a=b.i18n("CAppUseAnnotations"))?
"":_.escape(a))+"</span>\r\n\t\t\t":(c+="\r\n\t\t\t\t"+(null==(a=b.i18n("CAppConfirmNoConditions"))?"":_.escape(a))+"<br/>\r\n\t\t\t\t",c=b.isViewFile?c+("\r\n\t\t\t\t\t"+(null==(a=b.i18n("CAppAnnotationsDisregarded"))?"":_.escape(a))+"\r\n\t\t\t\t"):c+("\r\n\t\t\t\t\t"+(null==(a=b.i18n("CAppCommentsDisregarded"))?"":_.escape(a))+"\r\n\t\t\t\t"),c+="\r\n\t\t\t")):(c+="\r\n\t\t\t",c=b.blockComment?c+('\r\n\t\t\t\t<textarea  style="display: none;" rows="4"  class="form-control" name="ApprovalComments"  id="ApproveRejectComments" disabled="disabled">'+
(null==(a=b.i18n("CAppDocumentAnnotated"))?"":_.escape(a))+'</textarea>\r\n\t\t\t\t<span id="UseAnnotationsMsg" class="help-block">'+(null==(a=b.i18n("CAppUseAnnotations"))?"":_.escape(a))+"</span>\r\n\t\t\t"):c+("\r\n\t\t\t\t"+(null==(a=b.i18n("CAppComment"))?"":_.escape(a))+'\r\n\t\t\t\t<textarea class="form-control" style="" rows="4" name="ApprovalComments" id="ApproveRejectComments"></textarea>\r\n\t\t\t'));c+="\r\n\t\t\r\n\t\t";b.passwordValidation&&(c+='\r\n\t\t\t<div class="add-spacing-top clearfix">\r\n\t\t\t\t<label>'+
(null==(a=b.i18n("CAppReenterPassword"))?"":_.escape(a))+":&nbsp;"+(null==(a=b.userString)?"":_.escape(a))+'</label>\r\n\t\t\t\t<input type="password" class="form-control"  name="passwordEntry">\r\n\t\t\t</div>\r\n\t\t');c+='\r\n\t\t<div class="add-spacing-top clearfix">\r\n\t\t\t';b.blockComment&&"Comment"===b.approvalStatus||(c+='\r\n\t\t\t\t<input class="btn '+(null==(a=b.buttonColor)?"":_.escape(a))+'" type="button" name= "submitBtn" value="'+(null==(a=b.buttonText)?"":_.escape(a))+'"/>&nbsp;\r\n\t\t\t');
return c+='\r\n\t\t\t<input class="btn btn-default" type="button" name="cancelBtn" value="'+(null==(a=b.i18n("CAppCancel"))?"":_.escape(a))+'"/>\r\n\t\t</div>\r\n\t</form>\r\n</div>\r\n'}});
define("approval/view/ApproveRejectView","Template approval/ApprovalConstants tpl!approval/view/template/ApproveRejectDialog utils/webi18n!Approval wcr/hover wcr/webcenter_xml jquery underscore".split(" "),function(b,a,c,e,d,i,h,j){function g(a,b){this.approvalModel=a;this.viewModel=b;this._checkbox=this._pswdField=this._conditionField=this._submitBtn=this._cancelBtn=this._dropDownMenu=null}g.prototype.open=function(d,g,f){var i=this.viewModel.isViewFile&&"Prompt"!==this.approvalModel.viewerApprovalCommentType,
m=new b(e,c);void 0!==this.approvalModel.forcedStep&&(f=this.approvalModel.forcedStep);m.d.approvalStatus=g;m.d.conditionApproval=this.approvalModel.steps[f].condApp;m.d.passwordValidation=this.approvalModel.passwordValidation;m.d.blockComment=i;m.d.isViewFile=!0===this.viewModel.isViewFile;m.d.userString=this.approvalModel.getCurrentUserString();g===a.ApprovalStatus.APPROVED||g===a.ApprovalStatus.FORCE_APPROVED?(m.d.buttonColor="btn-success",m.d.buttonText=e.t("CAppCommitApproval")):g==a.ApprovalStatus.REJECTED||
g==a.ApprovalStatus.FORCE_REJECTED?(m.d.buttonColor="btn-danger",m.d.buttonText=e.t("CAppCommitRejection")):(m.d.buttonColor="btn-info",m.d.buttonText=e.t("CAppCommitComment"));dropdownmenu(d.target,d,[m.getRenderedHtml()],400,null,null,!0,null,!0);this._dropDownMenu=h("#dropmenudiv");this._conditionField=h("#ApproveRejectComments",this._dropDownMenu);this._pswdField=h("[name=passwordEntry]",this._dropDownMenu);this._checkbox=h("[name=approvalConditionChkBx]",this._dropDownMenu);this._submitBtn=h("[name=submitBtn]",
this._dropDownMenu);this._cancelBtn=h("[name=cancelBtn]",this._dropDownMenu);this._cancelBtn.on("click",function(){hidemenu()}.bind(this));this._submitBtn.on("click",function(){this._approveReject(g,f)}.bind(this));if(0<this._checkbox.length)this._checkbox.on("change",j.bind(function(){this._conditionField&&this._checkbox&&(!0===this._checkbox.is(":checked")?i?(this._conditionField.val(e.t("CAppDocumentAnnotated")),this._conditionField.hide(),h("#UseAnnotationsMsg").show()):(this._conditionField.prop("disabled",
!1),this._conditionField.show()):(this._conditionField.prop("disabled",!0),this._conditionField.val(""),this._conditionField.hide(),h("#UseAnnotationsMsg").hide()),this.viewModel.adjustPopupHeight&&(this._adjustApproveRejectHeight(),this.viewModel.toggleAction&&this.viewModel.toggleAction()))},this));if(0<this._pswdField.length)this._pswdField.on("keydown",j.bind(function(a){this._submitOnEnter(a,j.bind(function(){this._submitBtn.click()},this))},this));this.viewModel.adjustPopupHeight&&this.viewModel.toggleAction&&
this.viewModel.toggleAction();return this._dropDownMenu};g.prototype._approveReject=function(b,c){if(this.viewModel.beforesubmit)try{this.viewModel.beforesubmit()}catch(d){return}var g={comment:"",action:"",password:""};if(0<this._conditionField.length&&(0===this._checkbox.length||this._checkbox.is(":checked"))){if(""===this._conditionField.val()||null===this._conditionField.val()){if(b===a.ApprovalStatus.COMMENT){window.alert(e.t("CAppYouCannotGiveEmptyComment"));return}if(b===a.ApprovalStatus.APPROVED||
b===a.ApprovalStatus.FORCE_APPROVED){window.alert(e.t("CAppYouCannotGiveEmptyCondition"));return}}g.comment=this._conditionField.val();if(512<g.comment.length){window.alert(e.t("CApp_SUBMIT_ERR__COMMENTFIELD_TOO_LONG"));return}}var m={Approved:"approved",Rejected:"rejected",Comment:"comment",ForceApproved:"forceApproved",ForceRejected:"forceRejected"},s=b;m[b]&&(s=m[b]);if("approved"===s)for(var m=this.approvalModel.steps[c],q=0;q<m.approvers.length;q++)if("MustApprove"===this.approvalModel.currentUserApprovalStatus(c,
q)&&0<m.approvers[q].commentArr.length){for(var p="",p=0<g.comment.length?e.t("CAppCommentsWillBeOmitted")+"\n":e.t("CAppCommentsWillBeOmitted_NoCurrentComment")+"\n",t=0;t<m.approvers[q].commentArr.length;t++)p+="\n"+m.approvers[q].commentArr[t].commentText;if(!window.confirm(p))return}g.action=s;if(!0===this.approvalModel.passwordValidation)if(0<this._pswdField.length)g.password=i.encode64(this._pswdField.val());else throw"pwField or pwEntryField does not exist";this.viewModel.pageRange&&(g.pageindex=
this.viewModel.pageRange);this.approvalModel.submitDisabled?window.alert(e.t("CAppApprovalActionOngoing")):(this.approvalModel.submitDisabled=!0,this.approvalModel.submitAllowed?(this.approvalModel.confirmNeeded=!1,this.viewModel.isEncapsulated?(g.encapsulated=1,this._submitBtn.attr("disabled","disabled"),this._cancelBtn.attr("disabled","disabled"),h.ajax(this.viewModel.actionURL,{data:g,type:"post",success:j.bind(function(a){this.approvalModel.submitDisabled=!1;var c=a.match(/<title>Document Details - Approval Rule<\/title>/gim),
d=null;c&&0<c.length?(c=a.match(/errorOccured ?= ?true ?;/g))&&0<c.length&&(d=h(a).find("#errorFeedBack").text().trim()):d=e.t("CAppSessionExpired");hidemenu();if(d){if(window.alert(d),this.viewModel.approveRejectCallback&&this.viewModel.approveRejectCallback(!1,b,d),this.viewModel.onUpdateCallback)this.viewModel.onUpdateCallback(this.approvalModel)}else if(this.approvalModel.readFromXML(this.approvalModel.readURL),this.viewModel.approveRejectCallback)this.approvalModel.once("initialized",j.bind(this.viewModel.approveRejectCallback,
this,!0,b))},this),error:j.bind(function(){this.approvalModel.submitDisabled=!1;window.alert("Error while submitting approval, please try again")},this)})):this.viewModel.submit(g)):(hidemenu(),this.approvalModel.submitDisabled=!1))};g.prototype._submitOnEnter=function(a,b){13===(a.keyCode||a.which)&&b()};g.prototype._adjustApproveRejectHeight=function(){var a=this._dropDownMenu.css("top");!0===this._checkbox.is(":checked")?this._dropDownMenu.css("top",a.substr(0,a.length-2)-h(this._conditionField).outerHeight(!0)-
4+"px"):this._dropDownMenu.css("top",parseInt(a.substr(0,a.length-2))+h(this._conditionField).outerHeight(!0)+4+"px")};return g});
define("approval/view/ApproveButtonsToolbar","approval/ApprovalConstants approval/view/ApproveRejectView component/actionmenu/ActionMenu utils/webi18n!Approval utils/AnimationFrameRenderer jquery underscore".split(" "),function(b,a,c,e,d,i,h){function j(b,c){d.mixin(this);this.model=b;this._maxButtons=6;this._showStopAppButton=!1;this._container=null;this._approveRejectDialog=new a(b,c)}j.prototype.setElement=function(a){this._container=a};j.prototype.render=function(a,b){this._maxButtons=a;this._showStopAppButton=
b;this._render()};j.prototype._doRender=function(){this._container.append(this._renderApprovalActionButtons())};j.prototype._renderApprovalActionButtons=function(){var a=i("<div/>",{"class":"btn-toolbar",role:"toolbar"}),d=this.model.getApprovalActions();if(!d.showContent)return"";var j=i("<div>",{"class":"action-menu-component"}).appendTo(a);h.each(d.list,h.bind(function(a,c){var d="action ",g;switch(a.name){case "Approve":d+="action-success";g=b.images.Approve+" icon-white";break;case "ForceApprove":g=
b.images.ForceApprove+" "+b.imageColors.ForceApprove;break;case "Reject":d+="action-danger";g=b.images.Reject+" icon-white";break;case "ForceReject":g=b.images.ForceReject+" "+b.imageColors.ForceReject;break;case "Comment":g=b.images.Comment}j.append(i("<a>",{"class":d,"data-icon":g,"data-visibility":c>=this._maxButtons?"-1":"1",title:e.t(a.text),text:e.t(a.text),on:{click:h.bind(function(b){this._approveRejectDialog.open(b,a.internalName,a.step)},this)}}))},this));this._showStopAppButton&&i("<a>",
{"class":"action","data-icon":"icon-WCR_Stopped","data-visibility":d.list.length>=this._maxButtons?"-1":"1",title:e.t("CAppStopApprovalCycle"),text:" "+e.t("CAppStopApprovalCycle"),on:{click:h.bind(function(){this.model.submitDisabled?this.model.setError({errorMsg:"CAppApprovalActionOngoing"}):(this.model.submitDisabled=!0,this.model.confirmNeeded=!1,this.model.submit({action:"stopCycle"}))},this)}}).appendTo(j);new c(j);return a};return j});
define("tpl!approval/view/template/ApprovalDueDateDialog",function(){return function(b){var a;return b=""+('<div class="ui-dialog ui-widget ui-widget-content ui-corner-all ui-draggable ui-resizable" style="height: 200px; min-height: 109px; width: 500px; display:none;" id="dueDateRecalcDialog" title="'+(null==(a=b.i18n("CAppDueDateCalculation"))?"":_.escape(a))+'">\r\n\t<div class="wcr-form form-no-labels duedaterecalc_dialogbody">\r\n\t\t<div class="form-section add-padding-left add-padding-right">\r\n\t\t\t<div class="section-title"><label class="offset-label"></label>\r\n\t\t\t\t<h3>'+
(null==(a=b.i18n("CAppCalculateNewDueDates"))?"":_.escape(a))+'</h3>\r\n\t\t\t</div>\r\n\t\t\t<div class="form-group"><label class="offset-label"></label>\r\n\t\t\t\t<div class="form-entry">\r\n\t\t\t\t\t<div class="radio"><label><input type="radio" name="dueDateOperations" value="0">'+(null==(a=b.i18n("CAppGiveEachStage"))?"":_.escape(a))+'</label><label class="duedate-calc-inline-input"><input type="text" value="1" size="4" id="giveDays">&nbsp;'+(null==(a=b.i18n("CAppDays"))?"":_.escape(a))+'</label><label class="duedate-calc-inline-input"><input type="text" value="0" size="4" id="giveHours">&nbsp;'+
(null==(a=b.i18n("CAppHours"))?"":_.escape(a))+'</label></div>\r\n\t\t\t\t</div>\r\n\t\t\t</div>\r\n\t\t\t<div class="form-group"><label class="offset-label"></label>\r\n\t\t\t\t<div class="form-entry">\r\n\t\t\t\t\t<div class="radio"><label><input type="radio" name="dueDateOperations" value="1">'+(null==(a=b.i18n("CAppShiftDueDatesWith"))?"":_.escape(a))+'</label><label class="duedate-calc-inline-input"><input type="text" value="1" size="4" id="shiftDays">&nbsp;'+(null==(a=b.i18n("CAppDays"))?"":
_.escape(a))+'</label><label class="duedate-calc-inline-input"><input type="text" value="0" size="4" id="shiftHours">&nbsp;'+(null==(a=b.i18n("CAppHours"))?"":_.escape(a))+'</label></div>\r\n\t\t\t\t</div>\r\n\t\t\t</div>\r\n\t\t\t<div class="form-group"><label class="offset-label"></label>\r\n\t\t\t\t<div class="form-entry">\r\n\t\t\t\t\t<div class="radio"><label><input type="radio" name="dueDateOperations" value="2">'+(null==(a=b.i18n("CAppShiftDueLatestOn"))?"":_.escape(a))+'</label></div>\r\n\t\t\t\t\t<div class="form-datetime">\r\n\t\t\t\t\t\t'+
(null==(a=b.callTemplate("approval/view/template/Calendar",{id:"shiftLatestToDate",name:"shiftLatestToDate"}))?"":a)+"\r\n\t\t\t\t\t\t"+(null==(a=b.callTemplate("approval/view/template/HourDropDown",{dueHour:b.defaultDueHour,id:"shiftLatestToHour",name:"shiftLatestToHour"}))?"":a)+'\r\n\t\t\t\t\t</div>\r\n\t\t\t\t</div>\r\n\t\t\t</div>\r\n\t\t\t<div class="form-group"><label class="offset-label"></label>\r\n\t\t\t\t<div class="form-entry">\r\n\t\t\t\t\t<div class="radio"><label><input type="radio" name="dueDateOperations" value="3">'+
(null==(a=b.i18n("CAppShiftDueFirstOn"))?"":_.escape(a))+'</label></div>\r\n\t\t\t\t\t<div class="form-datetime">\r\n\t\t\t\t\t\t'+(null==(a=b.callTemplate("approval/view/template/Calendar",{id:"shiftFirstToDate",name:"shiftFirstToDate"}))?"":a)+"\r\n\t\t\t\t\t\t"+(null==(a=b.callTemplate("approval/view/template/HourDropDown",{dueHour:b.defaultDueHour,id:"shiftFirstToHour",name:"shiftFirstToHour"}))?"":a)+'\r\n\t\t\t\t\t</div>\r\n\t\t\t\t</div>\r\n\t\t\t</div>\r\n\t\t\t<div class="form-group"><label class="offset-label"></label>\r\n\t\t\t\t<div class="form-entry">\r\n\t\t\t\t\t<div class="radio"><label><input type="radio" name="dueDateOperations" value="4">'+
(null==(a=b.i18n("CAppDistributeEvenly"))?"":_.escape(a))+'</label></div>\r\n\t\t\t\t</div>\r\n\t\t\t\t<div class="form-entry">\r\n\t\t\t\t\t<div class="form-datetime distribute-evenly">\r\n\t\t\t\t\t\t<table>\r\n\t\t\t\t\t\t\t<tr>\r\n\t\t\t\t\t\t\t\t<td class="add-padding-bottom">'+(null==(a=b.i18n("CAppFrom"))?"":_.escape(a))+'</td>\r\n\t\t\t\t\t\t\t\t<td class="add-padding-bottom">\r\n\t\t\t\t\t\t\t\t\t'+(null==(a=b.callTemplate("approval/view/template/Calendar",{id:"distributeFromDate",name:"distributeFromDate"}))?
"":a)+"\r\n\t\t\t\t\t\t\t\t\t"+(null==(a=b.callTemplate("approval/view/template/HourDropDown",{dueHour:b.defaultDueHour,id:"distributeFromHour",name:"distributeFromHour"}))?"":a)+"\r\n\t\t\t\t\t\t\t\t</td>\r\n\t\t\t\t\t\t\t</tr>\r\n\t\t\t\t\t\t\t<tr>\r\n\t\t\t\t\t\t\t\t<td>"+(null==(a=b.i18n("CAppTo"))?"":_.escape(a))+"</td>\r\n\t\t\t\t\t\t\t\t<td>\r\n\t\t\t\t\t\t\t\t\t"+(null==(a=b.callTemplate("approval/view/template/Calendar",{id:"distributeToDate",name:"distributeToDate"}))?"":a)+"\r\n\t\t\t\t\t\t\t\t\t"+
(null==(a=b.callTemplate("approval/view/template/HourDropDown",{dueHour:b.defaultDueHour,id:"distributeToHour",name:"distributeToHour"}))?"":a)+"\r\n\t\t\t\t\t\t\t\t</td>\r\n\t\t\t\t\t\t\t</tr>\r\n\t\t\t\t\t\t</table>\r\n\t\t\t\t\t</div>\r\n\t\t\t\t</div>\r\n\t\t\t</div>\r\n\t\t</div>\r\n\t</div>\r\n</div>")}});
define("tpl!approval/view/template/Calendar",function(){return function(b){var a;return b=""+('<div class="form-date">\r\n\t<div class="input-group">\r\n\t\t\r\n\t\t<input type="text" id="'+(null==(a=b.d.id)?"":_.escape(a))+'" name="'+(null==(a=b.d.name)?"":_.escape(a))+'" class="form-control">\r\n\t\t<span class="form-datetime-btn input-group-addon" onclick="$(\'#'+(null==(a=b.d.id)?"":_.escape(a))+'\').datepicker(\'show\'); return false;">\r\n\t\t\t<i class="icon icon-WCR_Calendar" id="IMG1"></i>\r\n\t\t</span>\r\n\t</div>\r\n</div>')}});
define("approval/view/ApprovalView","Template approval/ApprovalConstants approval/ApprovalUtils approval/view/NotificationView approval/view/ApprovalStageContainer approval/view/ApproveRejectView approval/view/ApproveButtonsToolbar component/message/MessageComponent utils/Observer tpl!approval/view/template/ApprovalDueDateDialog tpl!approval/view/template/HourDropDown tpl!approval/view/template/Calendar utils/webi18n!Approval utils/AnimationFrameRenderer utils/dateShift utils/datetools jquery underscore wcr/webcenter_html wcr/webcenter_xml".split(" "),
function(b,a,c,e,d,i,h,j,g,l,n,f,k,m,s,q,p,t,u,v){function r(b,c,d,e,f){m.mixin(this);g.mixin(this);this.model=b;this.currentUser=e;this.displayElem=d;this.loading();this.MSG_TAG="APPROVAL";this.stageViews=[];this._boundOnUpdate=this.onUpdate.bind(this);this._boundShowChangesApprovalMessage=t.debounce(this._toggleSaveButtonEnabled.bind(this),10);this._stagesContainer=p("<div />",{"class":"col-lg-8 col-xs-12"});this._saveButton=null;this._messageModel=new j.MessageModel;this.approveRejectDialog=new i(b,
c);c.on("submit",this._submitForm.bind(this));this.approveButtonsToolbar=new h(this.model,c);b.onAll(["update","changed.approvalstatus","initialized"],this._boundOnUpdate);b.onAll(["changed.*","stage.*.changed.*","stage.*.changed.approvers.*","initialized"],this._boundShowChangesApprovalMessage);b.on("error",this._showErrors.bind(this));b.on("changed.stages.deleted",this._deleteStageView.bind(this));b.on("changed.stages.deleted",function(){var b=t.last(this.model.steps);b&&b.approvalStatus!==a.ApprovalStatus.NOT_STARTED&&
this._renderDueDateElement()}.bind(this));b.on("changed.stages.added",this._addStage.bind(this));b.on("changed.stages.added",function(){var b=this.model.steps[this.model.steps.length-2],c=t.last(this.model.steps);b&&(b.approvalStatus!==a.ApprovalStatus.NOT_STARTED&&c.approvalStatus===a.ApprovalStatus.NOT_STARTED)&&this._renderDueDateElement()}.bind(this));b.on("submit",this._submitForm.bind(this));this._isSimplePage=!0===f;b=window.webcenterConfig.userLang||"en";this._helpArr={};this._helpArr.CAppApprovalStatusHelp=
"./help/ApprovalStatusHelp_"+b+".htm";this._helpArr.CAppDueDateHelp="./help/DueDateHelp_"+b+".htm";this._helpArr.CAppApprovalMasterHelp="./help/ApprovalMasterHelp_"+b+".htm";this._helpArr.CAppEditNextVersionHelp="./help/EditNextVersionHelp_"+b+".htm";this._helpArr.CAppWhenNewVersionUploadedHelp="./help/WhenNewVersionUploadedHelp_"+b+".htm"}r.prototype.onUpdate=function(){this._loadingMsg.remove();this._render()};r.prototype.loading=function(){this.displayElem.empty();this._loadingMsg=p("<div/>").html(k.t("CAppLoadingApprovalSetup"));
this.displayElem.append(this._loadingMsg)};r.prototype._doRender=function(){var b=p("<div/>",{"class":"container-fluid wcr-approval"});this._messageWidget||(this._messageWidget=p("<div>",{"class":"messagebar messageWidget add-spacing-bottom"}),new j.MessageWidget(this._messageModel,this._messageWidget));b.append(this._messageWidget);this._isSimplePage||(this._header||(this._header=p(".page-sub-title")),this._header.addClass("approvalTitle"),b.append(this._header),this.model.documentId&&(this._approvalStatusElem&&
this._approvalStatusElem.remove(),this.model.nextVersion||(this._approvalStatusElem=this._getStatusElement(),this._approvalStatusElem.insertAfter(this._header))));var c=this._getForm();b.append(c);if(this.model.errorObj)this._showErrors(this.model.errorObj);else{this.model.nextVersion&&(c=p("<div>").addClass("next-version-message alert alert-warning").append(p("<div>").text(k.t("CAppEditingNextVersion"))),b.append(c));var c=p("<div/>",{"class":"row add-spacing-bottom add-spacing-top"}).appendTo(b),
d=p("<div/>",{"class":"add-spacing-bottom"});this._isSimplePage?this.model.documentId&&!this.model.nextVersion&&d.append(this._getStatusElement()):(d.addClass("nextVersionButtonOnTop"),this.model.nextVersion&&d.addClass("with-message"));if(this.model.approvalStatus!==a.ApprovalStatus.NOT_DEFINED&&this.model.documentId&&!this.model.readOnly){var e=this._createHelpBalloon("CAppEditNextVersionHelp");d.append(p("<div/>").addClass("nextVersionButton").append(this._getSwitchToNextVersionBtn()).append(e))}e=
p("<div />",{"class":"col-lg-8 col-lg-pull-4 col-xs-12"}).append(this._getActionButtons());c.append(p("<div/>",{"class":"col-lg-4 col-lg-push-8 col-xs-12"}).append(d));c.append(e);c=p("<div/>",{"class":"row add-spacing-bottom"}).appendTo(b);c.append(this._stagesContainer);c.append(p("<div/>",{"class":"col-lg-4 col-xs-12 approval-settings-panel"}).append(this._getGeneralSettingsPanel()));this.displayElem.empty();this.displayElem.append(b);t.each(this.stageViews,t.bind(function(a){a.render()},this))}};
r.prototype._getForm=function(){this.form=p("<form>",{name:"actionform",id:"actionform",method:"post",action:this.model.actionURL});this.xmlContentField=p("<input>",{type:"hidden",id:"xmlcontent",name:"xmlcontent"}).appendTo(this.form);this.actionField=p("<input>",{type:"hidden",id:"actionField",name:"action"}).appendTo(this.form);this.passwordField=p("<input>",{type:"hidden",id:"password",name:"password"}).appendTo(this.form);this.commentField=p("<input>",{type:"hidden",id:"commentField",name:"comment"}).appendTo(this.form);
return this.form};r.prototype._submitForm=function(a){this.commentField.val(a.comment);this.actionField.val(a.action);this.model.passwordValidation&&this.passwordField.val(a.password);this.form.submit()};r.prototype._getStatusElement=function(){var b=p("<div />");b.addClass("approvalStatusLabelContainer");this._isSimplePage&&b.addClass("simple");var c=this._createHelpBalloon("CAppApprovalStatusHelp"),d=p("<span>",{text:k.t("CApp"+this.model.approvalStatus),"class":a.statusLabels[this.model.approvalStatus]+
" approvalStatusLabel"});b.append(d).append(c);return b};r.prototype._getGeneralSettingsPanel=function(){if(this.model.approvalStatus!==a.ApprovalStatus.NOT_DEFINED&&!this.model.readOnly){var b=p("<div>",{"class":"collapseSettingsPanel"}).append(p("<a>",{"class":"pull-left collapsed","data-toggle":"collapse","data-target":"#collapseSettings"}).append(p("<i>",{"class":"icon icon-normal"}))),c=p("<div/>",{"class":"panel panel-default"});p("<div/>",{"class":"panel-heading"}).append(p("<h3>",{"class":"panel-title",
text:k.t("CAppSettings")})).appendTo(c);var d=p("<div/>",{"class":"panel-body collapse",id:"collapseSettings"}).appendTo(c);this.model.approvalStatus===a.ApprovalStatus.NOT_STARTED&&!this.model.readOnly?(d.append(this._getDueDateElement(!1)),this.model.isStagedApprovalAllowed()&&d.append(this._getWhenNewVersionUploadedElement(!1)),d.append(this._getApprovalMasterElement(!1)),d.append(this._getNotificationElement(!1))):this.model.approvalStatus!==a.ApprovalStatus.NOT_DEFINED&&!this.model.readOnly&&
(d.append(this._getDueDateElement(!0)),this.model.isStagedApprovalAllowed()&&d.append(this._getWhenNewVersionUploadedElement(!0)),d.append(this._getApprovalMasterElement(!0)),d.append(this._getNotificationElement(!0)));c=p("<div>",{"class":"settingsPanel"}).append(c);return p("<div>").append(b).append(c)}};r.prototype._renderDueDateElement=function(){var b=this.displayElem.find(".approval-due-date-element"),c=this.displayElem.find(".final-due-date-element"),d=null;!this.model.readOnly&&this.model.approvalStatus!==
a.ApprovalStatus.NOT_DEFINED&&(d=this._getDueDateElement(this.model.approvalStatus!==a.ApprovalStatus.NOT_STARTED));d&&(b.after(d),b.remove(),c.remove())};r.prototype._getDueDateElement=function(b){var d=k.t("CAppDueDate"),e=this.model.dueDateType,f=k.t("CApp"+e);this.model.dueDateType===a.DueDateType.LEAD_TIMES_WITH_FINAL_DATE&&(f+=" "+c.getDateHourString(this.model.finalDueDate)+" ");if(b)return this._createFormEntryWithSelect(d,f,!1);var g=!0;(b=t.last(this.model.steps))&&b.approvalStatus!==a.ApprovalStatus.NOT_STARTED&&
(g=!1);b=a.dueDateOptions;!this.model.documentId&&!this.model.isMultiDocSetup&&(b=a.dueDateOptionsFolderProject);var h=null,i=null,j=function(){i&&(i.remove(),i=null);g&&(this.model.approvalStatus===a.ApprovalStatus.NOT_STARTED&&this.model.isStagedApprovalAllowed()&&this.model.dueDateType===a.DueDateType.FIXED?(i=this._getDueDateRecalculateButton(),h.append(i)):this.model.dueDateType===a.DueDateType.LEAD_TIMES_WITH_FINAL_DATE&&(i=this._getFinalDueDateElement(),i.insertAfter(h)))}.bind(this);this.model.on("changed.duedatetype",
j);var m=t.bind(function(a){this.model.changeDueDateType(a)},this),h=this._createFormEntryWithSelect(d,f,g,e,!1,b,m,null,j,"CAppDueDateHelp","approval_duedate_select");h.addClass("approval-due-date-element");return h};r.prototype._getWhenNewVersionUploadedElement=function(a){var b=k.t("CAppWhenNewVersionUploaded"),c=["RestartApproval","RestartStage","InheritApproval"],d=this.model.uponNewVersion,e=t.bind(function(a){this.model.changeInheritApproval(a)},this);return a?this._createFormEntryWithSelect(b,
k.t("CApp"+d),!1):this._createFormEntryWithSelect(b,k.t("CApp"+d),!0,d,!0,c,e,null,null,"CAppWhenNewVersionUploadedHelp","approval_new_version_select")};r.prototype._getApprovalMasterElement=function(b){var d=k.t("CAppApprovalMaster"),e="";this.model.approvalMasterType===a.ApprovalMasterType.USER&&this.model.approvalMaster===this.currentUser.userId&&(e=k.t("CAppMe"));this.model.approvalMasterType===a.ApprovalMasterType.PROJECT_MANAGER&&(e=k.t("CAppProjectManager"));this.model.approvalMasterType===
a.ApprovalMasterType.UPLOADER&&(e=k.t("CAppUploader"));var f;if(this.model.approvalMasterType===a.ApprovalMasterType.USER&&this.model.approvalMaster!==this.currentUser.userId){f=c.findMemberObj("User",this.model.approvalMaster,this.model.projectMembers);var g="";f||(f=c.findMemberObj("User",this.model.approvalMaster,this.model.usersWithNoAccess),g=p("<div>").append(p("<i>",{"class":"icon icon-warning icon-WCR_Msg-Warning",title:k.t("CAppAppMasterUserNoMember")})).html());f&&(e=b?e+u.getUserNameStringActiveHTML(null,
f.firstName,f.lastName,f.userName,f.isActive,k.t("CAppUserDeactivated"),!0):e+u.getUserNameStringActiveText(f.firstName,f.lastName,f.userName,f.isActive,k.t("CAppUserDeactivated")),e+=g)}this.model.approvalMasterType===a.ApprovalMasterType.GROUP&&(f=c.findMemberObj("Group",this.model.approvalMaster,this.model.projectMembers),null===f?e="<i  class='icon icon-large icon-warning icon-WCR_Msg-Warning' ></i>"+v.xmlencode(k.t("CAppAppMasterGroupNoMember")):(e=k.t("CAppGroup"),f.isRole&&(e=k.t("CAppRole")),
e=f.groupName+" ("+e+")"));if(b)return this._createFormEntryWithSelect(d,e,!1);b=this.model.approvalMasterType;this.model.approvalMasterType===a.ApprovalMasterType.USER&&this.model.approvalMaster===this.currentUser.userId?b="$Me$":this.model.approvalMasterType===a.ApprovalMasterType.PROJECT_MANAGER?b="$PM$":this.model.approvalMasterType===a.ApprovalMasterType.UPLOADER?b="$Uploader$":this.model.approvalMasterType===a.ApprovalMasterType.GROUP?b="$Group$"+this.model.approvalMaster:this.model.approvalMasterType===
a.ApprovalMasterType.USER&&(b=this.model.approvalMaster);g=f=!0;this.model.steps[0]&&this.model.steps[0].approvalStatus!==a.ApprovalStatus.NOT_STARTED&&(g=f=!1);var h=["$Me$","$PM$","$Uploader$"],i=[k.t("CAppMe"),k.t("CAppProjectManager"),k.t("CAppUploader")];this.createMemberOptionArrays(this.model.projectMembers,0,!0,"",!0,h,i);var j=t.bind(function(a){this.model.changeApprovalMaster(a)},this);return this._createFormEntryWithSelect(d,e,f,b,g,h,j,i,null,"CAppApprovalMasterHelp","approval_master_select")};
r.prototype._createFormEntryWithSelect=function(a,b,c,d,e,f,g,h,i,j,m){var l;if(c){l=p("<select>",{"class":"form-control","data-sahi-id":m});for(var n=0;n<f.length;n++){var q="",q=h?h[n]:k.t("CApp"+f[n]),q=p("<option>",{value:f[n]}).html(q);f[n]===d&&q.prop("selected",!0);l.append(q)}g&&l.change(function(){var a=l.val();g(a)})}d=p("<div/>",{"class":"form-group"});p("<label>",{text:a}).appendTo(d);a=p("<div/>",{"class":"form-entry"}).appendTo(d);if(e)a.append(l);else{var r=p("<span>",{"class":"general-settings-form-entry-value"}).html(b).appendTo(a);
c&&(a.append(l),l.hide(),r.append(p("<a>",{"class":"btn btn-no-border btn-no-padding-right","data-sahi-id":m+"_edit"}).append(p("<i>",{"class":"icon icon-WCR_Actions-Edit12"}))).on("click",function(){l.show();r.hide();i()}))}j&&(b=this._createHelpBalloon(j),c=p("<div />").addClass("input-group"),c.append(a.children()),a.append(c),c.append(p("<div />").addClass("input-group-btn").append(b)));return d};r.prototype._getNotificationElement=function(a){this.notificationView=new e(this.model.notificationInfo,
!a);a=p("<div />");this.notificationView.setElement(a);return a};r.prototype._getActionButtons=function(){var b=p('<div class="approval-action-buttons">');if(this.model.approvalStatus===a.ApprovalStatus.NOT_DEFINED){this.model.readOnly?this._showWarnMessage(k.t("CAppNotDefined"),null,this.MSG_TAG):this._addSetupApprovalButton(b,this.model.approvalRuleChanged?!1:!0);if((this.model.documentId||!0===this.model.isMultiDocSetup)&&this.currentUser&&!0===this.currentUser.canStartApproval&&!this.model.nextVersion)(this.model.hasProjectApprovalSetup||
this.model.hasFolderApprovalSetup)&&this._addStartDefaultApprovalButton(b);!this.model.readOnly&&this.model.approvalRuleChanged&&(b.prepend(this._getSaveButton()),b.append(this._getRevertButton(!0)))}else this.model.approvalStatus===a.ApprovalStatus.PENDING?this._addApprovalActions(b):this.model.approvalStatus===a.ApprovalStatus.NOT_STARTED&&this._addSaveCancelStartApprovalButtons(b,!0);this.model.approvalStatus===a.ApprovalStatus.NOT_DEFINED&&!this.model.readOnly&&this._addMoreActions(b);return b};
r.prototype._addSetupApprovalButton=function(b,c){p("<button>",{"class":c?"btn btn-primary add-spacing-right":"btn btn-default add-spacing-right",type:"button",on:{click:t.bind(function(){this.model.approvalStatus===a.ApprovalStatus.NOT_DEFINED&&this.model.setApprovalStatus(a.ApprovalStatus.NOT_STARTED);this.model.addNewStage(0)},this)}}).append(p("<i>",{"class":"icon icon-WCR_Actions-Appr-Setup12"})).append(" "+k.t("CAppSetupSimpleApproval")).appendTo(b)};r.prototype._addStartDefaultApprovalButton=
function(a){p("<button>",{"class":"btn btn-default add-spacing-right",type:"button",on:{click:t.bind(function(){this.save(!0)},this)}}).append(p("<i>",{"class":"icon icon-WCR_Actions-Appr-Start12"})).append(" "+k.t("CAppStartDefaultApprovalCycle")).appendTo(a)};r.prototype._addMoreActions=function(a){var b=p("<div>",{"class":"feedback-with-actions"}),c=p("<div>",{"class":"feedback-actions"}).append(p("<p>",{text:"More Actions"})),d=p("<ul>");this.model.isProjectSetupAvailable()&&d.append(p("<li>").append(this._getLoadProjectApprovalButton(!1)));
this.model.isFolderSetupAvailable()&&d.append(p("<li>").append(this._getLoadFolderApprovalButton(!1)));this.model.documentId&&d.append(p("<li>").append(p("<a>",{text:this.model.nextVersion?k.t("CAppGoBackToCurrentVersion"):k.t("CAppEditApprovalSetupForNextVersion"),on:{click:t.bind(function(){this.model.nextVersion?this.model.backToCurrentVersion():this.model.editSetupForNextVersion()},this)}})));0<d.children().length&&a.append(b.append(c.append(d)))};r.prototype._getLoadProjectApprovalButton=function(a){if(this.model.isProjectSetupAvailable()){var b=
{on:{click:t.bind(function(){var a=!0;0<this.model.steps.length&&(a=this.confirmWithWarnings({question:"CAppConfirmLoadProject"}));a&&this.model.loadProjectFolderApproval(!1)},this)}};if(a)return b["class"]="btn btn-default",b.type="button",b.title=k.t("CAppLoadProjectApprovalSetup"),p("<button>",b).append(p("<i>",{"class":"icon icon-WCR_Actions-Project-Load12"}));b.text=k.t("CAppLoadProjectApprovalSetup");return p("<a>",b)}};r.prototype._getLoadFolderApprovalButton=function(a){if(this.model.isFolderSetupAvailable()){var b=
{on:{click:t.bind(function(){var a=!0;0<this.model.steps.length&&(a=this.confirmWithWarnings({question:"CAppConfirmLoadProject"}));a&&this.model.loadProjectFolderApproval(!0)},this)}};if(a)return b["class"]="btn btn-default",b.title=k.t("CAppLoadFolderApprovalSetup"),b.type="button",p("<button>",b).append(p("<i>",{"class":"icon icon-WCR_Actions-Folder-Load12"}));b.text=k.t("CAppLoadFolderApprovalSetup");return p("<a>",b)}};r.prototype._addSaveCancelStartApprovalButtons=function(b){var c=!t.some(this.model.steps,
function(b){return b.approvalStatus!==a.ApprovalStatus.NOT_STARTED}),d=p("<div/>",{"class":"pull-left"}),e=p("<div/>",{"class":"pull-right btn-group"}),f=this._getSaveButton(),g=this._getRevertButton(!1),h=this._getStartApprovalButton(),i=this._getClearButton(),j=null,k=null;c&&(j=this._getLoadProjectApprovalButton(!0),k=this._getLoadFolderApprovalButton(!0));f&&d.append(f);h&&d.append(h);j&&e.append(j);k&&e.append(k);g&&e.append(g);i&&e.append(i);b.append(d).append(e);return b};r.prototype._getSaveButton=
function(){return this._saveButton=this.model.readOnly?null:p("<button>",{"class":"btn btn-primary add-spacing-right save-button",type:"button",on:{click:t.bind(function(){if(t.isEmpty(this.model.steps)&&!0===this.model.approvalRuleChanged&&!this.confirmWithWarnings({question:"CAppAreYouSureSaveEmpty"}))return!1;this.validateAndSave(!1)},this)}}).append(p("<i>",{"class":"icon icon-WCR_Save12"})).append(" "+k.t("CAppSave"))};r.prototype.validateAndSave=function(a){var b=this.model.validate();0<b.errors.length?
this._showErrors(b):0<b.warnings.length?this.confirmWithWarnings({question:"CAppContinueAnyway",warnings:b.warnings})&&this.save(a):this.save(a)};r.prototype.save=function(a){var b=null;if(this.model.readOnly){if(!a){this.model.setError({errorMsg:"CAppCannotSaveIfNothingChanged"});return}}else{b=this.model.writeToXML();if(!b)return this.model.setError({errorMsg:"CAppCouldNotSave"}),!1;this.xmlContentField&&this.xmlContentField.val(b)}if(this.actionField)this.model.nextVersion?this.actionField.val("saveNextDocVersion"):
a?this.actionField.val("startCycle"):this.actionField.val("save");else throw"actionField is null";if(this.model.submitDisabled)this.model.setError({errorMsg:"CAppApprovalActionOngoing"});else if(this.model.submitDisabled=!0,this.model.submitAllowed)this.model.confirmNeeded=!1,this.form.submit();else return b&&document.getElementById(this.model.saveFieldId)&&(document.getElementById(this.model.saveFieldId).value=b),this.model.submitDisabled=!1};r.prototype._getRevertButton=function(a){if(!this.model.readOnly){var b=
p("<button>",{"class":"btn btn-default",type:"button",title:k.t("CAppRevert"),on:{click:t.bind(function(){this.model.cancel()},this)}}).append(p("<i>",{"class":"icon icon-WCR_Revert12"}));a&&(b.append(" "+k.t("CAppRevert")),b.addClass("add-spacing-right"));return b}};r.prototype._getClearButton=function(){if(!this.model.readOnly&&0<this.model.steps.length&&this.model.steps[0].approvalStatus===a.ApprovalStatus.NOT_STARTED)return p("<button>",{"class":"btn btn-default",type:"button",title:k.t("CAppClear"),
on:{click:t.bind(function(){this.model.clear()},this)}}).append(p("<i>",{"class":"icon icon-WCR_Actions-Clear12"}))};r.prototype._getStartApprovalButton=function(){if(this.model.approvalStatus===a.ApprovalStatus.NOT_STARTED&&(this.model.documentId||!0===this.model.isMultiDocSetup)&&this.currentUser&&!0===this.currentUser.canStartApproval&&!this.model.nextVersion)return p("<button>",{"class":"btn btn-default add-spacing-right",type:"button",on:{click:t.bind(function(){this.validateAndSave(!0)},this)}}).append(p("<i>",
{"class":"icon icon-WCR_Actions-Appr-Start12"})).append(" "+k.t("CAppStartApprovalCycle"))};r.prototype._addApprovalActions=function(b){var c=!1;this.model.approvalStatus===a.ApprovalStatus.PENDING&&this.model.documentId&&(this.currentUser&&this.currentUser.canStartApproval)&&(c=!0);this.approveButtonsToolbar.setElement(b);this.approveButtonsToolbar.render(3,c)};r.prototype._getSwitchToNextVersionBtn=function(){var a=!this.model.nextVersion?"icon icon-WCR_Actions-Edit12":"icon icon-WCR_Revert12",
b=!this.model.nextVersion?k.t("CAppEditApprovalSetupForNextVersion"):k.t("CAppGoBackToCurrentVersion");return p("<button>",{"class":"btn btn-default",type:"button",on:{click:t.bind(function(){var a=!0;this.model.approvalRuleChanged&&(a=this.confirmWithWarnings({question:this.model.newVersion?"CAppConfirmBackToCurrent":"CAppConfirmGoToNextVersion"}));if(!a)return!1;this.model.nextVersion?this.model.backToCurrentVersion():this.model.editSetupForNextVersion()},this)}}).append(p("<i>",{"class":a})).append(" "+
b)};r.prototype._getDueDateRecalculateButton=function(){if(0===p("#dueDateRecalcDialog").length){var a=new b(k,l);a.d.defaultDueHour=34;this.displayElem.append(a.getRenderedHtml())}return p("<button>",{"class":"btn btn-default add-spacing-top",type:"button",text:k.t("CAppDueDateCalculation"),on:{click:function(){this._createDueDateRecalcDialog();p("#dueDateRecalcDialog").dialog("open")}.bind(this)}})};r.prototype._createDueDateRecalcDialog=t.once(function(){var a={};a[k.t("CAppCancel")]=function(){p(this).dialog("close")};
a[k.t("CAppOK")]=function(){this._doDueDateOperation()&&p("#dueDateRecalcDialog").dialog("close")}.bind(this);var b="auto";p.browser.msie&&(b="700px");p("#dueDateRecalcDialog").dialog({autoOpen:!1,modal:!1,closeOnEscape:!0,draggable:!0,height:"auto",resizable:!0,width:b,maxWidth:500,buttons:a});this._createCalendar("#shiftLatestToDate","#shiftLatestToHour");this._createCalendar("#shiftFirstToDate","#shiftFirstToHour");this._createCalendar("#distributeFromDate","#distributeFromHour");this._createCalendar("#distributeToDate",
"#distributeToHour")});r.prototype._doDueDateOperation=function(){var b=!0;if(this.model.dueDateType!==a.DueDateType.FIXED)throw"You cannot change due dates when the due date type is not fixed due dates";var c=document.getElementsByName("dueDateOperations"),c=t.find(c,function(a){return a.checked}),d;switch(null!=c?parseInt(c.value):null){case null:window.alert(k.t("CAppSelectOperation"));b=!1;break;case 0:c=parseInt(document.getElementById("giveDays").value,10);d=parseFloat(document.getElementById("giveHours").value);
this.model.addTimeToStages(c,d)||(window.alert(k.t("CAppDaysAndHoursMustBePositive")),b=!1);break;case 1:c=parseInt(document.getElementById("shiftDays").value);d=parseFloat(document.getElementById("shiftHours").value);this.model.shiftDueDatesOfStages(c,d)||(window.alert(k.t("CAppDaysAndHoursMustBeSameSign")),b=!1);break;case 2:if(!document.getElementById("shiftLatestToDate").value){window.alert(k.t("CAppPleaseGiveADate"));b=!1;break}c=q.getDateString(document.getElementById("shiftLatestToDate").value);
d=document.getElementById("shiftLatestToHour").value;c=new Date(c);d&&c.setHours(Math.floor(d/2));2*Math.floor(d/2)==d?c.setMinutes(0):c.setMinutes(30);c=q.fixDateSummerWinterTime(c,!0);this.model.shiftDueDatesToLatest(c);break;case 3:if(!this.model.steps||!this.model.steps[0]||!this.model.steps[0].dueDate){window.alert(k.t("CAppFirstStepHasNoDueDate"));return}if(this.model.steps[0].approvalStatus!==a.ApprovalStatus.NOT_STARTED){window.alert(k.t("CAppCannotShiftIfStarted"));return}if(!document.getElementById("shiftFirstToDate").value){window.alert(k.t("CAppPleaseGiveADate"));
b=!1;break}c=q.getDateString(document.getElementById("shiftFirstToDate").value);d=document.getElementById("shiftFirstToHour").value;c=new Date(c);d&&c.setHours(Math.floor(d/2));2*Math.floor(d/2)==d?c.setMinutes(0):c.setMinutes(30);c=q.fixDateSummerWinterTime(c,!0);this.model.shiftDueDatesToFirst(c);break;case 4:if(!document.getElementById("distributeFromDate").value||!document.getElementById("distributeToDate").value){window.alert(k.t("CAppPleaseGiveADate"));b=!1;break}c=new Date(q.getDateString(document.getElementById("distributeFromDate").value));
(d=document.getElementById("distributeFromHour").value)&&c.setHours(Math.floor(d/2));2*Math.floor(d/2)==d?c.setMinutes(0):c.setMinutes(30);c=q.fixDateSummerWinterTime(c,!0);d=new Date(q.getDateString(document.getElementById("distributeToDate").value));var e=document.getElementById("distributeToHour").value;e&&d.setHours(Math.floor(e/2));2*Math.floor(e/2)==e?d.setMinutes(0):d.setMinutes(30);d=q.fixDateSummerWinterTime(d,!0);this.model.distributeDueDatesEvenly(c,d)||(window.alert(k.t("CAppFirstDayLater")),
b=!1);break;default:window.alert("this operation is not implemented")}return b};r.prototype._getFinalDueDateElement=function(){if(!this.model.finalDueDate||this.model.finalDueDate.constructor!==Date)this.model.finalDueDate=new Date;var a=q.fixDateSummerWinterTime(this.model.finalDueDate,!1),c=p("<input>",{"class":"form-control","data-sahi-id":"CAppFinalDueDateText",value:q.getDateString(a),type:"text",name:"datepicker"}),d=new b(k,n);d.d.d={dueHour:2*a.getHours()+Math.floor(a.getMinutes()/30),name:"hourdropdown",
id:"CAppFinalDueHour"};var a=p(d.getRenderedHtml()),e=a.find("[name=hourdropdown]");c.datepicker({dateFormat:"M dd, yy",onClose:function(){var a=e[0];a&&0===a.selectedIndex&&(a.selectedIndex=37)}});d=p('<span class="form-datetime-btn input-group-addon">').on("click",function(){c.datepicker("show")});a=p("<div/>",{"class":"form-group final-due-date-element"}).append(p("<label>",{text:k.t("CAppFinalDueDate")})).append(p("<div/>",{"class":"form-entry"}).append(p('<div class="clearfix final-due-date">').append(p('<div class="form-date input-group">').append(c).append(d.append(p('<i class="icon icon-WCR_Calendar" >')))).append(a)));
d=function(){var a=c.val(),b=q.getDateString(a);if(b){var a=e.val(),b=new Date(b),d=Math.floor(a/2),a=2*d==a?0:30;b.setHours(d);b.setMinutes(a);b.setSeconds(0);a=q.fixDateSummerWinterTime(b,!0);isNaN(a.getTime())?c.val(q.getDateString(q.fixDateSummerWinterTime(this.model.finalDueDate,!1))):this.model.setFinalDueDate(a)}else c.val(q.getDateString(q.fixDateSummerWinterTime(this.model.finalDueDate,!1)))}.bind(this);c.change(d);e.change(d);return a};r.prototype._createCalendar=function(a,b){null!==p(a)&&
p(a).datepicker({dateFormat:"M dd, yy",onClose:function(){var a=p(b)[0];a&&0===a.selectedIndex&&(a.selectedIndex=37)}})};r.prototype._toggleSaveButtonEnabled=function(){this._saveButton&&(this.model.approvalRuleChanged?this._saveButton.removeAttr("disabled"):this._saveButton.attr("disabled","disabled"))};r.prototype.getStagesContainer=function(){return this._stagesContainer};r.prototype._addStage=function(a){var b=this.model.getStageNumber(a)-1;this._addViewsAtIndex(b,a)};r.prototype._addViewsAtIndex=
function(a,b){var c=this.stageViews.length===a,e=new d(this.model,b);this.stageViews.splice(a,0,e);0===a?this._stagesContainer.prepend(e.element):c?this._stagesContainer.append(e.element):this._getStageViewForStageAtIndex(a-1).element.after(e.element);e.render()};r.prototype._getStageViewForStageAtIndex=function(a){var b=this.model.getStageAtIndex(a);return t.find(this.stageViews,function(a){return a.stageModel===b})};r.prototype._deleteStageView=function(){t.each(arguments,function(a){var b=t.findIndex(this.stageViews,
function(b){return b.stageModel===a});-1<b&&this.stageViews.splice(b,1)}.bind(this))};r.prototype.createMemberOptionArrays=function(a,b,d,e,f,g,h){if(this.model.roleAssignments&&0<this.model.roleAssignments.length&&f)for(var f=k.t("CAppRole"),i=k.t("CAppGroup"),j=0;j<this.model.roleAssignments.length;j++){var l=this.model.roleAssignments[j],m=l.roleID,n=l.roleName,p=c.findMemberObj("Group",m,this.model.projectMembers);if(!(null===p||"undefined"===p)){p=l.userRoleAssignments;l=l.groupRoleAssignments;
g.push("$Group$"+m);h.push(n+"<"+f+">");if(p&&0<p.length&&!d)for(m=0;m<p.length;m++){var n=p[m],q=n.name;g.push(n.ID);h.push("&nbsp;&nbsp;&nbsp;&nbsp;"+q)}if(l&&0<l.length&&!d)for(p=0;p<l.length;p++){var r=l[p],m=r.ID,n=r.name,q=r.assigneeID,r=r.assigneeName,s=!1;q&&0<q.length&&(r&&0<r.length)&&(s=!0);s?h.push("&nbsp;&nbsp;&nbsp;&nbsp;"+r+" @ "+n+"<"+i+">"):h.push("&nbsp;&nbsp;&nbsp;&nbsp;"+n+"<"+i+">");s?g.push(q):g.push("$Group$"+m)}}}for(f=0;f<a.length;f++)if((i=a[f])&&(!d||!0===i.canBeApprovalMaster)){j=
"";for(l=0;l<b;l++)j+="&nbsp;&nbsp;&nbsp;&nbsp;";l=i.isActive||this.model.approvalMaster===i.userId;if("User"===i.memberType&&l){if(j+=v.xmlencode(u.getUserNameStringActiveText(i.firstName,i.lastName,i.userName,i.isActive,k.t("CAppUserDeactivated"))),!e||-1!==j.toLowerCase().indexOf(e.toLowerCase()))g.push(i.userId),h.push(j)}else if("Group"===i.memberType&&!i.isRole){i.groupName&&(l=k.t("CAppGroup"),i.isRole&&(l=k.t("CAppRole")),j+=i.groupName+"<"+l+">");if(!e||-1!==j.toLowerCase().indexOf(e.toLowerCase()))g.push("$Group$"+
i.groupId),h.push(j);i.members&&0<i.members.length&&this.createMemberOptionArrays(i.members,b+1,d,e,!1,g,h)}}};r.prototype._showErrors=function(a){var b=a.errorMsg?k.t(a.errorMsg)+"\n":"";if(a.errors)for(var c=0;c<a.errors.length;c++){var d=a.errors[c];d.parameters||(d.parameters=[]);d.inline?b+="- "+d.tag:(0<c&&(b+="\n"),d.parameters.unshift(d.tag),b+="- "+k.t.apply(this,d.parameters))}this._showErrorMessage(b,null,this.MSG_TAG)};r.prototype.confirmWithWarnings=function(a){var b=a.warningMsg?k.t(a.warningMsg)+
"\n":"";if(a.warnings)for(var c=0;c<a.warnings.length;c++){var d=a.warnings[c];d.parameters||(d.parameters=[]);0<c&&(b+="\n");d.inline?b+=d.tag:(d.parameters.unshift(d.tag),b+=k.t.apply(this,d.parameters))}a.question&&(b+="\n"+k.t(a.question));return window.confirm(b)};r.prototype._showSuccessMessage=function(a,b,c,d){this._messageModel.markObsolete(d);a=new j.Message(j.MessageType.SUCCESS,a,b,c,d);this._messageModel.addToMessageQueue(a)};r.prototype._showErrorMessage=function(a,b,c){this._messageModel.markObsolete(c);
a=new j.Message(j.MessageType.ERROR,a,b,!1,c);this._messageModel.addToMessageQueue(a)};r.prototype._showWarnMessage=function(a,b,c){this._messageModel.markObsolete(c);a=new j.Message(j.MessageType.WARN,a,b,!1,c);this._messageModel.addToMessageQueue(a)};r.prototype._createHelpBalloon=function(a){a=p("<a />").addClass("inline_help").attr("title",k.t("CAppHelp")).attr("help-info",a);a.append(p("<i />").addClass("icon icon-WCR_Info-Balloon"));a.on("click",t.bind(function(a){var b=a.currentTarget;a.preventDefault();
a.stopPropagation();a=p(b).attr("help-info");window.open(this._helpArr[a],a).focus()},this));return a};return r});
define("approval/Approval","approval/ApprovalConstants approval/model/ApprovalModel approval/model/ApproveRejectViewModel approval/controller/SortableController approval/view/ApprovalView utils/webi18n!Approval jquery underscore wcr/hover wcr/date wcr/dateShift wcr/datetools wcr/webcenter_ajax".split(" "),function(b,a,c,e,d,i,h,j){function g(g,i,f,k,m,s,q,p,t,u,v){this.afterInitializationCallback=u||function(){};this.model=new a(i,s,f,m,q,k,p);f=new c(f,t,p,v);this.view=new d(this.model,f,h("#"+g),
m,-1!==i.indexOf("simplePage"));this._sortableController=new e(this.view,this.model);this._sortableController.disable();this.model.on("initialized",function(){q&&(this.model.approvalStatus===b.ApprovalStatus.NOT_DEFINED||this.model.approvalStatus===b.ApprovalStatus.NOT_STARTED)?this._sortableController.enable():this._sortableController.disable()}.bind(this));this.model.once("initialized",j.partial(this.afterInitializationCallback,this));t||(window.onbeforeunload=j.bind(this.confirmExit,this),this.model.confirmNeeded=
!0)}g.prototype.confirmExit=function(){if(this.model.confirmNeeded&&this.model.approvalRuleChanged)return i.t("CAppConfirmPageExit")};g.prototype.setupSingleStageApproval=function(){this.model.approvalStatus===b.ApprovalStatus.NOT_DEFINED&&(this.model.setApprovalStatus(b.ApprovalStatus.NOT_STARTED),this.model.addNewStage(0))};return g});